/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.common.resource.impl;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.emf.common.util.Diagnostic;
import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.sphinx.emf.resource.ExtendedResourceAdapter;
import org.safe.common.internal.messages.Messages;
import org.safe.common.preferences.ISAFEPreferences;
import org.safe.common.resource.SAFEURIFactory;

public class ExtendedSAFEResourceAdapter extends ExtendedResourceAdapter {

	/*
	 * @see org.eclipse.sphinx.emf.resource.ExtendedResourceAdapter#getURI(org.eclipse.emf.ecore.EObject,
	 * org.eclipse.emf.ecore.EStructuralFeature, org.eclipse.emf.ecore.EObject)
	 */
	@Override
	public URI getURI(EObject oldOwner, EStructuralFeature oldOwnerContainingFeature, EObject eObject) {
		// we get URI using old Owner and old feature only if the given eObject is detached from its owner i.e erased
		if (oldOwner != null && oldOwnerContainingFeature != null && eObject.eContainer() == null) {
			return SAFEURIFactory.getURI(oldOwner, oldOwnerContainingFeature, eObject);
		}
		return SAFEURIFactory.getURI(eObject);
	}

	/*
	 * @see org.eclipse.sphinx.emf.resource.ExtendedResourceAdapter#getProblemHandlingOptions()
	 */
	@Override
	public Map<Object, Object> getProblemHandlingOptions() {
		if (problemHandlingOptions == null) {
			problemHandlingOptions = new HashMap<Object, Object>();
			// Set problem handling options according to preferences
			if (ISAFEPreferences.LIMIT_PROBLEM_INDICATION_ON_LOAD.get()) {
				problemHandlingOptions.put(OPTION_MAX_PROBLEM_MARKER_COUNT, ISAFEPreferences.MAX_PROBLEM_REPORTED_ON_LOAD.get());
			} else {
				problemHandlingOptions.put(OPTION_MAX_PROBLEM_MARKER_COUNT, OPTION_MAX_PROBLEM_MARKER_COUNT_UNLIMITED);
			}
			problemHandlingOptions.put(OPTION_XML_VALIDITY_PROBLEM_SEVERITY, ISAFEPreferences.XSD_VALIDATION_SEVERITY_LEVEL.get());

			problemHandlingOptions.put(OPTION_XML_WELLFORMEDNESS_PROBLEM_FORMAT_STRING, Messages.SAFEData00001);
			problemHandlingOptions.put(OPTION_XML_VALIDITY_PROBLEM_FORMAT_STRING, Messages.SAFEData00002);
		}
		return problemHandlingOptions;
	}

	/*
	 * @see org.eclipse.sphinx.emf.resource.ExtendedResourceAdapter#validateURI(java.lang.String)
	 */
	@Override
	public Diagnostic validateURI(String uri) {
		Diagnostic diagnostic = super.validateURI(uri);
		if (diagnostic != Diagnostic.OK_INSTANCE) {
			return diagnostic;
		}

		return SAFEURIFactory.validateURI(uri);
	}
}
