/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.common.resource.impl;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.eclipse.core.runtime.Assert;
import org.eclipse.core.runtime.Platform;
import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.impl.EPackageRegistryImpl;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.util.ExtendedMetaData;
import org.eclipse.emf.ecore.xmi.XMLResource;
import org.eclipse.sphinx.emf.metamodel.IMetaModelDescriptor;
import org.eclipse.sphinx.emf.resource.BasicMigrationExtendedMetaData;
import org.eclipse.sphinx.emf.resource.ExtendedResource;
import org.eclipse.sphinx.emf.resource.ResourceHandlerRegistry;
import org.eclipse.sphinx.emf.resource.SchemaLocationURIHandler;
import org.eclipse.sphinx.emf.serialization.XMLPersistenceMappingResourceFactoryImpl;
import org.eclipse.sphinx.emf.util.EcoreResourceUtil;
import org.safe.common.metamodel.SAFEMetaModelVersionData;
import org.safe.common.metamodel.SAFEReleaseDescriptor;
import org.safe.common.preferences.ISAFEPreferenceConstants;
import org.safe.common.preferences.ISAFEPreferences;

/**
 * <!-- begin-user-doc --> The <b>Resource Factory</b> associated with the package. <!-- end-user-doc -->
 * 
 * @see org.safe.metamodel10.common.util.Safe10ResourceImpl
 * @generated
 */
public abstract class SafeResourceFactoryImpl extends XMLPersistenceMappingResourceFactoryImpl {

	protected ExtendedMetaData extendedMetaData;

	protected Map<String, String> schemaLocationCatalog;

	protected SchemaLocationURIHandler schemaLocationURIHandler;
	/**
	 * The {@link SAFEReleaseDescriptor SAFE release} this {@link Resource.Factory resource factory} is dedicated to.
	 */
	protected SAFEReleaseDescriptor safeRelease;

	protected static Map<String, IMetaModelDescriptor> systemIdToResourceVersionDescriptorCache = new HashMap<String, IMetaModelDescriptor>();

	/**
	 * Creates an instance of the resource factory. <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	public SafeResourceFactoryImpl(SAFEReleaseDescriptor safeRelease) {
		Assert.isNotNull(safeRelease);
		// Assert.isNotNull(safeRelease.getRootEPackage());

		this.safeRelease = safeRelease;

		extendedMetaData = createExtendedMetaData();

		schemaLocationCatalog = createSchemaLocationCatalog();

		schemaLocationURIHandler = createSchemaLocationURIHandler();

		initSchemaLocationBaseURIs();
	}

	protected abstract void initSchemaLocationBaseURIs();

	protected Map<String, String> createSchemaLocationCatalog() {
		Map<String, String> schemaLocationCatalog = new HashMap<String, String>();

		Collection<IMetaModelDescriptor> compatibleDescriptors = safeRelease.getCompatibleResourceVersionDescriptors();

		for (IMetaModelDescriptor descriptor : compatibleDescriptors) {
			SAFEReleaseDescriptor safeDescriptor = (SAFEReleaseDescriptor) descriptor;
			schemaLocationCatalog.put(descriptor.getNamespace(), getSchemaLocation(safeDescriptor));
		}

		return schemaLocationCatalog;
	}

	/**
	 * Creates the {@link SchemaLocationURIHandler} instance. This method can be overridden by tool vendors.
	 * 
	 * @return An instantiated {@link SchemaLocationURIHandler}.
	 */
	protected SchemaLocationURIHandler createSchemaLocationURIHandler() {
		return new SchemaLocationURIHandler(schemaLocationCatalog) {
			@Override
			public URI resolve(URI uri) {
				// Handling of wrong schemaLocation attribute value in import declaration for xml.xsd in
				// /org.safe.metamodel10/model/safe_1-0-1.xsd
				// only location hint but not namespace plus location hint must be specified (see
				// http://www.w3.org/TR/2004/REC-xmlschema-1-20041028/#composition-schemaImport for details)
				String lastSegment = uri.lastSegment();
				if (lastSegment != null && lastSegment.endsWith("%20xml.xsd")) { //$NON-NLS-1$
					uri = URI.createURI("xml.xsd"); //$NON-NLS-1$
				}
				return super.resolve(uri);
			};
		};
	}

	/**
	 * Creates and initializes an {@link ExtendedMetaData} instance to be used on {@link XMLResource resources} created
	 * with this {@link Resource.Factory resource factory}.
	 * 
	 * @return The newly created and initialized {@link ExtendedMetaData} instance.
	 */
	protected ExtendedMetaData createExtendedMetaData() {
		// Create and initialize migration-enabled extended meta data enabling SAFE resources whose version is not
		// the same but compatible with that of current SAFE metamodel implementation to be loaded
		BasicMigrationExtendedMetaData extendedMetaData = new BasicMigrationExtendedMetaData(new EPackageRegistryImpl(EPackage.Registry.INSTANCE)) {
		};

		// extendedMetaData.putPackage(safeRelease.getNamespace(), safeRelease.getRootEPackage());
		for (java.net.URI compatibleNamespaceURI : safeRelease.getCompatibleNamespaceURIs()) {
			extendedMetaData.putPackage(compatibleNamespaceURI.toString(), safeRelease.getRootEPackage());
		}
		return extendedMetaData;
	}

	/**
	 * Initializes given {@link XMLResource resource}.
	 * 
	 * @param resource
	 *            The {@link XMLResource resource} to act upon.
	 */
	public void initResource(XMLResource resource) {
		initDefaultOptions(resource);
		installResourceHandler(resource);
	}

	/**
	 * Initializes default {@link XMLResource#getDefaultLoadOptions() load} and
	 * {@link XMLResource#getDefaultSaveOptions() save} options of given {@link XMLResource resource}.
	 * 
	 * @param resource
	 *            The {@link XMLResource resource} to act upon.
	 */
	protected void initDefaultOptions(XMLResource resource) {
		resource.getDefaultLoadOptions().put(XMLResource.OPTION_EXTENDED_META_DATA, extendedMetaData);
		resource.getDefaultSaveOptions().put(XMLResource.OPTION_EXTENDED_META_DATA, extendedMetaData);

		resource.getDefaultLoadOptions().put(XMLResource.OPTION_USE_ENCODED_ATTRIBUTE_STYLE, Boolean.TRUE);
		// resource.getDefaultLoadOptions().put(XMLResource.OPTION_RECORD_UNKNOWN_FEATURE, Boolean.TRUE);

		resource.getDefaultSaveOptions().put(XMLResource.OPTION_USE_ENCODED_ATTRIBUTE_STYLE, Boolean.TRUE);

		resource.getDefaultLoadOptions().put(XMLResource.OPTION_USE_LEXICAL_HANDLER, Boolean.TRUE);

		resource.getDefaultSaveOptions().put(XMLResource.OPTION_ENCODING, "UTF-8"); //$NON-NLS-1$
		resource.getDefaultSaveOptions().put(XMLResource.OPTION_SAVE_TYPE_INFORMATION, Boolean.FALSE);

		IMetaModelDescriptor resourceVersionDescriptor = getResourceVersionDescriptor(resource);
		resource.getDefaultLoadOptions().put(ExtendedResource.OPTION_RESOURCE_VERSION_DESCRIPTOR, resourceVersionDescriptor);

		resource.getDefaultSaveOptions().put(XMLResource.OPTION_SCHEMA_LOCATION, Boolean.TRUE);
		resource.getDefaultSaveOptions().put(ExtendedResource.OPTION_SCHEMA_LOCATION_CATALOG, schemaLocationCatalog);
		resource.getDefaultLoadOptions().put(XMLResource.OPTION_URI_HANDLER, schemaLocationURIHandler);
		resource.getDefaultSaveOptions().put(XMLResource.OPTION_URI_HANDLER, schemaLocationURIHandler);

		resource.getDefaultLoadOptions().put(ExtendedResource.OPTION_ENABLE_SCHEMA_VALIDATION,
				Platform.isRunning() ? ISAFEPreferences.XSD_VALIDATION_ON_LOAD.get() : ISAFEPreferenceConstants.PREF_XSD_VALIDATION_ON_LOAD_DEFAULT);

		// Performance enhancement
		resource.getDefaultLoadOptions().put(XMLResource.OPTION_DEFER_IDREF_RESOLUTION, Boolean.TRUE);

		resource.getDefaultLoadOptions().put(XMLResource.OPTION_SUPPRESS_DOCUMENT_ROOT, Boolean.TRUE);
	}

	/**
	 * Installs a {@link ResourceHandler resource handler} for current SAFE release on specified {@link XMLResource
	 * resource}. This is required to support the SAFE Extender.
	 * 
	 * @param resource
	 *            The XMLResource for which the {@link ResourceHandler resource handler} is to be installed.
	 */
	protected void installResourceHandler(XMLResource resource) {
		XMLResource.ResourceHandler resourceHandler = ResourceHandlerRegistry.INSTANCE.getHandler(safeRelease.getRootEPackage().getNsURI());
		if (resourceHandler != null) {
			resource.getDefaultLoadOptions().put(XMLResource.OPTION_RESOURCE_HANDLER, resourceHandler);
			resource.getDefaultSaveOptions().put(XMLResource.OPTION_RESOURCE_HANDLER, resourceHandler);
		}
	}

	/**
	 * Returns a {@link IMetaModelDescriptor descriptor} describing the version of specified {@link Resource resource}.
	 * This is done by retrieving the resource's {@link EcoreResourceUtil#readModelNamespace(Resource) model namespace}
	 * and testing if it matches either the {@link #safeRelease SAFE release} behind this
	 * {@link SAFEResourceFactoryImpl resource factory} or one of its
	 * {@link IMetaModelDescriptor#getCompatibleResourceVersionDescriptors() compatible resource version descriptor}s.
	 * 
	 * @param resource
	 *            The {@link Resource resource} whose version descriptor is to be retrieved.
	 * @return The resource's {@link IMetaModelDescriptor version descriptor} or <code>null</code> if no such could be
	 *         determined.
	 * @see EcoreResourceUtil#readModelNamespace(Resource)
	 * @see IMetaModelDescriptor#getCompatibleResourceVersionDescriptors()
	 */

	public IMetaModelDescriptor getResourceVersionDescriptor(Resource resource) {
		Assert.isNotNull(resource);

		String modelNamespace = EcoreResourceUtil.readModelNamespace(resource);

		if (modelNamespace == null) {
			return null;
		}

		List<SAFEReleaseDescriptor> applicableDescriptors = new ArrayList<SAFEReleaseDescriptor>();

		Collection<IMetaModelDescriptor> compatibleDescriptors = safeRelease.getCompatibleResourceVersionDescriptors();

		for (IMetaModelDescriptor descriptor : compatibleDescriptors) {
			SAFEReleaseDescriptor safeDescriptor = (SAFEReleaseDescriptor) descriptor;
			if (safeDescriptor.getNamespace().equals(modelNamespace)) {
				applicableDescriptors.add(safeDescriptor);
			}
		}

		if (applicableDescriptors.size() == 1) {
			// namespace based lookup already resulted in a unique result
			return applicableDescriptors.get(0);
		} else if (applicableDescriptors.size() == 0) {
			return null;
		} else {
			// disambiguate multiple namespace matches based on schema location
			Map<String, String> schemaLocationEntries = EcoreResourceUtil.readSchemaLocationEntries(resource);
			String schemaLocation = schemaLocationEntries.get(modelNamespace);

			if (schemaLocation == null) {
				// return latest revision if there is no schema location
				return applicableDescriptors.get(applicableDescriptors.size() - 1);
			}

			IMetaModelDescriptor releaseDescriptorCache = systemIdToResourceVersionDescriptorCache.get(schemaLocation);
			if (releaseDescriptorCache != null) {
				return releaseDescriptorCache;
			}

			for (SAFEReleaseDescriptor safeDescriptor : applicableDescriptors) {
				if (getSchemaLocation(safeDescriptor).equals(schemaLocation)) {
					systemIdToResourceVersionDescriptorCache.put(schemaLocation, safeDescriptor);
					return safeDescriptor;
				}
			}
		}

		return null;
	}

	@SuppressWarnings("nls")
	private static String getSchemaLocation(SAFEReleaseDescriptor safeDescriptor) {
		SAFEMetaModelVersionData versionData = safeDescriptor.getSAFEVersionData();
		return "safe_" + versionData.getMajor() + "-" + versionData.getMinor() + "-" + versionData.getRevision() + ".xsd";
	}

} // Safe10ResourceFactoryImpl
