/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.examples.explorer;

import org.safe.examples.common.ui.providers.TypeNameLabelDecorator;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.sphinx.emf.explorer.BasicExplorerLabelProvider;
import org.eclipse.ui.navigator.ICommonContentExtensionSite;
import org.safe.examples.explorer.internal.Activator;

/**
 * Extends the BasicExplorerLabelProvider to add the interface name of the element to display after the element's name.
 * This functionality can optionally be enabled via the view menu.
 */
public class AppearanceExampleExplorerLabelProvider extends BasicExplorerLabelProvider {

	private TypeNameLabelDecorator typeNameLabelDecorator;

	@Override
	public void init(ICommonContentExtensionSite aConfig) {
		super.init(aConfig);
		typeNameLabelDecorator = new TypeNameLabelDecorator();
	}

	@Override
	public String getText(Object element) {
		if (element instanceof IStructuredSelection) {
			IStructuredSelection selection = (IStructuredSelection) element;
			element = selection.getFirstElement();
		}

		String text = super.getText(element);
		if (isShowTypeName()) {
			return typeNameLabelDecorator.decorateText(text, element);
		} else {
			return text;
		}
	}

	private boolean isShowTypeName() {
		return Activator.getPlugin().getDialogSettings().getBoolean(AppearanceExampleActionProvider.MODEL_ELEMENT_APPEARANCE_PROPERTY);
	}
}
