/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.ide.jobs;

import org.eclipse.core.resources.IFile;
import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EClassifier;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.sphinx.emf.workspace.jobs.CreateNewModelFileJob;
import org.safe.common.metamodel.SAFEReleaseDescriptor;

public class CreateSAFEFileJob extends CreateNewModelFileJob {

	protected static final String SAFE_TYPE_NAME = "SAFE";
	protected static final String SAFEPACKAGE_TYPE_NAME = "SAFEPackage"; //$NON-NLS-1$
	protected static final String SHORTNAME_FEATURE_NAME = "shortName"; //$NON-NLS-1$
	protected static final String TOPLEVELPACKAGES_FEATURE_NAME = "topLevelPackage"; //$NON-NLS-1$
	protected static final String ROOT_EPACKAGE_URI = "http://safe-project.eu/1.0.1"; //"http://safe-project.eu/1.0.1/safe10/classmodel/commonstructure/toplevel"; //$NON-NLS-1$

	private String initialSAFEPackageName;
	
	/**
	 * Creates an CreateSAFEFileJob
	 * 
	 * @param jobName
	 *            the name of the job
	 * @param safeFile
	 *            the SAFE file that will be created, should not be null
	 * @param safeRelease
	 *            the identifier of the SAFE file's content type. If null the default content type specified by
	 *            the release descriptor behind the SAFE file's project will be used
	 * @param ePackage
	 * @PARAM eClassifier
	 */
	public CreateSAFEFileJob(String jobName, IFile safeFile, SAFEReleaseDescriptor safeRelease,  String initialSAFEPackageName) {
		super(jobName, safeFile, safeRelease, safeRelease.getEPackageRegistry().getEPackage(ROOT_EPACKAGE_URI), safeRelease.getEPackageRegistry().getEPackage(ROOT_EPACKAGE_URI).getEClassifier(SAFE_TYPE_NAME));
		this.initialSAFEPackageName = initialSAFEPackageName; 
	}
	
	 /**
     * Returns the EPackage that contains the required classifier
     * @param classifierName
     * @return
     */
	public EPackage getClassifierEPackage(String classifierName){
		for (EPackage pkg : metaModelDescriptor.getEPackages()) {
			EClassifier eClassifier = pkg.getEClassifier(classifierName);
			if (eClassifier != null) {
				return pkg;
			}
		}			
		return null;
	}
	
	/**
     * Returns the EClass which is required by the specific classifier name
     * @param classifierName
     * @return
     */
	public EClass getClassifierEclass(String classifierName){
		for (EPackage pkg : metaModelDescriptor.getEPackages()) {
			EClassifier eClassifier = pkg.getEClassifier(classifierName);
			if (eClassifier != null) {
				return (EClass) eClassifier;
			}
		}	
		
		return null;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.sphinx.emf.workspace.jobs.CreateNewModelFileJob#createInitialModel()
	 */
	@Override
	public EObject createInitialModel() {		
		EClass safeModel = (EClass) rootObjectEClassifier;
		EObject rootObject = rootObjectEPackage.getEFactoryInstance().create(safeModel);		
		
		// Add a Root SAFEPackage
		if (initialSAFEPackageName != null) {
			EClass safePackageType = getClassifierEclass(SAFEPACKAGE_TYPE_NAME);
			EPackage safePkg = getClassifierEPackage(SAFEPACKAGE_TYPE_NAME);

			EObject safePackage = safePkg.getEFactoryInstance().create(safePackageType);	
			EStructuralFeature shortNameFeature = safePackageType .getEStructuralFeature(SHORTNAME_FEATURE_NAME);
			safePackage.eSet(shortNameFeature, initialSAFEPackageName);
			 
			EStructuralFeature topLevelPackagesFeature = safeModel.getEStructuralFeature(TOPLEVELPACKAGES_FEATURE_NAME);
			 @SuppressWarnings("unchecked")
			EList<EObject> safePackages = (EList<EObject>) rootObject.eGet(topLevelPackagesFeature);
			safePackages.add(safePackage);
		}
		
		return rootObject;
	}
	
}
