/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10.edit.providers;

import java.util.ArrayList;
import java.util.Collection;

import org.eclipse.emf.common.notify.Adapter;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.notify.Notifier;

import org.eclipse.emf.edit.provider.ChangeNotifier;
import org.eclipse.emf.edit.provider.ComposeableAdapterFactory;
import org.eclipse.emf.edit.provider.ComposedAdapterFactory;
import org.eclipse.emf.edit.provider.IChangeNotifier;
import org.eclipse.emf.edit.provider.IDisposable;
import org.eclipse.emf.edit.provider.IEditingDomainItemProvider;
import org.eclipse.emf.edit.provider.IItemLabelProvider;
import org.eclipse.emf.edit.provider.IItemPropertySource;
import org.eclipse.emf.edit.provider.INotifyChangedListener;
import org.eclipse.emf.edit.provider.IStructuredItemContentProvider;
import org.eclipse.emf.edit.provider.ITreeItemContentProvider;

import org.safe.metamodel.safe10.util.Safe10AdapterFactory;

/**
 * This is the factory that is used to provide the interfaces needed to support Viewers.
 * The adapters generated by this factory convert EMF adapter notifications into calls to {@link #fireNotifyChanged fireNotifyChanged}.
 * The adapters also support Eclipse property sheets.
 * Note that most of the adapters are shared among multiple instances.
 * <!-- begin-user-doc -->
 * <!-- end-user-doc -->
 * @generated
 */
public class Safe10ItemProviderAdapterFactory extends Safe10AdapterFactory implements ComposeableAdapterFactory, IChangeNotifier, IDisposable
{
  /**
   * This keeps track of the root adapter factory that delegates to this adapter factory.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ComposedAdapterFactory parentAdapterFactory;

  /**
   * This is used to implement {@link org.eclipse.emf.edit.provider.IChangeNotifier}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected IChangeNotifier changeNotifier = new ChangeNotifier();

  /**
   * This keeps track of all the supported types checked by {@link #isFactoryForType isFactoryForType}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected Collection<Object> supportedTypes = new ArrayList<Object>();

  /**
   * This constructs an instance.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public Safe10ItemProviderAdapterFactory()
  {
    supportedTypes.add(IEditingDomainItemProvider.class);
    supportedTypes.add(IStructuredItemContentProvider.class);
    supportedTypes.add(ITreeItemContentProvider.class);
    supportedTypes.add(IItemLabelProvider.class);
    supportedTypes.add(IItemPropertySource.class);
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.FilterExpression} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected FilterExpressionItemProvider filterExpressionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.FilterExpression}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createFilterExpressionAdapter()
  {
    if (filterExpressionItemProvider == null)
    {
      filterExpressionItemProvider = new FilterExpressionItemProvider(this);
    }

    return filterExpressionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Application} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ApplicationItemProvider applicationItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Application}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createApplicationAdapter()
  {
    if (applicationItemProvider == null)
    {
      applicationItemProvider = new ApplicationItemProvider(this);
    }

    return applicationItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Component} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ComponentItemProvider componentItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Component}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createComponentAdapter()
  {
    if (componentItemProvider == null)
    {
      componentItemProvider = new ComponentItemProvider(this);
    }

    return componentItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ComponentModeInstanceRef} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ComponentModeInstanceRefItemProvider componentModeInstanceRefItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ComponentModeInstanceRef}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createComponentModeInstanceRefAdapter()
  {
    if (componentModeInstanceRefItemProvider == null)
    {
      componentModeInstanceRefItemProvider = new ComponentModeInstanceRefItemProvider(this);
    }

    return componentModeInstanceRefItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Node} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected NodeItemProvider nodeItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Node}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createNodeAdapter()
  {
    if (nodeItemProvider == null)
    {
      nodeItemProvider = new NodeItemProvider(this);
    }

    return nodeItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.System} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected SystemItemProvider systemItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.System}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createSystemAdapter()
  {
    if (systemItemProvider == null)
    {
      systemItemProvider = new SystemItemProvider(this);
    }

    return systemItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Topic} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected TopicItemProvider topicItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Topic}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createTopicAdapter()
  {
    if (topicItemProvider == null)
    {
      topicItemProvider = new TopicItemProvider(this);
    }

    return topicItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MultiLevelSafetyExtension} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MultiLevelSafetyExtensionItemProvider multiLevelSafetyExtensionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MultiLevelSafetyExtension}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMultiLevelSafetyExtensionAdapter()
  {
    if (multiLevelSafetyExtensionItemProvider == null)
    {
      multiLevelSafetyExtensionItemProvider = new MultiLevelSafetyExtensionItemProvider(this);
    }

    return multiLevelSafetyExtensionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.FunctionalSafetyExtension} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected FunctionalSafetyExtensionItemProvider functionalSafetyExtensionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.FunctionalSafetyExtension}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createFunctionalSafetyExtensionAdapter()
  {
    if (functionalSafetyExtensionItemProvider == null)
    {
      functionalSafetyExtensionItemProvider = new FunctionalSafetyExtensionItemProvider(this);
    }

    return functionalSafetyExtensionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HazardandRiskSafetyExtension} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HazardandRiskSafetyExtensionItemProvider hazardandRiskSafetyExtensionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HazardandRiskSafetyExtension}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHazardandRiskSafetyExtensionAdapter()
  {
    if (hazardandRiskSafetyExtensionItemProvider == null)
    {
      hazardandRiskSafetyExtensionItemProvider = new HazardandRiskSafetyExtensionItemProvider(this);
    }

    return hazardandRiskSafetyExtensionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarHardwareSafetyExtension} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarHardwareSafetyExtensionItemProvider autosarHardwareSafetyExtensionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarHardwareSafetyExtension}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarHardwareSafetyExtensionAdapter()
  {
    if (autosarHardwareSafetyExtensionItemProvider == null)
    {
      autosarHardwareSafetyExtensionItemProvider = new AutosarHardwareSafetyExtensionItemProvider(this);
    }

    return autosarHardwareSafetyExtensionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarSystemSafetyExtension} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarSystemSafetyExtensionItemProvider autosarSystemSafetyExtensionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarSystemSafetyExtension}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarSystemSafetyExtensionAdapter()
  {
    if (autosarSystemSafetyExtensionItemProvider == null)
    {
      autosarSystemSafetyExtensionItemProvider = new AutosarSystemSafetyExtensionItemProvider(this);
    }

    return autosarSystemSafetyExtensionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarVfbSafetyExtension} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarVfbSafetyExtensionItemProvider autosarVfbSafetyExtensionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarVfbSafetyExtension}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarVfbSafetyExtensionAdapter()
  {
    if (autosarVfbSafetyExtensionItemProvider == null)
    {
      autosarVfbSafetyExtensionItemProvider = new AutosarVfbSafetyExtensionItemProvider(this);
    }

    return autosarVfbSafetyExtensionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ChromosomeApplicationSafetyExtension} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ChromosomeApplicationSafetyExtensionItemProvider chromosomeApplicationSafetyExtensionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ChromosomeApplicationSafetyExtension}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createChromosomeApplicationSafetyExtensionAdapter()
  {
    if (chromosomeApplicationSafetyExtensionItemProvider == null)
    {
      chromosomeApplicationSafetyExtensionItemProvider = new ChromosomeApplicationSafetyExtensionItemProvider(this);
    }

    return chromosomeApplicationSafetyExtensionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ChromosomeSystemSafetyExtension} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ChromosomeSystemSafetyExtensionItemProvider chromosomeSystemSafetyExtensionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ChromosomeSystemSafetyExtension}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createChromosomeSystemSafetyExtensionAdapter()
  {
    if (chromosomeSystemSafetyExtensionItemProvider == null)
    {
      chromosomeSystemSafetyExtensionItemProvider = new ChromosomeSystemSafetyExtensionItemProvider(this);
    }

    return chromosomeSystemSafetyExtensionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ImplementationSafetyExtension} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ImplementationSafetyExtensionItemProvider implementationSafetyExtensionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ImplementationSafetyExtension}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createImplementationSafetyExtensionAdapter()
  {
    if (implementationSafetyExtensionItemProvider == null)
    {
      implementationSafetyExtensionItemProvider = new ImplementationSafetyExtensionItemProvider(this);
    }

    return implementationSafetyExtensionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.DesignLevelSafetyExtension} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected DesignLevelSafetyExtensionItemProvider designLevelSafetyExtensionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.DesignLevelSafetyExtension}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createDesignLevelSafetyExtensionAdapter()
  {
    if (designLevelSafetyExtensionItemProvider == null)
    {
      designLevelSafetyExtensionItemProvider = new DesignLevelSafetyExtensionItemProvider(this);
    }

    return designLevelSafetyExtensionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HardwareSafetyExtension} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HardwareSafetyExtensionItemProvider hardwareSafetyExtensionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HardwareSafetyExtension}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHardwareSafetyExtensionAdapter()
  {
    if (hardwareSafetyExtensionItemProvider == null)
    {
      hardwareSafetyExtensionItemProvider = new HardwareSafetyExtensionItemProvider(this);
    }

    return hardwareSafetyExtensionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.SoftwareSafetyExtension} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected SoftwareSafetyExtensionItemProvider softwareSafetyExtensionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.SoftwareSafetyExtension}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createSoftwareSafetyExtensionAdapter()
  {
    if (softwareSafetyExtensionItemProvider == null)
    {
      softwareSafetyExtensionItemProvider = new SoftwareSafetyExtensionItemProvider(this);
    }

    return softwareSafetyExtensionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.SAFE} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected SAFEItemProvider safeItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.SAFE}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createSAFEAdapter()
  {
    if (safeItemProvider == null)
    {
      safeItemProvider = new SAFEItemProvider(this);
    }

    return safeItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.SAFEPackage} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected SAFEPackageItemProvider safePackageItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.SAFEPackage}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createSAFEPackageAdapter()
  {
    if (safePackageItemProvider == null)
    {
      safePackageItemProvider = new SAFEPackageItemProvider(this);
    }

    return safePackageItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarClientServerOperationInstanceRef} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarClientServerOperationInstanceRefItemProvider autosarClientServerOperationInstanceRefItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarClientServerOperationInstanceRef}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarClientServerOperationInstanceRefAdapter()
  {
    if (autosarClientServerOperationInstanceRefItemProvider == null)
    {
      autosarClientServerOperationInstanceRefItemProvider = new AutosarClientServerOperationInstanceRefItemProvider(this);
    }

    return autosarClientServerOperationInstanceRefItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarComponentInCompositionInstanceRef} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarComponentInCompositionInstanceRefItemProvider autosarComponentInCompositionInstanceRefItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarComponentInCompositionInstanceRef}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarComponentInCompositionInstanceRefAdapter()
  {
    if (autosarComponentInCompositionInstanceRefItemProvider == null)
    {
      autosarComponentInCompositionInstanceRefItemProvider = new AutosarComponentInCompositionInstanceRefItemProvider(this);
    }

    return autosarComponentInCompositionInstanceRefItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarModeInPortFromComponentInCompositionInstanceRef} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarModeInPortFromComponentInCompositionInstanceRefItemProvider autosarModeInPortFromComponentInCompositionInstanceRefItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarModeInPortFromComponentInCompositionInstanceRef}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarModeInPortFromComponentInCompositionInstanceRefAdapter()
  {
    if (autosarModeInPortFromComponentInCompositionInstanceRefItemProvider == null)
    {
      autosarModeInPortFromComponentInCompositionInstanceRefItemProvider = new AutosarModeInPortFromComponentInCompositionInstanceRefItemProvider(this);
    }

    return autosarModeInPortFromComponentInCompositionInstanceRefItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarPortInCompositionInstanceRef} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarPortInCompositionInstanceRefItemProvider autosarPortInCompositionInstanceRefItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarPortInCompositionInstanceRef}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarPortInCompositionInstanceRefAdapter()
  {
    if (autosarPortInCompositionInstanceRefItemProvider == null)
    {
      autosarPortInCompositionInstanceRefItemProvider = new AutosarPortInCompositionInstanceRefItemProvider(this);
    }

    return autosarPortInCompositionInstanceRefItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarUndefinedInstanceRef} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarUndefinedInstanceRefItemProvider autosarUndefinedInstanceRefItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarUndefinedInstanceRef}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarUndefinedInstanceRefAdapter()
  {
    if (autosarUndefinedInstanceRefItemProvider == null)
    {
      autosarUndefinedInstanceRefItemProvider = new AutosarUndefinedInstanceRefItemProvider(this);
    }

    return autosarUndefinedInstanceRefItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarVariableDataPrototypeInstanceRef} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarVariableDataPrototypeInstanceRefItemProvider autosarVariableDataPrototypeInstanceRefItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarVariableDataPrototypeInstanceRef}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarVariableDataPrototypeInstanceRefAdapter()
  {
    if (autosarVariableDataPrototypeInstanceRefItemProvider == null)
    {
      autosarVariableDataPrototypeInstanceRefItemProvider = new AutosarVariableDataPrototypeInstanceRefItemProvider(this);
    }

    return autosarVariableDataPrototypeInstanceRefItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Restrictable} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected RestrictableItemProvider restrictableItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Restrictable}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createRestrictableAdapter()
  {
    if (restrictableItemProvider == null)
    {
      restrictableItemProvider = new RestrictableItemProvider(this);
    }

    return restrictableItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Restriction} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected RestrictionItemProvider restrictionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Restriction}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createRestrictionAdapter()
  {
    if (restrictionItemProvider == null)
    {
      restrictionItemProvider = new RestrictionItemProvider(this);
    }

    return restrictionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Variant} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected VariantItemProvider variantItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Variant}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createVariantAdapter()
  {
    if (variantItemProvider == null)
    {
      variantItemProvider = new VariantItemProvider(this);
    }

    return variantItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ErrorModel} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ErrorModelItemProvider errorModelItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ErrorModel}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createErrorModelAdapter()
  {
    if (errorModelItemProvider == null)
    {
      errorModelItemProvider = new ErrorModelItemProvider(this);
    }

    return errorModelItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ErrorModelInstanceRef} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ErrorModelInstanceRefItemProvider errorModelInstanceRefItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ErrorModelInstanceRef}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createErrorModelInstanceRefAdapter()
  {
    if (errorModelInstanceRefItemProvider == null)
    {
      errorModelInstanceRefItemProvider = new ErrorModelInstanceRefItemProvider(this);
    }

    return errorModelInstanceRefItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ErrorModelPrototype_analysisFunctionTarget} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ErrorModelPrototype_analysisFunctionTargetItemProvider errorModelPrototype_analysisFunctionTargetItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ErrorModelPrototype_analysisFunctionTarget}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createErrorModelPrototype_analysisFunctionTargetAdapter()
  {
    if (errorModelPrototype_analysisFunctionTargetItemProvider == null)
    {
      errorModelPrototype_analysisFunctionTargetItemProvider = new ErrorModelPrototype_analysisFunctionTargetItemProvider(this);
    }

    return errorModelPrototype_analysisFunctionTargetItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ErrorModelPrototype_designFunctionTarget} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ErrorModelPrototype_designFunctionTargetItemProvider errorModelPrototype_designFunctionTargetItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ErrorModelPrototype_designFunctionTarget}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createErrorModelPrototype_designFunctionTargetAdapter()
  {
    if (errorModelPrototype_designFunctionTargetItemProvider == null)
    {
      errorModelPrototype_designFunctionTargetItemProvider = new ErrorModelPrototype_designFunctionTargetItemProvider(this);
    }

    return errorModelPrototype_designFunctionTargetItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ErrorModelPrototype_hwTarget} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ErrorModelPrototype_hwTargetItemProvider errorModelPrototype_hwTargetItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ErrorModelPrototype_hwTarget}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createErrorModelPrototype_hwTargetAdapter()
  {
    if (errorModelPrototype_hwTargetItemProvider == null)
    {
      errorModelPrototype_hwTargetItemProvider = new ErrorModelPrototype_hwTargetItemProvider(this);
    }

    return errorModelPrototype_hwTargetItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.FaultFailurePort_functionTarget} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected FaultFailurePort_functionTargetItemProvider faultFailurePort_functionTargetItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.FaultFailurePort_functionTarget}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createFaultFailurePort_functionTargetAdapter()
  {
    if (faultFailurePort_functionTargetItemProvider == null)
    {
      faultFailurePort_functionTargetItemProvider = new FaultFailurePort_functionTargetItemProvider(this);
    }

    return faultFailurePort_functionTargetItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.FaultFailurePort_hwPinTarget} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected FaultFailurePort_hwPinTargetItemProvider faultFailurePort_hwPinTargetItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.FaultFailurePort_hwPinTarget}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createFaultFailurePort_hwPinTargetAdapter()
  {
    if (faultFailurePort_hwPinTargetItemProvider == null)
    {
      faultFailurePort_hwPinTargetItemProvider = new FaultFailurePort_hwPinTargetItemProvider(this);
    }

    return faultFailurePort_hwPinTargetItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.FaultFailurePort_hwPortTarget} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected FaultFailurePort_hwPortTargetItemProvider faultFailurePort_hwPortTargetItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.FaultFailurePort_hwPortTarget}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createFaultFailurePort_hwPortTargetAdapter()
  {
    if (faultFailurePort_hwPortTargetItemProvider == null)
    {
      faultFailurePort_hwPortTargetItemProvider = new FaultFailurePort_hwPortTargetItemProvider(this);
    }

    return faultFailurePort_hwPortTargetItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MalfunctionInstanceRef} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MalfunctionInstanceRefItemProvider malfunctionInstanceRefItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MalfunctionInstanceRef}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMalfunctionInstanceRefAdapter()
  {
    if (malfunctionInstanceRefItemProvider == null)
    {
      malfunctionInstanceRefItemProvider = new MalfunctionInstanceRefItemProvider(this);
    }

    return malfunctionInstanceRefItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.EastADLErrorBehavior} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected EastADLErrorBehaviorItemProvider eastADLErrorBehaviorItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.EastADLErrorBehavior}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createEastADLErrorBehaviorAdapter()
  {
    if (eastADLErrorBehaviorItemProvider == null)
    {
      eastADLErrorBehaviorItemProvider = new EastADLErrorBehaviorItemProvider(this);
    }

    return eastADLErrorBehaviorItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.FailureLogicFormula} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected FailureLogicFormulaItemProvider failureLogicFormulaItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.FailureLogicFormula}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createFailureLogicFormulaAdapter()
  {
    if (failureLogicFormulaItemProvider == null)
    {
      failureLogicFormulaItemProvider = new FailureLogicFormulaItemProvider(this);
    }

    return failureLogicFormulaItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.NativeErrorBehavior} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected NativeErrorBehaviorItemProvider nativeErrorBehaviorItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.NativeErrorBehavior}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createNativeErrorBehaviorAdapter()
  {
    if (nativeErrorBehaviorItemProvider == null)
    {
      nativeErrorBehaviorItemProvider = new NativeErrorBehaviorItemProvider(this);
    }

    return nativeErrorBehaviorItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.EMPAnalysis} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected EMPAnalysisItemProvider empAnalysisItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.EMPAnalysis}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createEMPAnalysisAdapter()
  {
    if (empAnalysisItemProvider == null)
    {
      empAnalysisItemProvider = new EMPAnalysisItemProvider(this);
    }

    return empAnalysisItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.EMPBswModule} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected EMPBswModuleItemProvider empBswModuleItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.EMPBswModule}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createEMPBswModuleAdapter()
  {
    if (empBswModuleItemProvider == null)
    {
      empBswModuleItemProvider = new EMPBswModuleItemProvider(this);
    }

    return empBswModuleItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.EMPDesign} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected EMPDesignItemProvider empDesignItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.EMPDesign}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createEMPDesignAdapter()
  {
    if (empDesignItemProvider == null)
    {
      empDesignItemProvider = new EMPDesignItemProvider(this);
    }

    return empDesignItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.EMPHwComponent} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected EMPHwComponentItemProvider empHwComponentItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.EMPHwComponent}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createEMPHwComponentAdapter()
  {
    if (empHwComponentItemProvider == null)
    {
      empHwComponentItemProvider = new EMPHwComponentItemProvider(this);
    }

    return empHwComponentItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.EMPReference} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected EMPReferenceItemProvider empReferenceItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.EMPReference}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createEMPReferenceAdapter()
  {
    if (empReferenceItemProvider == null)
    {
      empReferenceItemProvider = new EMPReferenceItemProvider(this);
    }

    return empReferenceItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.EMPSwComponent} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected EMPSwComponentItemProvider empSwComponentItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.EMPSwComponent}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createEMPSwComponentAdapter()
  {
    if (empSwComponentItemProvider == null)
    {
      empSwComponentItemProvider = new EMPSwComponentItemProvider(this);
    }

    return empSwComponentItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.EMTypeAnalysis} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected EMTypeAnalysisItemProvider emTypeAnalysisItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.EMTypeAnalysis}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createEMTypeAnalysisAdapter()
  {
    if (emTypeAnalysisItemProvider == null)
    {
      emTypeAnalysisItemProvider = new EMTypeAnalysisItemProvider(this);
    }

    return emTypeAnalysisItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.EMTypeApplicationEnvironment} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected EMTypeApplicationEnvironmentItemProvider emTypeApplicationEnvironmentItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.EMTypeApplicationEnvironment}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createEMTypeApplicationEnvironmentAdapter()
  {
    if (emTypeApplicationEnvironmentItemProvider == null)
    {
      emTypeApplicationEnvironmentItemProvider = new EMTypeApplicationEnvironmentItemProvider(this);
    }

    return emTypeApplicationEnvironmentItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.EMTypeBswModule} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected EMTypeBswModuleItemProvider emTypeBswModuleItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.EMTypeBswModule}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createEMTypeBswModuleAdapter()
  {
    if (emTypeBswModuleItemProvider == null)
    {
      emTypeBswModuleItemProvider = new EMTypeBswModuleItemProvider(this);
    }

    return emTypeBswModuleItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.EMTypeDesign} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected EMTypeDesignItemProvider emTypeDesignItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.EMTypeDesign}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createEMTypeDesignAdapter()
  {
    if (emTypeDesignItemProvider == null)
    {
      emTypeDesignItemProvider = new EMTypeDesignItemProvider(this);
    }

    return emTypeDesignItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.EMTypeHwComponent} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected EMTypeHwComponentItemProvider emTypeHwComponentItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.EMTypeHwComponent}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createEMTypeHwComponentAdapter()
  {
    if (emTypeHwComponentItemProvider == null)
    {
      emTypeHwComponentItemProvider = new EMTypeHwComponentItemProvider(this);
    }

    return emTypeHwComponentItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.EMTypeSwComponent} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected EMTypeSwComponentItemProvider emTypeSwComponentItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.EMTypeSwComponent}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createEMTypeSwComponentAdapter()
  {
    if (emTypeSwComponentItemProvider == null)
    {
      emTypeSwComponentItemProvider = new EMTypeSwComponentItemProvider(this);
    }

    return emTypeSwComponentItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ErrorModelPrototype} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ErrorModelPrototypeItemProvider errorModelPrototypeItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ErrorModelPrototype}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createErrorModelPrototypeAdapter()
  {
    if (errorModelPrototypeItemProvider == null)
    {
      errorModelPrototypeItemProvider = new ErrorModelPrototypeItemProvider(this);
    }

    return errorModelPrototypeItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ErrorModelType} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ErrorModelTypeItemProvider errorModelTypeItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ErrorModelType}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createErrorModelTypeAdapter()
  {
    if (errorModelTypeItemProvider == null)
    {
      errorModelTypeItemProvider = new ErrorModelTypeItemProvider(this);
    }

    return errorModelTypeItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.FaultFailurePropagationLink} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected FaultFailurePropagationLinkItemProvider faultFailurePropagationLinkItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.FaultFailurePropagationLink}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createFaultFailurePropagationLinkAdapter()
  {
    if (faultFailurePropagationLinkItemProvider == null)
    {
      faultFailurePropagationLinkItemProvider = new FaultFailurePropagationLinkItemProvider(this);
    }

    return faultFailurePropagationLinkItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.QuantitativeErrorModel} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected QuantitativeErrorModelItemProvider quantitativeErrorModelItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.QuantitativeErrorModel}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createQuantitativeErrorModelAdapter()
  {
    if (quantitativeErrorModelItemProvider == null)
    {
      quantitativeErrorModelItemProvider = new QuantitativeErrorModelItemProvider(this);
    }

    return quantitativeErrorModelItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MalfunctionPrototype} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MalfunctionPrototypeItemProvider malfunctionPrototypeItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MalfunctionPrototype}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMalfunctionPrototypeAdapter()
  {
    if (malfunctionPrototypeItemProvider == null)
    {
      malfunctionPrototypeItemProvider = new MalfunctionPrototypeItemProvider(this);
    }

    return malfunctionPrototypeItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MalfunctionType} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MalfunctionTypeItemProvider malfunctionTypeItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MalfunctionType}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMalfunctionTypeAdapter()
  {
    if (malfunctionTypeItemProvider == null)
    {
      malfunctionTypeItemProvider = new MalfunctionTypeItemProvider(this);
    }

    return malfunctionTypeItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MFPFunctionPort} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MFPFunctionPortItemProvider mfpFunctionPortItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MFPFunctionPort}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMFPFunctionPortAdapter()
  {
    if (mfpFunctionPortItemProvider == null)
    {
      mfpFunctionPortItemProvider = new MFPFunctionPortItemProvider(this);
    }

    return mfpFunctionPortItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MFPHardwarePin} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MFPHardwarePinItemProvider mfpHardwarePinItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MFPHardwarePin}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMFPHardwarePinAdapter()
  {
    if (mfpHardwarePinItemProvider == null)
    {
      mfpHardwarePinItemProvider = new MFPHardwarePinItemProvider(this);
    }

    return mfpHardwarePinItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MFPHardwarePort} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MFPHardwarePortItemProvider mfpHardwarePortItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MFPHardwarePort}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMFPHardwarePortAdapter()
  {
    if (mfpHardwarePortItemProvider == null)
    {
      mfpHardwarePortItemProvider = new MFPHardwarePortItemProvider(this);
    }

    return mfpHardwarePortItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MFPOperation} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MFPOperationItemProvider mfpOperationItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MFPOperation}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMFPOperationAdapter()
  {
    if (mfpOperationItemProvider == null)
    {
      mfpOperationItemProvider = new MFPOperationItemProvider(this);
    }

    return mfpOperationItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MFPSwcPort} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MFPSwcPortItemProvider mfpSwcPortItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MFPSwcPort}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMFPSwcPortAdapter()
  {
    if (mfpSwcPortItemProvider == null)
    {
      mfpSwcPortItemProvider = new MFPSwcPortItemProvider(this);
    }

    return mfpSwcPortItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MFPVariable} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MFPVariableItemProvider mfpVariableItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MFPVariable}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMFPVariableAdapter()
  {
    if (mfpVariableItemProvider == null)
    {
      mfpVariableItemProvider = new MFPVariableItemProvider(this);
    }

    return mfpVariableItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MTComposite} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MTCompositeItemProvider mtCompositeItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MTComposite}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMTCompositeAdapter()
  {
    if (mtCompositeItemProvider == null)
    {
      mtCompositeItemProvider = new MTCompositeItemProvider(this);
    }

    return mtCompositeItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MTCompositeElementPrototype} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MTCompositeElementPrototypeItemProvider mtCompositeElementPrototypeItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MTCompositeElementPrototype}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMTCompositeElementPrototypeAdapter()
  {
    if (mtCompositeElementPrototypeItemProvider == null)
    {
      mtCompositeElementPrototypeItemProvider = new MTCompositeElementPrototypeItemProvider(this);
    }

    return mtCompositeElementPrototypeItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MTPrimitive} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MTPrimitiveItemProvider mtPrimitiveItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MTPrimitive}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMTPrimitiveAdapter()
  {
    if (mtPrimitiveItemProvider == null)
    {
      mtPrimitiveItemProvider = new MTPrimitiveItemProvider(this);
    }

    return mtPrimitiveItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ErrorBehaviorMapping} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ErrorBehaviorMappingItemProvider errorBehaviorMappingItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ErrorBehaviorMapping}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createErrorBehaviorMappingAdapter()
  {
    if (errorBehaviorMappingItemProvider == null)
    {
      errorBehaviorMappingItemProvider = new ErrorBehaviorMappingItemProvider(this);
    }

    return errorBehaviorMappingItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ErrorModelMapping} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ErrorModelMappingItemProvider errorModelMappingItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ErrorModelMapping}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createErrorModelMappingAdapter()
  {
    if (errorModelMappingItemProvider == null)
    {
      errorModelMappingItemProvider = new ErrorModelMappingItemProvider(this);
    }

    return errorModelMappingItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MalfunctionMapping} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MalfunctionMappingItemProvider malfunctionMappingItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MalfunctionMapping}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMalfunctionMappingAdapter()
  {
    if (malfunctionMappingItemProvider == null)
    {
      malfunctionMappingItemProvider = new MalfunctionMappingItemProvider(this);
    }

    return malfunctionMappingItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWFailureClassContributionFormula} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWFailureClassContributionFormulaItemProvider hwFailureClassContributionFormulaItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWFailureClassContributionFormula}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWFailureClassContributionFormulaAdapter()
  {
    if (hwFailureClassContributionFormulaItemProvider == null)
    {
      hwFailureClassContributionFormulaItemProvider = new HWFailureClassContributionFormulaItemProvider(this);
    }

    return hwFailureClassContributionFormulaItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWFMSingleContributionFormula} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWFMSingleContributionFormulaItemProvider hwfmSingleContributionFormulaItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWFMSingleContributionFormula}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWFMSingleContributionFormulaAdapter()
  {
    if (hwfmSingleContributionFormulaItemProvider == null)
    {
      hwfmSingleContributionFormulaItemProvider = new HWFMSingleContributionFormulaItemProvider(this);
    }

    return hwfmSingleContributionFormulaItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWLambdaPartFormula} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWLambdaPartFormulaItemProvider hwLambdaPartFormulaItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWLambdaPartFormula}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWLambdaPartFormulaAdapter()
  {
    if (hwLambdaPartFormulaItemProvider == null)
    {
      hwLambdaPartFormulaItemProvider = new HWLambdaPartFormulaItemProvider(this);
    }

    return hwLambdaPartFormulaItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWLatentFaultMetricFormula} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWLatentFaultMetricFormulaItemProvider hwLatentFaultMetricFormulaItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWLatentFaultMetricFormula}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWLatentFaultMetricFormulaAdapter()
  {
    if (hwLatentFaultMetricFormulaItemProvider == null)
    {
      hwLatentFaultMetricFormulaItemProvider = new HWLatentFaultMetricFormulaItemProvider(this);
    }

    return hwLatentFaultMetricFormulaItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWPMHFFormula} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWPMHFFormulaItemProvider hwpmhfFormulaItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWPMHFFormula}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWPMHFFormulaAdapter()
  {
    if (hwpmhfFormulaItemProvider == null)
    {
      hwpmhfFormulaItemProvider = new HWPMHFFormulaItemProvider(this);
    }

    return hwpmhfFormulaItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWSinglePointFaultMetricFormula} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWSinglePointFaultMetricFormulaItemProvider hwSinglePointFaultMetricFormulaItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWSinglePointFaultMetricFormula}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWSinglePointFaultMetricFormulaAdapter()
  {
    if (hwSinglePointFaultMetricFormulaItemProvider == null)
    {
      hwSinglePointFaultMetricFormulaItemProvider = new HWSinglePointFaultMetricFormulaItemProvider(this);
    }

    return hwSinglePointFaultMetricFormulaItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HardwareFailureAnalysis} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HardwareFailureAnalysisItemProvider hardwareFailureAnalysisItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HardwareFailureAnalysis}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHardwareFailureAnalysisAdapter()
  {
    if (hardwareFailureAnalysisItemProvider == null)
    {
      hardwareFailureAnalysisItemProvider = new HardwareFailureAnalysisItemProvider(this);
    }

    return hardwareFailureAnalysisItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWFailureRate} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWFailureRateItemProvider hwFailureRateItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWFailureRate}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWFailureRateAdapter()
  {
    if (hwFailureRateItemProvider == null)
    {
      hwFailureRateItemProvider = new HWFailureRateItemProvider(this);
    }

    return hwFailureRateItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWFailureMode} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWFailureModeItemProvider hwFailureModeItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWFailureMode}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWFailureModeAdapter()
  {
    if (hwFailureModeItemProvider == null)
    {
      hwFailureModeItemProvider = new HWFailureModeItemProvider(this);
    }

    return hwFailureModeItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWFault} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWFaultItemProvider hwFaultItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWFault}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWFaultAdapter()
  {
    if (hwFaultItemProvider == null)
    {
      hwFaultItemProvider = new HWFaultItemProvider(this);
    }

    return hwFaultItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWComponentPrototypeScope} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWComponentPrototypeScopeItemProvider hwComponentPrototypeScopeItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWComponentPrototypeScope}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWComponentPrototypeScopeAdapter()
  {
    if (hwComponentPrototypeScopeItemProvider == null)
    {
      hwComponentPrototypeScopeItemProvider = new HWComponentPrototypeScopeItemProvider(this);
    }

    return hwComponentPrototypeScopeItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HwComponentScopeInstanceRef} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HwComponentScopeInstanceRefItemProvider hwComponentScopeInstanceRefItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HwComponentScopeInstanceRef}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHwComponentScopeInstanceRefAdapter()
  {
    if (hwComponentScopeInstanceRefItemProvider == null)
    {
      hwComponentScopeInstanceRefItemProvider = new HwComponentScopeInstanceRefItemProvider(this);
    }

    return hwComponentScopeInstanceRefItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWComponentQuantifiedFMFromPart} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWComponentQuantifiedFMFromPartItemProvider hwComponentQuantifiedFMFromPartItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWComponentQuantifiedFMFromPart}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWComponentQuantifiedFMFromPartAdapter()
  {
    if (hwComponentQuantifiedFMFromPartItemProvider == null)
    {
      hwComponentQuantifiedFMFromPartItemProvider = new HWComponentQuantifiedFMFromPartItemProvider(this);
    }

    return hwComponentQuantifiedFMFromPartItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWElementPrototypeScope} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWElementPrototypeScopeItemProvider hwElementPrototypeScopeItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWElementPrototypeScope}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWElementPrototypeScopeAdapter()
  {
    if (hwElementPrototypeScopeItemProvider == null)
    {
      hwElementPrototypeScopeItemProvider = new HWElementPrototypeScopeItemProvider(this);
    }

    return hwElementPrototypeScopeItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWPartFailure} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWPartFailureItemProvider hwPartFailureItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWPartFailure}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWPartFailureAdapter()
  {
    if (hwPartFailureItemProvider == null)
    {
      hwPartFailureItemProvider = new HWPartFailureItemProvider(this);
    }

    return hwPartFailureItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWPartFailureAnalysis} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWPartFailureAnalysisItemProvider hwPartFailureAnalysisItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWPartFailureAnalysis}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWPartFailureAnalysisAdapter()
  {
    if (hwPartFailureAnalysisItemProvider == null)
    {
      hwPartFailureAnalysisItemProvider = new HWPartFailureAnalysisItemProvider(this);
    }

    return hwPartFailureAnalysisItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWPartFailureMode} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWPartFailureModeItemProvider hwPartFailureModeItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWPartFailureMode}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWPartFailureModeAdapter()
  {
    if (hwPartFailureModeItemProvider == null)
    {
      hwPartFailureModeItemProvider = new HWPartFailureModeItemProvider(this);
    }

    return hwPartFailureModeItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWPartFailureRate} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWPartFailureRateItemProvider hwPartFailureRateItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWPartFailureRate}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWPartFailureRateAdapter()
  {
    if (hwPartFailureRateItemProvider == null)
    {
      hwPartFailureRateItemProvider = new HWPartFailureRateItemProvider(this);
    }

    return hwPartFailureRateItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWElementScopeInstanceRef} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWElementScopeInstanceRefItemProvider hwElementScopeInstanceRefItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWElementScopeInstanceRef}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWElementScopeInstanceRefAdapter()
  {
    if (hwElementScopeInstanceRefItemProvider == null)
    {
      hwElementScopeInstanceRefItemProvider = new HWElementScopeInstanceRefItemProvider(this);
    }

    return hwElementScopeInstanceRefItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWFMSingleContribution} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWFMSingleContributionItemProvider hwfmSingleContributionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWFMSingleContribution}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWFMSingleContributionAdapter()
  {
    if (hwfmSingleContributionItemProvider == null)
    {
      hwfmSingleContributionItemProvider = new HWFMSingleContributionItemProvider(this);
    }

    return hwfmSingleContributionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWQuantitativeFailureAnalysis} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWQuantitativeFailureAnalysisItemProvider hwQuantitativeFailureAnalysisItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWQuantitativeFailureAnalysis}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWQuantitativeFailureAnalysisAdapter()
  {
    if (hwQuantitativeFailureAnalysisItemProvider == null)
    {
      hwQuantitativeFailureAnalysisItemProvider = new HWQuantitativeFailureAnalysisItemProvider(this);
    }

    return hwQuantitativeFailureAnalysisItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWLatentFaultMetric} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWLatentFaultMetricItemProvider hwLatentFaultMetricItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWLatentFaultMetric}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWLatentFaultMetricAdapter()
  {
    if (hwLatentFaultMetricItemProvider == null)
    {
      hwLatentFaultMetricItemProvider = new HWLatentFaultMetricItemProvider(this);
    }

    return hwLatentFaultMetricItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWSinglePointFaultMetric} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWSinglePointFaultMetricItemProvider hwSinglePointFaultMetricItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWSinglePointFaultMetric}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWSinglePointFaultMetricAdapter()
  {
    if (hwSinglePointFaultMetricItemProvider == null)
    {
      hwSinglePointFaultMetricItemProvider = new HWSinglePointFaultMetricItemProvider(this);
    }

    return hwSinglePointFaultMetricItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWElementFailureRateClass} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWElementFailureRateClassItemProvider hwElementFailureRateClassItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWElementFailureRateClass}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWElementFailureRateClassAdapter()
  {
    if (hwElementFailureRateClassItemProvider == null)
    {
      hwElementFailureRateClassItemProvider = new HWElementFailureRateClassItemProvider(this);
    }

    return hwElementFailureRateClassItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWFailureClassContainer} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWFailureClassContainerItemProvider hwFailureClassContainerItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWFailureClassContainer}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWFailureClassContainerAdapter()
  {
    if (hwFailureClassContainerItemProvider == null)
    {
      hwFailureClassContainerItemProvider = new HWFailureClassContainerItemProvider(this);
    }

    return hwFailureClassContainerItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HWPMHF} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HWPMHFItemProvider hwpmhfItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HWPMHF}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHWPMHFAdapter()
  {
    if (hwpmhfItemProvider == null)
    {
      hwpmhfItemProvider = new HWPMHFItemProvider(this);
    }

    return hwpmhfItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Actor} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ActorItemProvider actorItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Actor}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createActorAdapter()
  {
    if (actorItemProvider == null)
    {
      actorItemProvider = new ActorItemProvider(this);
    }

    return actorItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ControllabilityReference} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ControllabilityReferenceItemProvider controllabilityReferenceItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ControllabilityReference}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createControllabilityReferenceAdapter()
  {
    if (controllabilityReferenceItemProvider == null)
    {
      controllabilityReferenceItemProvider = new ControllabilityReferenceItemProvider(this);
    }

    return controllabilityReferenceItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Hazard} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HazardItemProvider hazardItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Hazard}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHazardAdapter()
  {
    if (hazardItemProvider == null)
    {
      hazardItemProvider = new HazardItemProvider(this);
    }

    return hazardItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HazardousEvent} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HazardousEventItemProvider hazardousEventItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HazardousEvent}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHazardousEventAdapter()
  {
    if (hazardousEventItemProvider == null)
    {
      hazardousEventItemProvider = new HazardousEventItemProvider(this);
    }

    return hazardousEventItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Item} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ItemItemProvider itemItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Item}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createItemAdapter()
  {
    if (itemItemProvider == null)
    {
      itemItemProvider = new ItemItemProvider(this);
    }

    return itemItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ItemFunctionDescription} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ItemFunctionDescriptionItemProvider itemFunctionDescriptionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ItemFunctionDescription}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createItemFunctionDescriptionAdapter()
  {
    if (itemFunctionDescriptionItemProvider == null)
    {
      itemFunctionDescriptionItemProvider = new ItemFunctionDescriptionItemProvider(this);
    }

    return itemFunctionDescriptionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.OperatingMode} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected OperatingModeItemProvider operatingModeItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.OperatingMode}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createOperatingModeAdapter()
  {
    if (operatingModeItemProvider == null)
    {
      operatingModeItemProvider = new OperatingModeItemProvider(this);
    }

    return operatingModeItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.OperationalSituation} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected OperationalSituationItemProvider operationalSituationItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.OperationalSituation}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createOperationalSituationAdapter()
  {
    if (operationalSituationItemProvider == null)
    {
      operationalSituationItemProvider = new OperationalSituationItemProvider(this);
    }

    return operationalSituationItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.RiskDescription} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected RiskDescriptionItemProvider riskDescriptionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.RiskDescription}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createRiskDescriptionAdapter()
  {
    if (riskDescriptionItemProvider == null)
    {
      riskDescriptionItemProvider = new RiskDescriptionItemProvider(this);
    }

    return riskDescriptionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.SafeState} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected SafeStateItemProvider safeStateItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.SafeState}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createSafeStateAdapter()
  {
    if (safeStateItemProvider == null)
    {
      safeStateItemProvider = new SafeStateItemProvider(this);
    }

    return safeStateItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AllocationTargets} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AllocationTargetsItemProvider allocationTargetsItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AllocationTargets}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAllocationTargetsAdapter()
  {
    if (allocationTargetsItemProvider == null)
    {
      allocationTargetsItemProvider = new AllocationTargetsItemProvider(this);
    }

    return allocationTargetsItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.FunctionalSafetyRequirement} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected FunctionalSafetyRequirementItemProvider functionalSafetyRequirementItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.FunctionalSafetyRequirement}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createFunctionalSafetyRequirementAdapter()
  {
    if (functionalSafetyRequirementItemProvider == null)
    {
      functionalSafetyRequirementItemProvider = new FunctionalSafetyRequirementItemProvider(this);
    }

    return functionalSafetyRequirementItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HardwareSafetyRequirement} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HardwareSafetyRequirementItemProvider hardwareSafetyRequirementItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HardwareSafetyRequirement}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHardwareSafetyRequirementAdapter()
  {
    if (hardwareSafetyRequirementItemProvider == null)
    {
      hardwareSafetyRequirementItemProvider = new HardwareSafetyRequirementItemProvider(this);
    }

    return hardwareSafetyRequirementItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.QuantifiedDiagnosticCoverageProperty} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected QuantifiedDiagnosticCoveragePropertyItemProvider quantifiedDiagnosticCoveragePropertyItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.QuantifiedDiagnosticCoverageProperty}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createQuantifiedDiagnosticCoveragePropertyAdapter()
  {
    if (quantifiedDiagnosticCoveragePropertyItemProvider == null)
    {
      quantifiedDiagnosticCoveragePropertyItemProvider = new QuantifiedDiagnosticCoveragePropertyItemProvider(this);
    }

    return quantifiedDiagnosticCoveragePropertyItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.QuantifiedHWProperty} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected QuantifiedHWPropertyItemProvider quantifiedHWPropertyItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.QuantifiedHWProperty}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createQuantifiedHWPropertyAdapter()
  {
    if (quantifiedHWPropertyItemProvider == null)
    {
      quantifiedHWPropertyItemProvider = new QuantifiedHWPropertyItemProvider(this);
    }

    return quantifiedHWPropertyItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.RequirementsLink} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected RequirementsLinkItemProvider requirementsLinkItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.RequirementsLink}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createRequirementsLinkAdapter()
  {
    if (requirementsLinkItemProvider == null)
    {
      requirementsLinkItemProvider = new RequirementsLinkItemProvider(this);
    }

    return requirementsLinkItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.SafetyConcept} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected SafetyConceptItemProvider safetyConceptItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.SafetyConcept}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createSafetyConceptAdapter()
  {
    if (safetyConceptItemProvider == null)
    {
      safetyConceptItemProvider = new SafetyConceptItemProvider(this);
    }

    return safetyConceptItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Satisfy} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected SatisfyItemProvider satisfyItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Satisfy}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createSatisfyAdapter()
  {
    if (satisfyItemProvider == null)
    {
      satisfyItemProvider = new SatisfyItemProvider(this);
    }

    return satisfyItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.SoftwareSafetyRequirement} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected SoftwareSafetyRequirementItemProvider softwareSafetyRequirementItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.SoftwareSafetyRequirement}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createSoftwareSafetyRequirementAdapter()
  {
    if (softwareSafetyRequirementItemProvider == null)
    {
      softwareSafetyRequirementItemProvider = new SoftwareSafetyRequirementItemProvider(this);
    }

    return softwareSafetyRequirementItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.TechnicalSafetyRequirement} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected TechnicalSafetyRequirementItemProvider technicalSafetyRequirementItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.TechnicalSafetyRequirement}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createTechnicalSafetyRequirementAdapter()
  {
    if (technicalSafetyRequirementItemProvider == null)
    {
      technicalSafetyRequirementItemProvider = new TechnicalSafetyRequirementItemProvider(this);
    }

    return technicalSafetyRequirementItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Verify} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected VerifyItemProvider verifyItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Verify}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createVerifyAdapter()
  {
    if (verifyItemProvider == null)
    {
      verifyItemProvider = new VerifyItemProvider(this);
    }

    return verifyItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.WarningAndDegradation} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected WarningAndDegradationItemProvider warningAndDegradationItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.WarningAndDegradation}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createWarningAndDegradationAdapter()
  {
    if (warningAndDegradationItemProvider == null)
    {
      warningAndDegradationItemProvider = new WarningAndDegradationItemProvider(this);
    }

    return warningAndDegradationItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.WarningAndDegradationHandle} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected WarningAndDegradationHandleItemProvider warningAndDegradationHandleItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.WarningAndDegradationHandle}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createWarningAndDegradationHandleAdapter()
  {
    if (warningAndDegradationHandleItemProvider == null)
    {
      warningAndDegradationHandleItemProvider = new WarningAndDegradationHandleItemProvider(this);
    }

    return warningAndDegradationHandleItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Assumption} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AssumptionItemProvider assumptionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Assumption}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAssumptionAdapter()
  {
    if (assumptionItemProvider == null)
    {
      assumptionItemProvider = new AssumptionItemProvider(this);
    }

    return assumptionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Context} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ContextItemProvider contextItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Context}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createContextAdapter()
  {
    if (contextItemProvider == null)
    {
      contextItemProvider = new ContextItemProvider(this);
    }

    return contextItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Goal} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected GoalItemProvider goalItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Goal}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createGoalAdapter()
  {
    if (goalItemProvider == null)
    {
      goalItemProvider = new GoalItemProvider(this);
    }

    return goalItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Justification} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected JustificationItemProvider justificationItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Justification}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createJustificationAdapter()
  {
    if (justificationItemProvider == null)
    {
      justificationItemProvider = new JustificationItemProvider(this);
    }

    return justificationItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.SafetyCase} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected SafetyCaseItemProvider safetyCaseItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.SafetyCase}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createSafetyCaseAdapter()
  {
    if (safetyCaseItemProvider == null)
    {
      safetyCaseItemProvider = new SafetyCaseItemProvider(this);
    }

    return safetyCaseItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Solution} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected SolutionItemProvider solutionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Solution}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createSolutionAdapter()
  {
    if (solutionItemProvider == null)
    {
      solutionItemProvider = new SolutionItemProvider(this);
    }

    return solutionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Strategy} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected StrategyItemProvider strategyItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Strategy}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createStrategyAdapter()
  {
    if (strategyItemProvider == null)
    {
      strategyItemProvider = new StrategyItemProvider(this);
    }

    return strategyItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AnalysisReport} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AnalysisReportItemProvider analysisReportItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AnalysisReport}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAnalysisReportAdapter()
  {
    if (analysisReportItemProvider == null)
    {
      analysisReportItemProvider = new AnalysisReportItemProvider(this);
    }

    return analysisReportItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.DesignSpecification} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected DesignSpecificationItemProvider designSpecificationItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.DesignSpecification}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createDesignSpecificationAdapter()
  {
    if (designSpecificationItemProvider == null)
    {
      designSpecificationItemProvider = new DesignSpecificationItemProvider(this);
    }

    return designSpecificationItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.FieldTestProtocol} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected FieldTestProtocolItemProvider fieldTestProtocolItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.FieldTestProtocol}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createFieldTestProtocolAdapter()
  {
    if (fieldTestProtocolItemProvider == null)
    {
      fieldTestProtocolItemProvider = new FieldTestProtocolItemProvider(this);
    }

    return fieldTestProtocolItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.FMEAReport} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected FMEAReportItemProvider fmeaReportItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.FMEAReport}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createFMEAReportAdapter()
  {
    if (fmeaReportItemProvider == null)
    {
      fmeaReportItemProvider = new FMEAReportItemProvider(this);
    }

    return fmeaReportItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.TestProtocol} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected TestProtocolItemProvider testProtocolItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.TestProtocol}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createTestProtocolAdapter()
  {
    if (testProtocolItemProvider == null)
    {
      testProtocolItemProvider = new TestProtocolItemProvider(this);
    }

    return testProtocolItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.UnitTestProtocol} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected UnitTestProtocolItemProvider unitTestProtocolItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.UnitTestProtocol}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createUnitTestProtocolAdapter()
  {
    if (unitTestProtocolItemProvider == null)
    {
      unitTestProtocolItemProvider = new UnitTestProtocolItemProvider(this);
    }

    return unitTestProtocolItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Avoid} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AvoidItemProvider avoidItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Avoid}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAvoidAdapter()
  {
    if (avoidItemProvider == null)
    {
      avoidItemProvider = new AvoidItemProvider(this);
    }

    return avoidItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Detect} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected DetectItemProvider detectItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Detect}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createDetectAdapter()
  {
    if (detectItemProvider == null)
    {
      detectItemProvider = new DetectItemProvider(this);
    }

    return detectItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Handle} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HandleItemProvider handleItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Handle}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHandleAdapter()
  {
    if (handleItemProvider == null)
    {
      handleItemProvider = new HandleItemProvider(this);
    }

    return handleItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AUTOSARRunnableEntitySequenceConstraint} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AUTOSARRunnableEntitySequenceConstraintItemProvider autosarRunnableEntitySequenceConstraintItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AUTOSARRunnableEntitySequenceConstraint}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAUTOSARRunnableEntitySequenceConstraintAdapter()
  {
    if (autosarRunnableEntitySequenceConstraintItemProvider == null)
    {
      autosarRunnableEntitySequenceConstraintItemProvider = new AUTOSARRunnableEntitySequenceConstraintItemProvider(this);
    }

    return autosarRunnableEntitySequenceConstraintItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AUTOSARSequenceConstraint} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AUTOSARSequenceConstraintItemProvider autosarSequenceConstraintItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AUTOSARSequenceConstraint}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAUTOSARSequenceConstraintAdapter()
  {
    if (autosarSequenceConstraintItemProvider == null)
    {
      autosarSequenceConstraintItemProvider = new AUTOSARSequenceConstraintItemProvider(this);
    }

    return autosarSequenceConstraintItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ControlFlowError} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ControlFlowErrorItemProvider controlFlowErrorItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ControlFlowError}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createControlFlowErrorAdapter()
  {
    if (controlFlowErrorItemProvider == null)
    {
      controlFlowErrorItemProvider = new ControlFlowErrorItemProvider(this);
    }

    return controlFlowErrorItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ControlFlowErrorDetection} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ControlFlowErrorDetectionItemProvider controlFlowErrorDetectionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ControlFlowErrorDetection}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createControlFlowErrorDetectionAdapter()
  {
    if (controlFlowErrorDetectionItemProvider == null)
    {
      controlFlowErrorDetectionItemProvider = new ControlFlowErrorDetectionItemProvider(this);
    }

    return controlFlowErrorDetectionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ControlFlowMonitor} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ControlFlowMonitorItemProvider controlFlowMonitorItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ControlFlowMonitor}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createControlFlowMonitorAdapter()
  {
    if (controlFlowMonitorItemProvider == null)
    {
      controlFlowMonitorItemProvider = new ControlFlowMonitorItemProvider(this);
    }

    return controlFlowMonitorItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.InputBlock} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected InputBlockItemProvider inputBlockItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.InputBlock}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createInputBlockAdapter()
  {
    if (inputBlockItemProvider == null)
    {
      inputBlockItemProvider = new InputBlockItemProvider(this);
    }

    return inputBlockItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.OutputBlock} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected OutputBlockItemProvider outputBlockItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.OutputBlock}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createOutputBlockAdapter()
  {
    if (outputBlockItemProvider == null)
    {
      outputBlockItemProvider = new OutputBlockItemProvider(this);
    }

    return outputBlockItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.RunnableEntitySequenceElement} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected RunnableEntitySequenceElementItemProvider runnableEntitySequenceElementItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.RunnableEntitySequenceElement}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createRunnableEntitySequenceElementAdapter()
  {
    if (runnableEntitySequenceElementItemProvider == null)
    {
      runnableEntitySequenceElementItemProvider = new RunnableEntitySequenceElementItemProvider(this);
    }

    return runnableEntitySequenceElementItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AlivenessCheckpointTooEarly} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AlivenessCheckpointTooEarlyItemProvider alivenessCheckpointTooEarlyItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AlivenessCheckpointTooEarly}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAlivenessCheckpointTooEarlyAdapter()
  {
    if (alivenessCheckpointTooEarlyItemProvider == null)
    {
      alivenessCheckpointTooEarlyItemProvider = new AlivenessCheckpointTooEarlyItemProvider(this);
    }

    return alivenessCheckpointTooEarlyItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AlivenessCheckpointTooLate} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AlivenessCheckpointTooLateItemProvider alivenessCheckpointTooLateItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AlivenessCheckpointTooLate}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAlivenessCheckpointTooLateAdapter()
  {
    if (alivenessCheckpointTooLateItemProvider == null)
    {
      alivenessCheckpointTooLateItemProvider = new AlivenessCheckpointTooLateItemProvider(this);
    }

    return alivenessCheckpointTooLateItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AlivenessCheckpointTooOften} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AlivenessCheckpointTooOftenItemProvider alivenessCheckpointTooOftenItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AlivenessCheckpointTooOften}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAlivenessCheckpointTooOftenAdapter()
  {
    if (alivenessCheckpointTooOftenItemProvider == null)
    {
      alivenessCheckpointTooOftenItemProvider = new AlivenessCheckpointTooOftenItemProvider(this);
    }

    return alivenessCheckpointTooOftenItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AlivenessMonitor} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AlivenessMonitorItemProvider alivenessMonitorItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AlivenessMonitor}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAlivenessMonitorAdapter()
  {
    if (alivenessMonitorItemProvider == null)
    {
      alivenessMonitorItemProvider = new AlivenessMonitorItemProvider(this);
    }

    return alivenessMonitorItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarAlivenessMonitor} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarAlivenessMonitorItemProvider autosarAlivenessMonitorItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarAlivenessMonitor}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarAlivenessMonitorAdapter()
  {
    if (autosarAlivenessMonitorItemProvider == null)
    {
      autosarAlivenessMonitorItemProvider = new AutosarAlivenessMonitorItemProvider(this);
    }

    return autosarAlivenessMonitorItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarCheckPoint} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarCheckPointItemProvider autosarCheckPointItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarCheckPoint}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarCheckPointAdapter()
  {
    if (autosarCheckPointItemProvider == null)
    {
      autosarCheckPointItemProvider = new AutosarCheckPointItemProvider(this);
    }

    return autosarCheckPointItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.CheckPoint} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected CheckPointItemProvider checkPointItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.CheckPoint}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createCheckPointAdapter()
  {
    if (checkPointItemProvider == null)
    {
      checkPointItemProvider = new CheckPointItemProvider(this);
    }

    return checkPointItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.SoftwareAlivenessDetection} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected SoftwareAlivenessDetectionItemProvider softwareAlivenessDetectionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.SoftwareAlivenessDetection}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createSoftwareAlivenessDetectionAdapter()
  {
    if (softwareAlivenessDetectionItemProvider == null)
    {
      softwareAlivenessDetectionItemProvider = new SoftwareAlivenessDetectionItemProvider(this);
    }

    return softwareAlivenessDetectionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ActuatorError} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ActuatorErrorItemProvider actuatorErrorItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ActuatorError}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createActuatorErrorAdapter()
  {
    if (actuatorErrorItemProvider == null)
    {
      actuatorErrorItemProvider = new ActuatorErrorItemProvider(this);
    }

    return actuatorErrorItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ActuatorErrorDetection} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ActuatorErrorDetectionItemProvider actuatorErrorDetectionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ActuatorErrorDetection}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createActuatorErrorDetectionAdapter()
  {
    if (actuatorErrorDetectionItemProvider == null)
    {
      actuatorErrorDetectionItemProvider = new ActuatorErrorDetectionItemProvider(this);
    }

    return actuatorErrorDetectionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ActuatorMonitor} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ActuatorMonitorItemProvider actuatorMonitorItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ActuatorMonitor}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createActuatorMonitorAdapter()
  {
    if (actuatorMonitorItemProvider == null)
    {
      actuatorMonitorItemProvider = new ActuatorMonitorItemProvider(this);
    }

    return actuatorMonitorItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarActuatorMonitor} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarActuatorMonitorItemProvider autosarActuatorMonitorItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarActuatorMonitor}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarActuatorMonitorAdapter()
  {
    if (autosarActuatorMonitorItemProvider == null)
    {
      autosarActuatorMonitorItemProvider = new AutosarActuatorMonitorItemProvider(this);
    }

    return autosarActuatorMonitorItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarEvaluationFunction} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarEvaluationFunctionItemProvider autosarEvaluationFunctionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarEvaluationFunction}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarEvaluationFunctionAdapter()
  {
    if (autosarEvaluationFunctionItemProvider == null)
    {
      autosarEvaluationFunctionItemProvider = new AutosarEvaluationFunctionItemProvider(this);
    }

    return autosarEvaluationFunctionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.EvaluationFunction} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected EvaluationFunctionItemProvider evaluationFunctionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.EvaluationFunction}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createEvaluationFunctionAdapter()
  {
    if (evaluationFunctionItemProvider == null)
    {
      evaluationFunctionItemProvider = new EvaluationFunctionItemProvider(this);
    }

    return evaluationFunctionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarCRC} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarCRCItemProvider autosarCRCItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarCRC}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarCRCAdapter()
  {
    if (autosarCRCItemProvider == null)
    {
      autosarCRCItemProvider = new AutosarCRCItemProvider(this);
    }

    return autosarCRCItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ComponentPrototypeCRC} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ComponentPrototypeCRCItemProvider componentPrototypeCRCItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ComponentPrototypeCRC}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createComponentPrototypeCRCAdapter()
  {
    if (componentPrototypeCRCItemProvider == null)
    {
      componentPrototypeCRCItemProvider = new ComponentPrototypeCRCItemProvider(this);
    }

    return componentPrototypeCRCItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.CRC} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected CRCItemProvider crcItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.CRC}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createCRCAdapter()
  {
    if (crcItemProvider == null)
    {
      crcItemProvider = new CRCItemProvider(this);
    }

    return crcItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.CRCConfig} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected CRCConfigItemProvider crcConfigItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.CRCConfig}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createCRCConfigAdapter()
  {
    if (crcConfigItemProvider == null)
    {
      crcConfigItemProvider = new CRCConfigItemProvider(this);
    }

    return crcConfigItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.CRCErrorDetection} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected CRCErrorDetectionItemProvider crcErrorDetectionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.CRCErrorDetection}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createCRCErrorDetectionAdapter()
  {
    if (crcErrorDetectionItemProvider == null)
    {
      crcErrorDetectionItemProvider = new CRCErrorDetectionItemProvider(this);
    }

    return crcErrorDetectionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.CRCFailed} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected CRCFailedItemProvider crcFailedItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.CRCFailed}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createCRCFailedAdapter()
  {
    if (crcFailedItemProvider == null)
    {
      crcFailedItemProvider = new CRCFailedItemProvider(this);
    }

    return crcFailedItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.InterfaceCRC} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected InterfaceCRCItemProvider interfaceCRCItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.InterfaceCRC}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createInterfaceCRCAdapter()
  {
    if (interfaceCRCItemProvider == null)
    {
      interfaceCRCItemProvider = new InterfaceCRCItemProvider(this);
    }

    return interfaceCRCItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarComparison} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarComparisonItemProvider autosarComparisonItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarComparison}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarComparisonAdapter()
  {
    if (autosarComparisonItemProvider == null)
    {
      autosarComparisonItemProvider = new AutosarComparisonItemProvider(this);
    }

    return autosarComparisonItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarComparisonParam} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarComparisonParamItemProvider autosarComparisonParamItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarComparisonParam}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarComparisonParamAdapter()
  {
    if (autosarComparisonParamItemProvider == null)
    {
      autosarComparisonParamItemProvider = new AutosarComparisonParamItemProvider(this);
    }

    return autosarComparisonParamItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ChromosomeComparison} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ChromosomeComparisonItemProvider chromosomeComparisonItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ChromosomeComparison}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createChromosomeComparisonAdapter()
  {
    if (chromosomeComparisonItemProvider == null)
    {
      chromosomeComparisonItemProvider = new ChromosomeComparisonItemProvider(this);
    }

    return chromosomeComparisonItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ChromosomeComparisonParameter} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ChromosomeComparisonParameterItemProvider chromosomeComparisonParameterItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ChromosomeComparisonParameter}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createChromosomeComparisonParameterAdapter()
  {
    if (chromosomeComparisonParameterItemProvider == null)
    {
      chromosomeComparisonParameterItemProvider = new ChromosomeComparisonParameterItemProvider(this);
    }

    return chromosomeComparisonParameterItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Comparison} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ComparisonItemProvider comparisonItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Comparison}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createComparisonAdapter()
  {
    if (comparisonItemProvider == null)
    {
      comparisonItemProvider = new ComparisonItemProvider(this);
    }

    return comparisonItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ComparisonDetection} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ComparisonDetectionItemProvider comparisonDetectionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ComparisonDetection}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createComparisonDetectionAdapter()
  {
    if (comparisonDetectionItemProvider == null)
    {
      comparisonDetectionItemProvider = new ComparisonDetectionItemProvider(this);
    }

    return comparisonDetectionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ComparisonFalse} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ComparisonFalseItemProvider comparisonFalseItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ComparisonFalse}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createComparisonFalseAdapter()
  {
    if (comparisonFalseItemProvider == null)
    {
      comparisonFalseItemProvider = new ComparisonFalseItemProvider(this);
    }

    return comparisonFalseItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ComparisonParameter} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ComparisonParameterItemProvider comparisonParameterItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ComparisonParameter}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createComparisonParameterAdapter()
  {
    if (comparisonParameterItemProvider == null)
    {
      comparisonParameterItemProvider = new ComparisonParameterItemProvider(this);
    }

    return comparisonParameterItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ComparisonTrue} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ComparisonTrueItemProvider comparisonTrueItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ComparisonTrue}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createComparisonTrueAdapter()
  {
    if (comparisonTrueItemProvider == null)
    {
      comparisonTrueItemProvider = new ComparisonTrueItemProvider(this);
    }

    return comparisonTrueItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ConstantComparisonParameter} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ConstantComparisonParameterItemProvider constantComparisonParameterItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ConstantComparisonParameter}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createConstantComparisonParameterAdapter()
  {
    if (constantComparisonParameterItemProvider == null)
    {
      constantComparisonParameterItemProvider = new ConstantComparisonParameterItemProvider(this);
    }

    return constantComparisonParameterItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarContext} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarContextItemProvider autosarContextItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarContext}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarContextAdapter()
  {
    if (autosarContextItemProvider == null)
    {
      autosarContextItemProvider = new AutosarContextItemProvider(this);
    }

    return autosarContextItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarContextRangeCheck} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarContextRangeCheckItemProvider autosarContextRangeCheckItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarContextRangeCheck}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarContextRangeCheckAdapter()
  {
    if (autosarContextRangeCheckItemProvider == null)
    {
      autosarContextRangeCheckItemProvider = new AutosarContextRangeCheckItemProvider(this);
    }

    return autosarContextRangeCheckItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ContextParameter} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ContextParameterItemProvider contextParameterItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ContextParameter}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createContextParameterAdapter()
  {
    if (contextParameterItemProvider == null)
    {
      contextParameterItemProvider = new ContextParameterItemProvider(this);
    }

    return contextParameterItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ContextRangeCheck} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ContextRangeCheckItemProvider contextRangeCheckItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ContextRangeCheck}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createContextRangeCheckAdapter()
  {
    if (contextRangeCheckItemProvider == null)
    {
      contextRangeCheckItemProvider = new ContextRangeCheckItemProvider(this);
    }

    return contextRangeCheckItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ContextRangeCheckDetection} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ContextRangeCheckDetectionItemProvider contextRangeCheckDetectionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ContextRangeCheckDetection}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createContextRangeCheckDetectionAdapter()
  {
    if (contextRangeCheckDetectionItemProvider == null)
    {
      contextRangeCheckDetectionItemProvider = new ContextRangeCheckDetectionItemProvider(this);
    }

    return contextRangeCheckDetectionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.RangeCheckContext} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected RangeCheckContextItemProvider rangeCheckContextItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.RangeCheckContext}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createRangeCheckContextAdapter()
  {
    if (rangeCheckContextItemProvider == null)
    {
      rangeCheckContextItemProvider = new RangeCheckContextItemProvider(this);
    }

    return rangeCheckContextItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ValueAboveRange} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ValueAboveRangeItemProvider valueAboveRangeItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ValueAboveRange}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createValueAboveRangeAdapter()
  {
    if (valueAboveRangeItemProvider == null)
    {
      valueAboveRangeItemProvider = new ValueAboveRangeItemProvider(this);
    }

    return valueAboveRangeItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ValueBelowRange} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ValueBelowRangeItemProvider valueBelowRangeItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ValueBelowRange}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createValueBelowRangeAdapter()
  {
    if (valueBelowRangeItemProvider == null)
    {
      valueBelowRangeItemProvider = new ValueBelowRangeItemProvider(this);
    }

    return valueBelowRangeItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ChromosomeCpuSelfTest} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ChromosomeCpuSelfTestItemProvider chromosomeCpuSelfTestItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ChromosomeCpuSelfTest}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createChromosomeCpuSelfTestAdapter()
  {
    if (chromosomeCpuSelfTestItemProvider == null)
    {
      chromosomeCpuSelfTestItemProvider = new ChromosomeCpuSelfTestItemProvider(this);
    }

    return chromosomeCpuSelfTestItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.CpuSelfTest} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected CpuSelfTestItemProvider cpuSelfTestItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.CpuSelfTest}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createCpuSelfTestAdapter()
  {
    if (cpuSelfTestItemProvider == null)
    {
      cpuSelfTestItemProvider = new CpuSelfTestItemProvider(this);
    }

    return cpuSelfTestItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.CpuSelfTestConfig} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected CpuSelfTestConfigItemProvider cpuSelfTestConfigItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.CpuSelfTestConfig}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createCpuSelfTestConfigAdapter()
  {
    if (cpuSelfTestConfigItemProvider == null)
    {
      cpuSelfTestConfigItemProvider = new CpuSelfTestConfigItemProvider(this);
    }

    return cpuSelfTestConfigItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.CpuSelfTestDetection} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected CpuSelfTestDetectionItemProvider cpuSelfTestDetectionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.CpuSelfTestDetection}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createCpuSelfTestDetectionAdapter()
  {
    if (cpuSelfTestDetectionItemProvider == null)
    {
      cpuSelfTestDetectionItemProvider = new CpuSelfTestDetectionItemProvider(this);
    }

    return cpuSelfTestDetectionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.CpuSelfTestFailed} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected CpuSelfTestFailedItemProvider cpuSelfTestFailedItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.CpuSelfTestFailed}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createCpuSelfTestFailedAdapter()
  {
    if (cpuSelfTestFailedItemProvider == null)
    {
      cpuSelfTestFailedItemProvider = new CpuSelfTestFailedItemProvider(this);
    }

    return cpuSelfTestFailedItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Filter} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected FilterItemProvider filterItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Filter}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createFilterAdapter()
  {
    if (filterItemProvider == null)
    {
      filterItemProvider = new FilterItemProvider(this);
    }

    return filterItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.FilterBasedHandling} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected FilterBasedHandlingItemProvider filterBasedHandlingItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.FilterBasedHandling}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createFilterBasedHandlingAdapter()
  {
    if (filterBasedHandlingItemProvider == null)
    {
      filterBasedHandlingItemProvider = new FilterBasedHandlingItemProvider(this);
    }

    return filterBasedHandlingItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.FilterError} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected FilterErrorItemProvider filterErrorItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.FilterError}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createFilterErrorAdapter()
  {
    if (filterErrorItemProvider == null)
    {
      filterErrorItemProvider = new FilterErrorItemProvider(this);
    }

    return filterErrorItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.FilterParameter} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected FilterParameterItemProvider filterParameterItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.FilterParameter}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createFilterParameterAdapter()
  {
    if (filterParameterItemProvider == null)
    {
      filterParameterItemProvider = new FilterParameterItemProvider(this);
    }

    return filterParameterItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.AutosarGradientCheck} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected AutosarGradientCheckItemProvider autosarGradientCheckItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.AutosarGradientCheck}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createAutosarGradientCheckAdapter()
  {
    if (autosarGradientCheckItemProvider == null)
    {
      autosarGradientCheckItemProvider = new AutosarGradientCheckItemProvider(this);
    }

    return autosarGradientCheckItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.GradientCheck} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected GradientCheckItemProvider gradientCheckItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.GradientCheck}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createGradientCheckAdapter()
  {
    if (gradientCheckItemProvider == null)
    {
      gradientCheckItemProvider = new GradientCheckItemProvider(this);
    }

    return gradientCheckItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.GradientCheckDetection} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected GradientCheckDetectionItemProvider gradientCheckDetectionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.GradientCheckDetection}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createGradientCheckDetectionAdapter()
  {
    if (gradientCheckDetectionItemProvider == null)
    {
      gradientCheckDetectionItemProvider = new GradientCheckDetectionItemProvider(this);
    }

    return gradientCheckDetectionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.GradientTooHigh} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected GradientTooHighItemProvider gradientTooHighItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.GradientTooHigh}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createGradientTooHighAdapter()
  {
    if (gradientTooHighItemProvider == null)
    {
      gradientTooHighItemProvider = new GradientTooHighItemProvider(this);
    }

    return gradientTooHighItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.GradientTooLow} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected GradientTooLowItemProvider gradientTooLowItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.GradientTooLow}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createGradientTooLowAdapter()
  {
    if (gradientTooLowItemProvider == null)
    {
      gradientTooLowItemProvider = new GradientTooLowItemProvider(this);
    }

    return gradientTooLowItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ChromosomeApplicationHealthMonitor} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ChromosomeApplicationHealthMonitorItemProvider chromosomeApplicationHealthMonitorItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ChromosomeApplicationHealthMonitor}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createChromosomeApplicationHealthMonitorAdapter()
  {
    if (chromosomeApplicationHealthMonitorItemProvider == null)
    {
      chromosomeApplicationHealthMonitorItemProvider = new ChromosomeApplicationHealthMonitorItemProvider(this);
    }

    return chromosomeApplicationHealthMonitorItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ChromosomeComponentModeCondition} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ChromosomeComponentModeConditionItemProvider chromosomeComponentModeConditionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ChromosomeComponentModeCondition}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createChromosomeComponentModeConditionAdapter()
  {
    if (chromosomeComponentModeConditionItemProvider == null)
    {
      chromosomeComponentModeConditionItemProvider = new ChromosomeComponentModeConditionItemProvider(this);
    }

    return chromosomeComponentModeConditionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ChromosomeErrorEventCondition} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ChromosomeErrorEventConditionItemProvider chromosomeErrorEventConditionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ChromosomeErrorEventCondition}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createChromosomeErrorEventConditionAdapter()
  {
    if (chromosomeErrorEventConditionItemProvider == null)
    {
      chromosomeErrorEventConditionItemProvider = new ChromosomeErrorEventConditionItemProvider(this);
    }

    return chromosomeErrorEventConditionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ChromosomeErrorHandler} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ChromosomeErrorHandlerItemProvider chromosomeErrorHandlerItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ChromosomeErrorHandler}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createChromosomeErrorHandlerAdapter()
  {
    if (chromosomeErrorHandlerItemProvider == null)
    {
      chromosomeErrorHandlerItemProvider = new ChromosomeErrorHandlerItemProvider(this);
    }

    return chromosomeErrorHandlerItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ChromosomeHealthMonitor} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ChromosomeHealthMonitorItemProvider chromosomeHealthMonitorItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ChromosomeHealthMonitor}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createChromosomeHealthMonitorAdapter()
  {
    if (chromosomeHealthMonitorItemProvider == null)
    {
      chromosomeHealthMonitorItemProvider = new ChromosomeHealthMonitorItemProvider(this);
    }

    return chromosomeHealthMonitorItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.CHROMOSOMEHealthMonitorNotification} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected CHROMOSOMEHealthMonitorNotificationItemProvider chromosomeHealthMonitorNotificationItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.CHROMOSOMEHealthMonitorNotification}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createCHROMOSOMEHealthMonitorNotificationAdapter()
  {
    if (chromosomeHealthMonitorNotificationItemProvider == null)
    {
      chromosomeHealthMonitorNotificationItemProvider = new CHROMOSOMEHealthMonitorNotificationItemProvider(this);
    }

    return chromosomeHealthMonitorNotificationItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ChromosomeNodeHealthMonitor} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ChromosomeNodeHealthMonitorItemProvider chromosomeNodeHealthMonitorItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ChromosomeNodeHealthMonitor}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createChromosomeNodeHealthMonitorAdapter()
  {
    if (chromosomeNodeHealthMonitorItemProvider == null)
    {
      chromosomeNodeHealthMonitorItemProvider = new ChromosomeNodeHealthMonitorItemProvider(this);
    }

    return chromosomeNodeHealthMonitorItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HealthMonitor} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HealthMonitorItemProvider healthMonitorItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HealthMonitor}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHealthMonitorAdapter()
  {
    if (healthMonitorItemProvider == null)
    {
      healthMonitorItemProvider = new HealthMonitorItemProvider(this);
    }

    return healthMonitorItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HealthMonitorErrorCondition} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HealthMonitorErrorConditionItemProvider healthMonitorErrorConditionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HealthMonitorErrorCondition}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHealthMonitorErrorConditionAdapter()
  {
    if (healthMonitorErrorConditionItemProvider == null)
    {
      healthMonitorErrorConditionItemProvider = new HealthMonitorErrorConditionItemProvider(this);
    }

    return healthMonitorErrorConditionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HealthMonitoring} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HealthMonitoringItemProvider healthMonitoringItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HealthMonitoring}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHealthMonitoringAdapter()
  {
    if (healthMonitoringItemProvider == null)
    {
      healthMonitoringItemProvider = new HealthMonitoringItemProvider(this);
    }

    return healthMonitoringItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ChromosomeHeartbeatReceiver} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ChromosomeHeartbeatReceiverItemProvider chromosomeHeartbeatReceiverItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ChromosomeHeartbeatReceiver}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createChromosomeHeartbeatReceiverAdapter()
  {
    if (chromosomeHeartbeatReceiverItemProvider == null)
    {
      chromosomeHeartbeatReceiverItemProvider = new ChromosomeHeartbeatReceiverItemProvider(this);
    }

    return chromosomeHeartbeatReceiverItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ChromosomeHeartbeatSender} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ChromosomeHeartbeatSenderItemProvider chromosomeHeartbeatSenderItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ChromosomeHeartbeatSender}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createChromosomeHeartbeatSenderAdapter()
  {
    if (chromosomeHeartbeatSenderItemProvider == null)
    {
      chromosomeHeartbeatSenderItemProvider = new ChromosomeHeartbeatSenderItemProvider(this);
    }

    return chromosomeHeartbeatSenderItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Heartbeat} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HeartbeatItemProvider heartbeatItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Heartbeat}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHeartbeatAdapter()
  {
    if (heartbeatItemProvider == null)
    {
      heartbeatItemProvider = new HeartbeatItemProvider(this);
    }

    return heartbeatItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HeartbeatConfig} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HeartbeatConfigItemProvider heartbeatConfigItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HeartbeatConfig}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHeartbeatConfigAdapter()
  {
    if (heartbeatConfigItemProvider == null)
    {
      heartbeatConfigItemProvider = new HeartbeatConfigItemProvider(this);
    }

    return heartbeatConfigItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HeartBeatDeadlineMissed} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HeartBeatDeadlineMissedItemProvider heartBeatDeadlineMissedItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HeartBeatDeadlineMissed}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHeartBeatDeadlineMissedAdapter()
  {
    if (heartBeatDeadlineMissedItemProvider == null)
    {
      heartBeatDeadlineMissedItemProvider = new HeartBeatDeadlineMissedItemProvider(this);
    }

    return heartBeatDeadlineMissedItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HeartBeatDetection} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HeartBeatDetectionItemProvider heartBeatDetectionItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HeartBeatDetection}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHeartBeatDetectionAdapter()
  {
    if (heartBeatDetectionItemProvider == null)
    {
      heartBeatDetectionItemProvider = new HeartBeatDetectionItemProvider(this);
    }

    return heartBeatDetectionItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HeartbeatReceiver} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HeartbeatReceiverItemProvider heartbeatReceiverItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HeartbeatReceiver}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHeartbeatReceiverAdapter()
  {
    if (heartbeatReceiverItemProvider == null)
    {
      heartbeatReceiverItemProvider = new HeartbeatReceiverItemProvider(this);
    }

    return heartbeatReceiverItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HeartbeatSender} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HeartbeatSenderItemProvider heartbeatSenderItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HeartbeatSender}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHeartbeatSenderAdapter()
  {
    if (heartbeatSenderItemProvider == null)
    {
      heartbeatSenderItemProvider = new HeartbeatSenderItemProvider(this);
    }

    return heartbeatSenderItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ChromosomeMemoryTest} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ChromosomeMemoryTestItemProvider chromosomeMemoryTestItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ChromosomeMemoryTest}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createChromosomeMemoryTestAdapter()
  {
    if (chromosomeMemoryTestItemProvider == null)
    {
      chromosomeMemoryTestItemProvider = new ChromosomeMemoryTestItemProvider(this);
    }

    return chromosomeMemoryTestItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MemoryRange} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MemoryRangeItemProvider memoryRangeItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MemoryRange}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMemoryRangeAdapter()
  {
    if (memoryRangeItemProvider == null)
    {
      memoryRangeItemProvider = new MemoryRangeItemProvider(this);
    }

    return memoryRangeItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MemorySelfTest} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MemorySelfTestItemProvider memorySelfTestItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MemorySelfTest}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMemorySelfTestAdapter()
  {
    if (memorySelfTestItemProvider == null)
    {
      memorySelfTestItemProvider = new MemorySelfTestItemProvider(this);
    }

    return memorySelfTestItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MemorySelfTestConfig} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MemorySelfTestConfigItemProvider memorySelfTestConfigItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MemorySelfTestConfig}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMemorySelfTestConfigAdapter()
  {
    if (memorySelfTestConfigItemProvider == null)
    {
      memorySelfTestConfigItemProvider = new MemorySelfTestConfigItemProvider(this);
    }

    return memorySelfTestConfigItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MemorySelfTestFailed} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MemorySelfTestFailedItemProvider memorySelfTestFailedItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MemorySelfTestFailed}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMemorySelfTestFailedAdapter()
  {
    if (memorySelfTestFailedItemProvider == null)
    {
      memorySelfTestFailedItemProvider = new MemorySelfTestFailedItemProvider(this);
    }

    return memorySelfTestFailedItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.MemorySelfTesting} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected MemorySelfTestingItemProvider memorySelfTestingItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.MemorySelfTesting}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createMemorySelfTestingAdapter()
  {
    if (memorySelfTestingItemProvider == null)
    {
      memorySelfTestingItemProvider = new MemorySelfTestingItemProvider(this);
    }

    return memorySelfTestingItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ChromosomeVoter} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ChromosomeVoterItemProvider chromosomeVoterItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ChromosomeVoter}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createChromosomeVoterAdapter()
  {
    if (chromosomeVoterItemProvider == null)
    {
      chromosomeVoterItemProvider = new ChromosomeVoterItemProvider(this);
    }

    return chromosomeVoterItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ChromosomeVoterParameter} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ChromosomeVoterParameterItemProvider chromosomeVoterParameterItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ChromosomeVoterParameter}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createChromosomeVoterParameterAdapter()
  {
    if (chromosomeVoterParameterItemProvider == null)
    {
      chromosomeVoterParameterItemProvider = new ChromosomeVoterParameterItemProvider(this);
    }

    return chromosomeVoterParameterItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Voter} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected VoterItemProvider voterItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Voter}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createVoterAdapter()
  {
    if (voterItemProvider == null)
    {
      voterItemProvider = new VoterItemProvider(this);
    }

    return voterItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.VoterConfig} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected VoterConfigItemProvider voterConfigItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.VoterConfig}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createVoterConfigAdapter()
  {
    if (voterConfigItemProvider == null)
    {
      voterConfigItemProvider = new VoterConfigItemProvider(this);
    }

    return voterConfigItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.VoterNoConsensus} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected VoterNoConsensusItemProvider voterNoConsensusItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.VoterNoConsensus}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createVoterNoConsensusAdapter()
  {
    if (voterNoConsensusItemProvider == null)
    {
      voterNoConsensusItemProvider = new VoterNoConsensusItemProvider(this);
    }

    return voterNoConsensusItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.VoterParameter} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected VoterParameterItemProvider voterParameterItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.VoterParameter}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createVoterParameterAdapter()
  {
    if (voterParameterItemProvider == null)
    {
      voterParameterItemProvider = new VoterParameterItemProvider(this);
    }

    return voterParameterItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.VoterValueMismatch} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected VoterValueMismatchItemProvider voterValueMismatchItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.VoterValueMismatch}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createVoterValueMismatchAdapter()
  {
    if (voterValueMismatchItemProvider == null)
    {
      voterValueMismatchItemProvider = new VoterValueMismatchItemProvider(this);
    }

    return voterValueMismatchItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.Voting} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected VotingItemProvider votingItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.Voting}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createVotingAdapter()
  {
    if (votingItemProvider == null)
    {
      votingItemProvider = new VotingItemProvider(this);
    }

    return votingItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.BooleanConfigParameterValue} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected BooleanConfigParameterValueItemProvider booleanConfigParameterValueItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.BooleanConfigParameterValue}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createBooleanConfigParameterValueAdapter()
  {
    if (booleanConfigParameterValueItemProvider == null)
    {
      booleanConfigParameterValueItemProvider = new BooleanConfigParameterValueItemProvider(this);
    }

    return booleanConfigParameterValueItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.CodeGenerationConfiguration} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected CodeGenerationConfigurationItemProvider codeGenerationConfigurationItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.CodeGenerationConfiguration}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createCodeGenerationConfigurationAdapter()
  {
    if (codeGenerationConfigurationItemProvider == null)
    {
      codeGenerationConfigurationItemProvider = new CodeGenerationConfigurationItemProvider(this);
    }

    return codeGenerationConfigurationItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ConfigParameter} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ConfigParameterItemProvider configParameterItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ConfigParameter}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createConfigParameterAdapter()
  {
    if (configParameterItemProvider == null)
    {
      configParameterItemProvider = new ConfigParameterItemProvider(this);
    }

    return configParameterItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.ConfigParameterValue} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected ConfigParameterValueItemProvider configParameterValueItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.ConfigParameterValue}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createConfigParameterValueAdapter()
  {
    if (configParameterValueItemProvider == null)
    {
      configParameterValueItemProvider = new ConfigParameterValueItemProvider(this);
    }

    return configParameterValueItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.FloatConfigParameterValue} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected FloatConfigParameterValueItemProvider floatConfigParameterValueItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.FloatConfigParameterValue}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createFloatConfigParameterValueAdapter()
  {
    if (floatConfigParameterValueItemProvider == null)
    {
      floatConfigParameterValueItemProvider = new FloatConfigParameterValueItemProvider(this);
    }

    return floatConfigParameterValueItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.IdentifierConfigParameterValue} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected IdentifierConfigParameterValueItemProvider identifierConfigParameterValueItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.IdentifierConfigParameterValue}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createIdentifierConfigParameterValueAdapter()
  {
    if (identifierConfigParameterValueItemProvider == null)
    {
      identifierConfigParameterValueItemProvider = new IdentifierConfigParameterValueItemProvider(this);
    }

    return identifierConfigParameterValueItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.IntegerConfigParameterValue} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected IntegerConfigParameterValueItemProvider integerConfigParameterValueItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.IntegerConfigParameterValue}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createIntegerConfigParameterValueAdapter()
  {
    if (integerConfigParameterValueItemProvider == null)
    {
      integerConfigParameterValueItemProvider = new IntegerConfigParameterValueItemProvider(this);
    }

    return integerConfigParameterValueItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.StringConfigParameterValue} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected StringConfigParameterValueItemProvider stringConfigParameterValueItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.StringConfigParameterValue}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createStringConfigParameterValueAdapter()
  {
    if (stringConfigParameterValueItemProvider == null)
    {
      stringConfigParameterValueItemProvider = new StringConfigParameterValueItemProvider(this);
    }

    return stringConfigParameterValueItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HardwareSoftwareInterfaceElement} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HardwareSoftwareInterfaceElementItemProvider hardwareSoftwareInterfaceElementItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HardwareSoftwareInterfaceElement}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHardwareSoftwareInterfaceElementAdapter()
  {
    if (hardwareSoftwareInterfaceElementItemProvider == null)
    {
      hardwareSoftwareInterfaceElementItemProvider = new HardwareSoftwareInterfaceElementItemProvider(this);
    }

    return hardwareSoftwareInterfaceElementItemProvider;
  }

  /**
   * This keeps track of the one adapter used for all {@link org.safe.metamodel.safe10.HardwareSoftwareInterfaceSpecification} instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected HardwareSoftwareInterfaceSpecificationItemProvider hardwareSoftwareInterfaceSpecificationItemProvider;

  /**
   * This creates an adapter for a {@link org.safe.metamodel.safe10.HardwareSoftwareInterfaceSpecification}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter createHardwareSoftwareInterfaceSpecificationAdapter()
  {
    if (hardwareSoftwareInterfaceSpecificationItemProvider == null)
    {
      hardwareSoftwareInterfaceSpecificationItemProvider = new HardwareSoftwareInterfaceSpecificationItemProvider(this);
    }

    return hardwareSoftwareInterfaceSpecificationItemProvider;
  }

  /**
   * This returns the root adapter factory that contains this factory.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public ComposeableAdapterFactory getRootAdapterFactory()
  {
    return parentAdapterFactory == null ? this : parentAdapterFactory.getRootAdapterFactory();
  }

  /**
   * This sets the composed adapter factory that contains this factory.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public void setParentAdapterFactory(ComposedAdapterFactory parentAdapterFactory)
  {
    this.parentAdapterFactory = parentAdapterFactory;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public boolean isFactoryForType(Object type)
  {
    return supportedTypes.contains(type) || super.isFactoryForType(type);
  }

  /**
   * This implementation substitutes the factory itself as the key for the adapter.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Adapter adapt(Notifier notifier, Object type)
  {
    return super.adapt(notifier, this);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public Object adapt(Object object, Object type)
  {
    if (isFactoryForType(type))
    {
      Object adapter = super.adapt(object, type);
      if (!(type instanceof Class<?>) || (((Class<?>)type).isInstance(adapter)))
      {
        return adapter;
      }
    }

    return null;
  }

  /**
   * This adds a listener.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public void addListener(INotifyChangedListener notifyChangedListener)
  {
    changeNotifier.addListener(notifyChangedListener);
  }

  /**
   * This removes a listener.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public void removeListener(INotifyChangedListener notifyChangedListener)
  {
    changeNotifier.removeListener(notifyChangedListener);
  }

  /**
   * This delegates to {@link #changeNotifier} and to {@link #parentAdapterFactory}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public void fireNotifyChanged(Notification notification)
  {
    changeNotifier.fireNotifyChanged(notification);

    if (parentAdapterFactory != null)
    {
      parentAdapterFactory.fireNotifyChanged(notification);
    }
  }

  /**
   * This disposes all of the item providers created by this factory. 
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public void dispose()
  {
    if (filterExpressionItemProvider != null) filterExpressionItemProvider.dispose();
    if (applicationItemProvider != null) applicationItemProvider.dispose();
    if (componentItemProvider != null) componentItemProvider.dispose();
    if (componentModeInstanceRefItemProvider != null) componentModeInstanceRefItemProvider.dispose();
    if (nodeItemProvider != null) nodeItemProvider.dispose();
    if (systemItemProvider != null) systemItemProvider.dispose();
    if (topicItemProvider != null) topicItemProvider.dispose();
    if (multiLevelSafetyExtensionItemProvider != null) multiLevelSafetyExtensionItemProvider.dispose();
    if (functionalSafetyExtensionItemProvider != null) functionalSafetyExtensionItemProvider.dispose();
    if (hazardandRiskSafetyExtensionItemProvider != null) hazardandRiskSafetyExtensionItemProvider.dispose();
    if (autosarHardwareSafetyExtensionItemProvider != null) autosarHardwareSafetyExtensionItemProvider.dispose();
    if (autosarSystemSafetyExtensionItemProvider != null) autosarSystemSafetyExtensionItemProvider.dispose();
    if (autosarVfbSafetyExtensionItemProvider != null) autosarVfbSafetyExtensionItemProvider.dispose();
    if (chromosomeApplicationSafetyExtensionItemProvider != null) chromosomeApplicationSafetyExtensionItemProvider.dispose();
    if (chromosomeSystemSafetyExtensionItemProvider != null) chromosomeSystemSafetyExtensionItemProvider.dispose();
    if (implementationSafetyExtensionItemProvider != null) implementationSafetyExtensionItemProvider.dispose();
    if (designLevelSafetyExtensionItemProvider != null) designLevelSafetyExtensionItemProvider.dispose();
    if (hardwareSafetyExtensionItemProvider != null) hardwareSafetyExtensionItemProvider.dispose();
    if (softwareSafetyExtensionItemProvider != null) softwareSafetyExtensionItemProvider.dispose();
    if (safeItemProvider != null) safeItemProvider.dispose();
    if (safePackageItemProvider != null) safePackageItemProvider.dispose();
    if (autosarClientServerOperationInstanceRefItemProvider != null) autosarClientServerOperationInstanceRefItemProvider.dispose();
    if (autosarComponentInCompositionInstanceRefItemProvider != null) autosarComponentInCompositionInstanceRefItemProvider.dispose();
    if (autosarModeInPortFromComponentInCompositionInstanceRefItemProvider != null) autosarModeInPortFromComponentInCompositionInstanceRefItemProvider.dispose();
    if (autosarPortInCompositionInstanceRefItemProvider != null) autosarPortInCompositionInstanceRefItemProvider.dispose();
    if (autosarUndefinedInstanceRefItemProvider != null) autosarUndefinedInstanceRefItemProvider.dispose();
    if (autosarVariableDataPrototypeInstanceRefItemProvider != null) autosarVariableDataPrototypeInstanceRefItemProvider.dispose();
    if (restrictableItemProvider != null) restrictableItemProvider.dispose();
    if (restrictionItemProvider != null) restrictionItemProvider.dispose();
    if (variantItemProvider != null) variantItemProvider.dispose();
    if (errorModelItemProvider != null) errorModelItemProvider.dispose();
    if (errorModelInstanceRefItemProvider != null) errorModelInstanceRefItemProvider.dispose();
    if (errorModelPrototype_analysisFunctionTargetItemProvider != null) errorModelPrototype_analysisFunctionTargetItemProvider.dispose();
    if (errorModelPrototype_designFunctionTargetItemProvider != null) errorModelPrototype_designFunctionTargetItemProvider.dispose();
    if (errorModelPrototype_hwTargetItemProvider != null) errorModelPrototype_hwTargetItemProvider.dispose();
    if (faultFailurePort_functionTargetItemProvider != null) faultFailurePort_functionTargetItemProvider.dispose();
    if (faultFailurePort_hwPinTargetItemProvider != null) faultFailurePort_hwPinTargetItemProvider.dispose();
    if (faultFailurePort_hwPortTargetItemProvider != null) faultFailurePort_hwPortTargetItemProvider.dispose();
    if (malfunctionInstanceRefItemProvider != null) malfunctionInstanceRefItemProvider.dispose();
    if (eastADLErrorBehaviorItemProvider != null) eastADLErrorBehaviorItemProvider.dispose();
    if (failureLogicFormulaItemProvider != null) failureLogicFormulaItemProvider.dispose();
    if (nativeErrorBehaviorItemProvider != null) nativeErrorBehaviorItemProvider.dispose();
    if (empAnalysisItemProvider != null) empAnalysisItemProvider.dispose();
    if (empBswModuleItemProvider != null) empBswModuleItemProvider.dispose();
    if (empDesignItemProvider != null) empDesignItemProvider.dispose();
    if (empHwComponentItemProvider != null) empHwComponentItemProvider.dispose();
    if (empReferenceItemProvider != null) empReferenceItemProvider.dispose();
    if (empSwComponentItemProvider != null) empSwComponentItemProvider.dispose();
    if (emTypeAnalysisItemProvider != null) emTypeAnalysisItemProvider.dispose();
    if (emTypeApplicationEnvironmentItemProvider != null) emTypeApplicationEnvironmentItemProvider.dispose();
    if (emTypeBswModuleItemProvider != null) emTypeBswModuleItemProvider.dispose();
    if (emTypeDesignItemProvider != null) emTypeDesignItemProvider.dispose();
    if (emTypeHwComponentItemProvider != null) emTypeHwComponentItemProvider.dispose();
    if (emTypeSwComponentItemProvider != null) emTypeSwComponentItemProvider.dispose();
    if (errorModelPrototypeItemProvider != null) errorModelPrototypeItemProvider.dispose();
    if (errorModelTypeItemProvider != null) errorModelTypeItemProvider.dispose();
    if (faultFailurePropagationLinkItemProvider != null) faultFailurePropagationLinkItemProvider.dispose();
    if (quantitativeErrorModelItemProvider != null) quantitativeErrorModelItemProvider.dispose();
    if (malfunctionPrototypeItemProvider != null) malfunctionPrototypeItemProvider.dispose();
    if (malfunctionTypeItemProvider != null) malfunctionTypeItemProvider.dispose();
    if (mfpFunctionPortItemProvider != null) mfpFunctionPortItemProvider.dispose();
    if (mfpHardwarePinItemProvider != null) mfpHardwarePinItemProvider.dispose();
    if (mfpHardwarePortItemProvider != null) mfpHardwarePortItemProvider.dispose();
    if (mfpOperationItemProvider != null) mfpOperationItemProvider.dispose();
    if (mfpSwcPortItemProvider != null) mfpSwcPortItemProvider.dispose();
    if (mfpVariableItemProvider != null) mfpVariableItemProvider.dispose();
    if (mtCompositeItemProvider != null) mtCompositeItemProvider.dispose();
    if (mtCompositeElementPrototypeItemProvider != null) mtCompositeElementPrototypeItemProvider.dispose();
    if (mtPrimitiveItemProvider != null) mtPrimitiveItemProvider.dispose();
    if (errorBehaviorMappingItemProvider != null) errorBehaviorMappingItemProvider.dispose();
    if (errorModelMappingItemProvider != null) errorModelMappingItemProvider.dispose();
    if (malfunctionMappingItemProvider != null) malfunctionMappingItemProvider.dispose();
    if (hwFailureClassContributionFormulaItemProvider != null) hwFailureClassContributionFormulaItemProvider.dispose();
    if (hwfmSingleContributionFormulaItemProvider != null) hwfmSingleContributionFormulaItemProvider.dispose();
    if (hwLambdaPartFormulaItemProvider != null) hwLambdaPartFormulaItemProvider.dispose();
    if (hwLatentFaultMetricFormulaItemProvider != null) hwLatentFaultMetricFormulaItemProvider.dispose();
    if (hwpmhfFormulaItemProvider != null) hwpmhfFormulaItemProvider.dispose();
    if (hwSinglePointFaultMetricFormulaItemProvider != null) hwSinglePointFaultMetricFormulaItemProvider.dispose();
    if (hardwareFailureAnalysisItemProvider != null) hardwareFailureAnalysisItemProvider.dispose();
    if (hwFailureRateItemProvider != null) hwFailureRateItemProvider.dispose();
    if (hwFailureModeItemProvider != null) hwFailureModeItemProvider.dispose();
    if (hwFaultItemProvider != null) hwFaultItemProvider.dispose();
    if (hwComponentPrototypeScopeItemProvider != null) hwComponentPrototypeScopeItemProvider.dispose();
    if (hwComponentScopeInstanceRefItemProvider != null) hwComponentScopeInstanceRefItemProvider.dispose();
    if (hwComponentQuantifiedFMFromPartItemProvider != null) hwComponentQuantifiedFMFromPartItemProvider.dispose();
    if (hwElementPrototypeScopeItemProvider != null) hwElementPrototypeScopeItemProvider.dispose();
    if (hwPartFailureItemProvider != null) hwPartFailureItemProvider.dispose();
    if (hwPartFailureAnalysisItemProvider != null) hwPartFailureAnalysisItemProvider.dispose();
    if (hwPartFailureModeItemProvider != null) hwPartFailureModeItemProvider.dispose();
    if (hwPartFailureRateItemProvider != null) hwPartFailureRateItemProvider.dispose();
    if (hwElementScopeInstanceRefItemProvider != null) hwElementScopeInstanceRefItemProvider.dispose();
    if (hwfmSingleContributionItemProvider != null) hwfmSingleContributionItemProvider.dispose();
    if (hwQuantitativeFailureAnalysisItemProvider != null) hwQuantitativeFailureAnalysisItemProvider.dispose();
    if (hwLatentFaultMetricItemProvider != null) hwLatentFaultMetricItemProvider.dispose();
    if (hwSinglePointFaultMetricItemProvider != null) hwSinglePointFaultMetricItemProvider.dispose();
    if (hwElementFailureRateClassItemProvider != null) hwElementFailureRateClassItemProvider.dispose();
    if (hwFailureClassContainerItemProvider != null) hwFailureClassContainerItemProvider.dispose();
    if (hwpmhfItemProvider != null) hwpmhfItemProvider.dispose();
    if (actorItemProvider != null) actorItemProvider.dispose();
    if (controllabilityReferenceItemProvider != null) controllabilityReferenceItemProvider.dispose();
    if (hazardItemProvider != null) hazardItemProvider.dispose();
    if (hazardousEventItemProvider != null) hazardousEventItemProvider.dispose();
    if (itemItemProvider != null) itemItemProvider.dispose();
    if (itemFunctionDescriptionItemProvider != null) itemFunctionDescriptionItemProvider.dispose();
    if (operatingModeItemProvider != null) operatingModeItemProvider.dispose();
    if (operationalSituationItemProvider != null) operationalSituationItemProvider.dispose();
    if (riskDescriptionItemProvider != null) riskDescriptionItemProvider.dispose();
    if (safeStateItemProvider != null) safeStateItemProvider.dispose();
    if (allocationTargetsItemProvider != null) allocationTargetsItemProvider.dispose();
    if (functionalSafetyRequirementItemProvider != null) functionalSafetyRequirementItemProvider.dispose();
    if (hardwareSafetyRequirementItemProvider != null) hardwareSafetyRequirementItemProvider.dispose();
    if (quantifiedDiagnosticCoveragePropertyItemProvider != null) quantifiedDiagnosticCoveragePropertyItemProvider.dispose();
    if (quantifiedHWPropertyItemProvider != null) quantifiedHWPropertyItemProvider.dispose();
    if (requirementsLinkItemProvider != null) requirementsLinkItemProvider.dispose();
    if (safetyConceptItemProvider != null) safetyConceptItemProvider.dispose();
    if (satisfyItemProvider != null) satisfyItemProvider.dispose();
    if (softwareSafetyRequirementItemProvider != null) softwareSafetyRequirementItemProvider.dispose();
    if (technicalSafetyRequirementItemProvider != null) technicalSafetyRequirementItemProvider.dispose();
    if (verifyItemProvider != null) verifyItemProvider.dispose();
    if (warningAndDegradationItemProvider != null) warningAndDegradationItemProvider.dispose();
    if (warningAndDegradationHandleItemProvider != null) warningAndDegradationHandleItemProvider.dispose();
    if (assumptionItemProvider != null) assumptionItemProvider.dispose();
    if (contextItemProvider != null) contextItemProvider.dispose();
    if (goalItemProvider != null) goalItemProvider.dispose();
    if (justificationItemProvider != null) justificationItemProvider.dispose();
    if (safetyCaseItemProvider != null) safetyCaseItemProvider.dispose();
    if (solutionItemProvider != null) solutionItemProvider.dispose();
    if (strategyItemProvider != null) strategyItemProvider.dispose();
    if (analysisReportItemProvider != null) analysisReportItemProvider.dispose();
    if (designSpecificationItemProvider != null) designSpecificationItemProvider.dispose();
    if (fieldTestProtocolItemProvider != null) fieldTestProtocolItemProvider.dispose();
    if (fmeaReportItemProvider != null) fmeaReportItemProvider.dispose();
    if (testProtocolItemProvider != null) testProtocolItemProvider.dispose();
    if (unitTestProtocolItemProvider != null) unitTestProtocolItemProvider.dispose();
    if (avoidItemProvider != null) avoidItemProvider.dispose();
    if (detectItemProvider != null) detectItemProvider.dispose();
    if (handleItemProvider != null) handleItemProvider.dispose();
    if (autosarRunnableEntitySequenceConstraintItemProvider != null) autosarRunnableEntitySequenceConstraintItemProvider.dispose();
    if (autosarSequenceConstraintItemProvider != null) autosarSequenceConstraintItemProvider.dispose();
    if (controlFlowErrorItemProvider != null) controlFlowErrorItemProvider.dispose();
    if (controlFlowErrorDetectionItemProvider != null) controlFlowErrorDetectionItemProvider.dispose();
    if (controlFlowMonitorItemProvider != null) controlFlowMonitorItemProvider.dispose();
    if (inputBlockItemProvider != null) inputBlockItemProvider.dispose();
    if (outputBlockItemProvider != null) outputBlockItemProvider.dispose();
    if (runnableEntitySequenceElementItemProvider != null) runnableEntitySequenceElementItemProvider.dispose();
    if (alivenessCheckpointTooEarlyItemProvider != null) alivenessCheckpointTooEarlyItemProvider.dispose();
    if (alivenessCheckpointTooLateItemProvider != null) alivenessCheckpointTooLateItemProvider.dispose();
    if (alivenessCheckpointTooOftenItemProvider != null) alivenessCheckpointTooOftenItemProvider.dispose();
    if (alivenessMonitorItemProvider != null) alivenessMonitorItemProvider.dispose();
    if (autosarAlivenessMonitorItemProvider != null) autosarAlivenessMonitorItemProvider.dispose();
    if (autosarCheckPointItemProvider != null) autosarCheckPointItemProvider.dispose();
    if (checkPointItemProvider != null) checkPointItemProvider.dispose();
    if (softwareAlivenessDetectionItemProvider != null) softwareAlivenessDetectionItemProvider.dispose();
    if (actuatorErrorItemProvider != null) actuatorErrorItemProvider.dispose();
    if (actuatorErrorDetectionItemProvider != null) actuatorErrorDetectionItemProvider.dispose();
    if (actuatorMonitorItemProvider != null) actuatorMonitorItemProvider.dispose();
    if (autosarActuatorMonitorItemProvider != null) autosarActuatorMonitorItemProvider.dispose();
    if (autosarEvaluationFunctionItemProvider != null) autosarEvaluationFunctionItemProvider.dispose();
    if (evaluationFunctionItemProvider != null) evaluationFunctionItemProvider.dispose();
    if (autosarCRCItemProvider != null) autosarCRCItemProvider.dispose();
    if (componentPrototypeCRCItemProvider != null) componentPrototypeCRCItemProvider.dispose();
    if (crcItemProvider != null) crcItemProvider.dispose();
    if (crcConfigItemProvider != null) crcConfigItemProvider.dispose();
    if (crcErrorDetectionItemProvider != null) crcErrorDetectionItemProvider.dispose();
    if (crcFailedItemProvider != null) crcFailedItemProvider.dispose();
    if (interfaceCRCItemProvider != null) interfaceCRCItemProvider.dispose();
    if (autosarComparisonItemProvider != null) autosarComparisonItemProvider.dispose();
    if (autosarComparisonParamItemProvider != null) autosarComparisonParamItemProvider.dispose();
    if (chromosomeComparisonItemProvider != null) chromosomeComparisonItemProvider.dispose();
    if (chromosomeComparisonParameterItemProvider != null) chromosomeComparisonParameterItemProvider.dispose();
    if (comparisonItemProvider != null) comparisonItemProvider.dispose();
    if (comparisonDetectionItemProvider != null) comparisonDetectionItemProvider.dispose();
    if (comparisonFalseItemProvider != null) comparisonFalseItemProvider.dispose();
    if (comparisonParameterItemProvider != null) comparisonParameterItemProvider.dispose();
    if (comparisonTrueItemProvider != null) comparisonTrueItemProvider.dispose();
    if (constantComparisonParameterItemProvider != null) constantComparisonParameterItemProvider.dispose();
    if (autosarContextItemProvider != null) autosarContextItemProvider.dispose();
    if (autosarContextRangeCheckItemProvider != null) autosarContextRangeCheckItemProvider.dispose();
    if (contextParameterItemProvider != null) contextParameterItemProvider.dispose();
    if (contextRangeCheckItemProvider != null) contextRangeCheckItemProvider.dispose();
    if (contextRangeCheckDetectionItemProvider != null) contextRangeCheckDetectionItemProvider.dispose();
    if (rangeCheckContextItemProvider != null) rangeCheckContextItemProvider.dispose();
    if (valueAboveRangeItemProvider != null) valueAboveRangeItemProvider.dispose();
    if (valueBelowRangeItemProvider != null) valueBelowRangeItemProvider.dispose();
    if (chromosomeCpuSelfTestItemProvider != null) chromosomeCpuSelfTestItemProvider.dispose();
    if (cpuSelfTestItemProvider != null) cpuSelfTestItemProvider.dispose();
    if (cpuSelfTestConfigItemProvider != null) cpuSelfTestConfigItemProvider.dispose();
    if (cpuSelfTestDetectionItemProvider != null) cpuSelfTestDetectionItemProvider.dispose();
    if (cpuSelfTestFailedItemProvider != null) cpuSelfTestFailedItemProvider.dispose();
    if (filterItemProvider != null) filterItemProvider.dispose();
    if (filterBasedHandlingItemProvider != null) filterBasedHandlingItemProvider.dispose();
    if (filterErrorItemProvider != null) filterErrorItemProvider.dispose();
    if (filterParameterItemProvider != null) filterParameterItemProvider.dispose();
    if (autosarGradientCheckItemProvider != null) autosarGradientCheckItemProvider.dispose();
    if (gradientCheckItemProvider != null) gradientCheckItemProvider.dispose();
    if (gradientCheckDetectionItemProvider != null) gradientCheckDetectionItemProvider.dispose();
    if (gradientTooHighItemProvider != null) gradientTooHighItemProvider.dispose();
    if (gradientTooLowItemProvider != null) gradientTooLowItemProvider.dispose();
    if (chromosomeApplicationHealthMonitorItemProvider != null) chromosomeApplicationHealthMonitorItemProvider.dispose();
    if (chromosomeComponentModeConditionItemProvider != null) chromosomeComponentModeConditionItemProvider.dispose();
    if (chromosomeErrorEventConditionItemProvider != null) chromosomeErrorEventConditionItemProvider.dispose();
    if (chromosomeErrorHandlerItemProvider != null) chromosomeErrorHandlerItemProvider.dispose();
    if (chromosomeHealthMonitorItemProvider != null) chromosomeHealthMonitorItemProvider.dispose();
    if (chromosomeHealthMonitorNotificationItemProvider != null) chromosomeHealthMonitorNotificationItemProvider.dispose();
    if (chromosomeNodeHealthMonitorItemProvider != null) chromosomeNodeHealthMonitorItemProvider.dispose();
    if (healthMonitorItemProvider != null) healthMonitorItemProvider.dispose();
    if (healthMonitorErrorConditionItemProvider != null) healthMonitorErrorConditionItemProvider.dispose();
    if (healthMonitoringItemProvider != null) healthMonitoringItemProvider.dispose();
    if (chromosomeHeartbeatReceiverItemProvider != null) chromosomeHeartbeatReceiverItemProvider.dispose();
    if (chromosomeHeartbeatSenderItemProvider != null) chromosomeHeartbeatSenderItemProvider.dispose();
    if (heartbeatItemProvider != null) heartbeatItemProvider.dispose();
    if (heartbeatConfigItemProvider != null) heartbeatConfigItemProvider.dispose();
    if (heartBeatDeadlineMissedItemProvider != null) heartBeatDeadlineMissedItemProvider.dispose();
    if (heartBeatDetectionItemProvider != null) heartBeatDetectionItemProvider.dispose();
    if (heartbeatReceiverItemProvider != null) heartbeatReceiverItemProvider.dispose();
    if (heartbeatSenderItemProvider != null) heartbeatSenderItemProvider.dispose();
    if (chromosomeMemoryTestItemProvider != null) chromosomeMemoryTestItemProvider.dispose();
    if (memoryRangeItemProvider != null) memoryRangeItemProvider.dispose();
    if (memorySelfTestItemProvider != null) memorySelfTestItemProvider.dispose();
    if (memorySelfTestConfigItemProvider != null) memorySelfTestConfigItemProvider.dispose();
    if (memorySelfTestFailedItemProvider != null) memorySelfTestFailedItemProvider.dispose();
    if (memorySelfTestingItemProvider != null) memorySelfTestingItemProvider.dispose();
    if (chromosomeVoterItemProvider != null) chromosomeVoterItemProvider.dispose();
    if (chromosomeVoterParameterItemProvider != null) chromosomeVoterParameterItemProvider.dispose();
    if (voterItemProvider != null) voterItemProvider.dispose();
    if (voterConfigItemProvider != null) voterConfigItemProvider.dispose();
    if (voterNoConsensusItemProvider != null) voterNoConsensusItemProvider.dispose();
    if (voterParameterItemProvider != null) voterParameterItemProvider.dispose();
    if (voterValueMismatchItemProvider != null) voterValueMismatchItemProvider.dispose();
    if (votingItemProvider != null) votingItemProvider.dispose();
    if (booleanConfigParameterValueItemProvider != null) booleanConfigParameterValueItemProvider.dispose();
    if (codeGenerationConfigurationItemProvider != null) codeGenerationConfigurationItemProvider.dispose();
    if (configParameterItemProvider != null) configParameterItemProvider.dispose();
    if (configParameterValueItemProvider != null) configParameterValueItemProvider.dispose();
    if (floatConfigParameterValueItemProvider != null) floatConfigParameterValueItemProvider.dispose();
    if (identifierConfigParameterValueItemProvider != null) identifierConfigParameterValueItemProvider.dispose();
    if (integerConfigParameterValueItemProvider != null) integerConfigParameterValueItemProvider.dispose();
    if (stringConfigParameterValueItemProvider != null) stringConfigParameterValueItemProvider.dispose();
    if (hardwareSoftwareInterfaceElementItemProvider != null) hardwareSoftwareInterfaceElementItemProvider.dispose();
    if (hardwareSoftwareInterfaceSpecificationItemProvider != null) hardwareSoftwareInterfaceSpecificationItemProvider.dispose();
  }

}
