/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;

import org.eatop.eel.eastadl21.ErrorBehavior;

import org.eclipse.emf.common.util.EList;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Abstract Error Behavior</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class contains information about the error behavior independent of concrete behavior descriptions.
 * 
 * The AbstractErrorBehavior contains internalFaults, representing faults that are either propagated to externalFailures of the ErrorModelType or masked, according to the definition of its fault propagation.
 * 
 * A processFault represents a flaw introduced during design, and may lead to any of the failures represented by the ErrorModelType. A processFault therefore has a direct propagation to all externalFailures and cannot be masked. 
 * 
 * Each error behavior description relates the occurrences of internal faults and incoming external faults to external failures. The faults and failures that the error behavior propagates to and from the target element are declared through the malfunction prototypes of the error model.
 * 
 * Semantics: 
 * An error behavior describes the error propagation logic of its containing ErrorModelType.
 * The ErrorBehavior description represents the error propagation from internal faults or external faults to external failures. Faults are identified by the internalFault externalFault associations. The propagated external failures are identified by the externalFailure association. 
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.ErrorModel.ErrorBehavior.AbstractErrorBehavior</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.AbstractErrorBehavior#getEastADLErrorBehavior <em>East ADL Error Behavior</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.AbstractErrorBehavior#getErrorModel <em>Error Model</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.AbstractErrorBehavior#getProcessFault <em>Process Fault</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.AbstractErrorBehavior#getInternalFault <em>Internal Fault</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getAbstractErrorBehavior()
 * @model abstract="true"
 *        annotation="MetaData guid='{32005160-AD0F-433f-AB77-8A26FD8947B9}' id='2016434680' EA\040name='AbstractErrorBehavior'"
 *        annotation="Stereotype Stereotype='abstract'"
 *        extendedMetaData="name='ABSTRACT-ERROR-BEHAVIOR' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='ABSTRACT-ERROR-BEHAVIORS'"
 * @generated
 */
public interface AbstractErrorBehavior extends Identifiable
{
  /**
   * Returns the value of the '<em><b>East ADL Error Behavior</b></em>' containment reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>East ADL Error Behavior</em>' containment reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>East ADL Error Behavior</em>' containment reference.
   * @see #setEastADLErrorBehavior(ErrorBehavior)
   * @see org.safe.metamodel.safe10.Safe10Package#getAbstractErrorBehavior_EastADLErrorBehavior()
   * @model containment="true"
   *        annotation="MetaData guid='{5CB4577F-B88D-43b4-88A9-4E6693AF3647}' id='1005553088' EA\040name=''"
   *        extendedMetaData="name='EAST-ADL-ERROR-BEHAVIOR' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='EAST-ADL-ERROR-BEHAVIORS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  ErrorBehavior getEastADLErrorBehavior();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.AbstractErrorBehavior#getEastADLErrorBehavior <em>East ADL Error Behavior</em>}' containment reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>East ADL Error Behavior</em>' containment reference.
   * @see #getEastADLErrorBehavior()
   * @generated
   */
  void setEastADLErrorBehavior(ErrorBehavior value);

  /**
   * Returns the value of the '<em><b>Error Model</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Error Model</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Error Model</em>' reference.
   * @see #setErrorModel(ErrorModelType)
   * @see org.safe.metamodel.safe10.Safe10Package#getAbstractErrorBehavior_ErrorModel()
   * @model required="true"
   *        annotation="MetaData guid='{5B422AC0-A8AB-47c3-A66D-5077A60E41A1}' id='-560186768' EA\040name=''"
   *        extendedMetaData="name='ERROR-MODEL-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='ERROR-MODEL-REFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  ErrorModelType getErrorModel();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.AbstractErrorBehavior#getErrorModel <em>Error Model</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Error Model</em>' reference.
   * @see #getErrorModel()
   * @generated
   */
  void setErrorModel(ErrorModelType value);

  /**
   * Returns the value of the '<em><b>Process Fault</b></em>' containment reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.MalfunctionPrototype}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * processFaults that may affect the ErrorBehavior of the architectural element associated via the ErrorModelType
   * <!-- end-model-doc -->
   * @return the value of the '<em>Process Fault</em>' containment reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getAbstractErrorBehavior_ProcessFault()
   * @model containment="true"
   *        annotation="MetaData guid='{2F1DF07F-76B2-4789-8ADB-7EB860C542A3}' id='-2018818036' EA\040name=''"
   *        extendedMetaData="name='PROCESS-FAULT' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='PROCESS-FAULTS' xmlAttribute='false' featureWrapperElement='true' featureElement='false' classifierWrapperElement='false' classifierElement='true'"
   * @generated
   */
  EList<MalfunctionPrototype> getProcessFault();

  /**
   * Returns the value of the '<em><b>Internal Fault</b></em>' containment reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.MalfunctionPrototype}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * internalFaults that may affect the ErrorBehavior of the architectural element associated via the ErrorModelType
   * <!-- end-model-doc -->
   * @return the value of the '<em>Internal Fault</em>' containment reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getAbstractErrorBehavior_InternalFault()
   * @model containment="true"
   *        annotation="MetaData guid='{B71301A6-7A91-47e6-B560-C276C606E89B}' id='1025457710' EA\040name=''"
   *        extendedMetaData="name='INTERNAL-FAULT' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='INTERNAL-FAULTS' xmlAttribute='false' featureWrapperElement='true' featureElement='false' classifierWrapperElement='false' classifierElement='true'"
   * @generated
   */
  EList<MalfunctionPrototype> getInternalFault();

} // AbstractErrorBehavior
