/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;


/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Failure Logic Formula</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * FailureLogicFormula is used to describe the error propagation through the architectural element associated with the containing ErrorModelType. The grammer of the FailureLogicFormula is defined in the respective specification document.
 * 
 * The failure logic formula language supports at least
 * <ul>
 * 	<li>AND operator</li>
 * 	<li>OR operator</li>
 * 	<li>NOT operator</li>
 * 	<li>local symbol or variable</li>
 * 	<li>Typed for Boolean expression</li>
 * 	<li>Allows stratified negation (failure itself shall not be used in its negated form), e.g. failure1 = fault2 or fault3 and not(failure1) expression is forbidden</li>
 * 	<li>Permits to n:k gates. The error occurs if k out of n input faults occur.</li>
 * </ul>
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.ErrorModel.ErrorBehavior.FailureLogicFormula</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.FailureLogicFormula#getExternalFailure <em>External Failure</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.FailureLogicFormula#getProcessFault <em>Process Fault</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.FailureLogicFormula#getInternalFault <em>Internal Fault</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.FailureLogicFormula#getExternalFault <em>External Fault</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getFailureLogicFormula()
 * @model annotation="MetaData guid='{F2BE1C24-0F13-4146-9CBA-4BE997DAE390}' id='928293017' EA\040name='FailureLogicFormula'"
 *        annotation="Stereotype Stereotype='mixedString'"
 *        extendedMetaData="name='FAILURE-LOGIC-FORMULA' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='FAILURE-LOGIC-FORMULAS'"
 * @generated
 */
public interface FailureLogicFormula extends FormulaExpression
{
  /**
   * Returns the value of the '<em><b>External Failure</b></em>' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * external failures that may result from the ErrorBehavior
   * <!-- end-model-doc -->
   * @return the value of the '<em>External Failure</em>' reference.
   * @see #setExternalFailure(MalfunctionPrototype)
   * @see org.safe.metamodel.safe10.Safe10Package#getFailureLogicFormula_ExternalFailure()
   * @model annotation="MetaData guid='{658803B2-F532-4cf0-9197-F954EACCC245}' id='-2070127707' EA\040name=''"
   *        extendedMetaData="name='EXTERNAL-FAILURE-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='EXTERNAL-FAILURE-REFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  MalfunctionPrototype getExternalFailure();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.FailureLogicFormula#getExternalFailure <em>External Failure</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>External Failure</em>' reference.
   * @see #getExternalFailure()
   * @generated
   */
  void setExternalFailure(MalfunctionPrototype value);

  /**
   * Returns the value of the '<em><b>Process Fault</b></em>' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * processFaults that influence the errorBehavior 
   * <!-- end-model-doc -->
   * @return the value of the '<em>Process Fault</em>' reference.
   * @see #setProcessFault(MalfunctionPrototype)
   * @see org.safe.metamodel.safe10.Safe10Package#getFailureLogicFormula_ProcessFault()
   * @model annotation="MetaData guid='{8FAC975C-407F-451f-A7EB-9644FF11417A}' id='-1466458533' EA\040name=''"
   *        extendedMetaData="name='PROCESS-FAULT-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='PROCESS-FAULT-REFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  MalfunctionPrototype getProcessFault();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.FailureLogicFormula#getProcessFault <em>Process Fault</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Process Fault</em>' reference.
   * @see #getProcessFault()
   * @generated
   */
  void setProcessFault(MalfunctionPrototype value);

  /**
   * Returns the value of the '<em><b>Internal Fault</b></em>' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * internalFaults that influence the errorBehavior 
   * <!-- end-model-doc -->
   * @return the value of the '<em>Internal Fault</em>' reference.
   * @see #setInternalFault(MalfunctionPrototype)
   * @see org.safe.metamodel.safe10.Safe10Package#getFailureLogicFormula_InternalFault()
   * @model annotation="MetaData guid='{13D924FC-0D57-41e3-A94D-747DFB46279D}' id='861607092' EA\040name=''"
   *        extendedMetaData="name='INTERNAL-FAULT-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='INTERNAL-FAULT-REFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  MalfunctionPrototype getInternalFault();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.FailureLogicFormula#getInternalFault <em>Internal Fault</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Internal Fault</em>' reference.
   * @see #getInternalFault()
   * @generated
   */
  void setInternalFault(MalfunctionPrototype value);

  /**
   * Returns the value of the '<em><b>External Fault</b></em>' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * external(incoming) faults that influence the errorBehavior.
   * <!-- end-model-doc -->
   * @return the value of the '<em>External Fault</em>' reference.
   * @see #setExternalFault(MalfunctionPrototype)
   * @see org.safe.metamodel.safe10.Safe10Package#getFailureLogicFormula_ExternalFault()
   * @model annotation="MetaData guid='{5F6ED5D1-5D7C-46fa-9AE1-B08976AF9763}' id='1593872991' EA\040name=''"
   *        extendedMetaData="name='EXTERNAL-FAULT-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='EXTERNAL-FAULT-REFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  MalfunctionPrototype getExternalFault();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.FailureLogicFormula#getExternalFault <em>External Fault</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>External Fault</em>' reference.
   * @see #getExternalFault()
   * @generated
   */
  void setExternalFault(MalfunctionPrototype value);

} // FailureLogicFormula
