/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;


/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Functional Safety Requirement</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * FunctionalSafetyRequirements are used to specify
 * <ul>
 * 	<li>implementation-independent safety behavior</li>
 * 	<li>implementation-independent safety measures.</li>
 * </ul>
 * FunctionalSafetyRequirements shall contain safety-related attributes.
 * At least one functional safety requirement shall be specified for each safety goal. 
 * FunctionalSafetyRequirements are allocated to the FunctionComponent of the item.
 * A safety goal shall be determined for each hazardous event with an ASIL evaluated in the hazard analysis. If similar safety goals are determined, these may be combined into one safety goal. 
 * 
 * <i><u>Constraint</u></i>:
 * HasAsilDecomposed shall only be set if attribute redundancy is set true. 
 * <b><i><u>
 * </u></i></b><i><u>Reference</u></i><b><i><u>: </u></i></b>
 * ISO 26262-1-1.53
 * ISO 26262-3: 8.4.2.3
 * ISO 26262-3-7.4.4.3
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.Requirements.FunctionalSafetyRequirement</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.FunctionalSafetyRequirement#getIsSafetyGoal <em>Is Safety Goal</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getFunctionalSafetyRequirement()
 * @model annotation="MetaData guid='{92F8CEC9-C638-48e7-8151-15120713DCDD}' id='-204502646' EA\040name='FunctionalSafetyRequirement'"
 *        extendedMetaData="name='FUNCTIONAL-SAFETY-REQUIREMENT' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='FUNCTIONAL-SAFETY-REQUIREMENTS'"
 * @generated
 */
public interface FunctionalSafetyRequirement extends AbstractSafetyRequirement
{
  /**
   * Returns the value of the '<em><b>Is Safety Goal</b></em>' attribute.
   * The default value is <code>"false"</code>.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Is Safety Goal</em>' attribute isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Is Safety Goal</em>' attribute.
   * @see #isSetIsSafetyGoal()
   * @see #unsetIsSafetyGoal()
   * @see #setIsSafetyGoal(Boolean)
   * @see org.safe.metamodel.safe10.Safe10Package#getFunctionalSafetyRequirement_IsSafetyGoal()
   * @model default="false" unsettable="true" dataType="org.safe.metamodel.safe10.Boolean" required="true"
   *        annotation="MetaData guid='{8E92F3CC-33AD-4033-8D10-D9DF27D4399F}' id='1098451751' EA\040name='isSafetyGoal'"
   *        extendedMetaData="name='IS-SAFETY-GOAL' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='IS-SAFETY-GOALS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  Boolean getIsSafetyGoal();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.FunctionalSafetyRequirement#getIsSafetyGoal <em>Is Safety Goal</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Is Safety Goal</em>' attribute.
   * @see #isSetIsSafetyGoal()
   * @see #IsSafetyGoal()
   * @see #getIsSafetyGoal()
   * @generated
   */
  void setIsSafetyGoal(Boolean value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.FunctionalSafetyRequirement#getIsSafetyGoal <em>Is Safety Goal</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetIsSafetyGoal()
   * @see #getIsSafetyGoal()
   * @see #setIsSafetyGoal(Boolean)
   * @generated
   */
  void unsetIsSafetyGoal();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.FunctionalSafetyRequirement#getIsSafetyGoal <em>Is Safety Goal</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Is Safety Goal</em>' attribute is set.
   * @see #IsSafetyGoal()
   * @see #getIsSafetyGoal()
   * @see #setIsSafetyGoal(Boolean)
   * @generated
   */
  boolean isSetIsSafetyGoal();

} // FunctionalSafetyRequirement
