/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;


/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>HWFM Single Contribution Formula</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class describes the individual contribution of an HWFailureMode of a HWComponent to ResidualFault, SinglePointFault or Multiple Fault Latent (in FIT). It is assumed that the HWFailureMode lead to the top level malfunction (link to violation of a SafetyGoal) given by the relation to HWFault connected to a malfunction.
 * 
 * The formula expression shall be for each FailureMode of a safety-related HwComponent (part of the item).
 * 
 * SinglePointFault represents a first order fault, while DualPointFault multiple order fault (limited to 2)
 * The below calculation for lambdaMultiplePointFaultLatent is mostly relevant for HW metrics calculation and PMHF simplified calculation as only SafetyMechanism coverage are considered. It shall not be used for FTA based quantification as multiple point should consider the AND of the combination of the 2 failures.
 * 
 * lambdaSafetyComponent = Value(HWFailureRate)
 * SafetyComponentName = HardwareComponent Class name // to allow detect multiple counting of lambdaSafetyComponent
 * 
 * If (HWFault == SafeFault)
 * lambdaSafeFault(HWFMSingleContribution) = [Value(HWFailureRate)*failureRateDistribution(HWFailureMode) ]   
 * Else
 * lambdaSafeFault(HWFMSingleContribution) = 0
 * Endif
 * 
 * If (HWFault == SinglePointFault) 
 * lambdaSinglePointFault(HWFMSingleContribution) = [Value(HWFailureRate)*failureRateDistribution(HWFailureMode) ]
 * Else lambdaSinglePointFault(HWFMSingleContribution) = 0
 * Endif
 * 
 * If (HWFault == DualPointFault)
 *        If   (HWSafetyMechanism covers the FailureMode) //residual Fault as HWFailureMode.HWSafetyMechanism != null 
 * lambdaResidualFault(HWFMSingleContribution) = [ Value(HWFailureRate)*failureRateDistribution(HWFailureMode) ]  * [ 1 - hwDiagnosisCoverageRF(HWSafetyMechanism)/100 ]
 * lambdaMultiplePointFaultLatentM(HWFMSingleContribution) = [ Value(HWFailureRate) * failureRateDistribution(HWFailureMode) * hwDiagnosisCoverageRF(HWSafetyMechanism) ] *  [ ( 1 - hwDiagnosisCoverageLF(HWSafetyMechanism)/100) ]
 *        Else   // assume 0% of efficiency for MPL,L metrics (from order 2)
 * lambdaResidualFault(HWFMSingleContribution) = 0 
 * lambdaMultiplePointFaultLatent(HWFMSingleContribution) = [Value(HWFailureRate)*failureRateDistribution(HWFailureMode) ]   
 * Endif
 * 
 * Notes that value(HWFailureRate) and failureRateDistribution(HWFailureMode) are applied on the calculated value extracted from electronic design level  to perform the final calculation and verification of the architectural hardware metrics and probabilistic evaluation of violation of the safety goal. The selection between allocated and calculated value is a tool feature that allow first a calculation for estimation based on allocation field of failure rate and distribution, and then verification based on HWComponentQuantifiedFMFromPartHWPart as extract from Part Analysis gives directly the lambda of the HWFailure Mode as HWFailureRate*FailureRateDistribution thanks to the relation to HWFault.
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.Hardware.FailureFormula.HWFMSingleContributionFormula</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.HWFMSingleContributionFormula#getFailureRateDistribution <em>Failure Rate Distribution</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWFMSingleContributionFormula#getHwFaultTypeValue <em>Hw Fault Type Value</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWFMSingleContributionFormula#getHwFailureRateValue <em>Hw Failure Rate Value</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getHWFMSingleContributionFormula()
 * @model annotation="MetaData guid='{1FA8D095-DA80-47b2-A7B9-19160816335D}' id='-371920057' EA\040name='HWFMSingleContributionFormula'"
 *        extendedMetaData="name='HWFM-SINGLE-CONTRIBUTION-FORMULA' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HWFM-SINGLE-CONTRIBUTION-FORMULAS'"
 * @generated
 */
public interface HWFMSingleContributionFormula extends FormulaDocumentation
{
  /**
   * Returns the value of the '<em><b>Failure Rate Distribution</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Failure Rate Distribution</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Failure Rate Distribution</em>' reference.
   * @see #setFailureRateDistribution(HWFailureMode)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWFMSingleContributionFormula_FailureRateDistribution()
   * @model required="true"
   *        annotation="MetaData guid='{4E2CF278-B4BF-435c-A47C-67F6BB6BD1B5}' id='-1180107483' EA\040name=''"
   *        extendedMetaData="name='FAILURE-RATE-DISTRIBUTION-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='FAILURE-RATE-DISTRIBUTION-REFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  HWFailureMode getFailureRateDistribution();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWFMSingleContributionFormula#getFailureRateDistribution <em>Failure Rate Distribution</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Failure Rate Distribution</em>' reference.
   * @see #getFailureRateDistribution()
   * @generated
   */
  void setFailureRateDistribution(HWFailureMode value);

  /**
   * Returns the value of the '<em><b>Hw Fault Type Value</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Hw Fault Type Value</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Hw Fault Type Value</em>' reference.
   * @see #setHwFaultTypeValue(HWFault)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWFMSingleContributionFormula_HwFaultTypeValue()
   * @model required="true"
   *        annotation="MetaData guid='{FBF2B5AB-60AF-468c-91BE-7B7D74EBD578}' id='-966541950' EA\040name=''"
   *        extendedMetaData="name='HW-FAULT-TYPE-VALUE-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-FAULT-TYPE-VALUE-REFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  HWFault getHwFaultTypeValue();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWFMSingleContributionFormula#getHwFaultTypeValue <em>Hw Fault Type Value</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Hw Fault Type Value</em>' reference.
   * @see #getHwFaultTypeValue()
   * @generated
   */
  void setHwFaultTypeValue(HWFault value);

  /**
   * Returns the value of the '<em><b>Hw Failure Rate Value</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Hw Failure Rate Value</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Hw Failure Rate Value</em>' reference.
   * @see #setHwFailureRateValue(HWFailureRate)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWFMSingleContributionFormula_HwFailureRateValue()
   * @model required="true"
   *        annotation="MetaData guid='{DCFF2BC6-491E-47d4-AD47-A1DACF93DE6D}' id='-748113898' EA\040name=''"
   *        extendedMetaData="name='HW-FAILURE-RATE-VALUE-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-FAILURE-RATE-VALUE-REFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  HWFailureRate getHwFailureRateValue();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWFMSingleContributionFormula#getHwFailureRateValue <em>Hw Failure Rate Value</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Hw Failure Rate Value</em>' reference.
   * @see #getHwFailureRateValue()
   * @generated
   */
  void setHwFailureRateValue(HWFailureRate value);

} // HWFMSingleContributionFormula
