/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;

import org.eclipse.emf.common.util.EList;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>HW Failure Class Contribution Formula</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class describes the calculation of the diagnostic coverage of a HWElement (from HWComponent) for the Failure Rate Class method (in %) as ratio of all fault coverage of the HW Component (safe fault, single-point fault and residual fault) and the calculation of the element FailureRateClass defined by its failure rate.
 * 
 * The formula expression shall be calculated for each FailureMode of a safety-related HwComponent (part of the item).
 * 
 * HW Element Failure Rate Class = Failure Class (safety-related failure rate component)
 * HW Element Residual Diagnostic Coverage  = 100% - total (single point faults failure rate + residual faults failure rate) /safety related failure rate component
 * HW Element Latent Diagnostic Coverage  = 100% - total(multiple fault latent) / ((safety related failure rate component) - total (single point faults failure rate + residual faults failure rate))
 * 
 * The formula expression shall be for each the top level malfunction (link to violation of the SafetyGoal).
 * 
 * 
 * hwElementResidualDiagnosisCoverage
 * HWElementFailureRateClass(hwElementFailureClass) = HWValuesFailureRateClassEnum(LambdaSafetyComponent )
 * HWElementFailureRateClass(hwElementResidualDiagnosisCoverage) = { 1 - ( Sum (lambdaSinglePointFault(HWFMSingleContribution) + lambdaResidualFault(HWFMSingleContribution) ) / LambdaSafetyComponent  }  * 100
 * HWElementFailureRateClass(hwElementLatentDiagnosisCoverage) =  { 1 - Sum (lambdaMultipleFaultLatent(HWFMSingleContribution) / LambdaSafetyComponent }  * 100
 * 
 * Note that Value(hwElementDiagnosisCoverage) is applied on estimatedValue from electronic design level  to perform the final calculation and verification of the  individual HWElement FailureRateClass and ElementDiagnosisCoverage.  The selection between calculated and estimated value is a tool feature that allow first a calculation for estimation based on allocation field of failure rate. Only safety-related component are considered and LambdaSafetyComponent is only counted once for a HWElement (identical safetyComponentClassName).
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.Hardware.FailureFormula.HWFailureClassContributionFormula</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.HWFailureClassContributionFormula#getLambdaValue <em>Lambda Value</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getHWFailureClassContributionFormula()
 * @model annotation="MetaData guid='{0F0E1310-EAA6-4b5f-BEC9-2F83A1ED46D8}' id='465603964' EA\040name='HWFailureClassContributionFormula'"
 *        extendedMetaData="name='HW-FAILURE-CLASS-CONTRIBUTION-FORMULA' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-FAILURE-CLASS-CONTRIBUTION-FORMULAS'"
 * @generated
 */
public interface HWFailureClassContributionFormula extends FormulaDocumentation
{
  /**
   * Returns the value of the '<em><b>Lambda Value</b></em>' reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.HWFMSingleContribution}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Lambda Value</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Lambda Value</em>' reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getHWFailureClassContributionFormula_LambdaValue()
   * @model annotation="MetaData guid='{0DA7C4A9-839E-426b-8F28-42E632CA821E}' id='1792618403' EA\040name=''"
   *        extendedMetaData="name='LAMBDA-VALUE-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='LAMBDA-VALUE-REFS' xmlAttribute='false' featureWrapperElement='true' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  EList<HWFMSingleContribution> getLambdaValue();

} // HWFailureClassContributionFormula
