/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;


/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>HW Failure Mode</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class describes a HWFailureMode of a HWComponent.
 * 
 * Each HWFailureMode of the HWComponent must have its own characterization for each linked malfunction (linked to violation of a SafetyGoal).
 * 
 * The HWFailureMode and HWFailureRateDistribution can be derived from e.g. Industry Source (see ISO Part 5 8.4.3).
 * 
 * The HWfailureMode as a specialization of A malfunction can be traced according Requirement tracing relation to a SafetyMechanismSpecification composed with  QuantifiedHWDCProperty class to identify the  Diagnosis Coverage value for Latent and/or Residual Fault to be able then to compute HW metrics.
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.Hardware.Failure.HWFailureMode</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.HWFailureMode#getAllocatedFailureRateDistribution <em>Allocated Failure Rate Distribution</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWFailureMode#getFailureModeType <em>Failure Mode Type</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWFailureMode#getPotentialCause <em>Potential Cause</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getHWFailureMode()
 * @model annotation="MetaData guid='{B27C36BE-7BD0-43c3-A023-C33DD8C8C225}' id='1199064744' EA\040name='HWFailureMode'"
 *        extendedMetaData="name='HW-FAILURE-MODE' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-FAILURE-MODES'"
 * @generated
 */
public interface HWFailureMode extends Referrable, MalfunctionType
{
  /**
   * Returns the value of the '<em><b>Allocated Failure Rate Distribution</b></em>' attribute.
   * The default value is <code>"0.0"</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * This attribute describes the allocated distribution of the failure rate of the specific failure mode (in percentage) of a HWComponent
   * 
   * The sum of all failure rate distributions of all failure modes for a single hardware component must lead to the value 100% (may check for consistency).
   * <!-- end-model-doc -->
   * @return the value of the '<em>Allocated Failure Rate Distribution</em>' attribute.
   * @see #isSetAllocatedFailureRateDistribution()
   * @see #unsetAllocatedFailureRateDistribution()
   * @see #setAllocatedFailureRateDistribution(Double)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWFailureMode_AllocatedFailureRateDistribution()
   * @model default="0.0" unsettable="true" dataType="org.safe.metamodel.safe10.Float" required="true"
   *        annotation="MetaData guid='{B0626B41-8707-4d73-A559-6115ADF3E629}' id='27220873' EA\040name='allocatedFailureRateDistribution'"
   *        extendedMetaData="name='ALLOCATED-FAILURE-RATE-DISTRIBUTION' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='ALLOCATED-FAILURE-RATE-DISTRIBUTIONS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  Double getAllocatedFailureRateDistribution();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWFailureMode#getAllocatedFailureRateDistribution <em>Allocated Failure Rate Distribution</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Allocated Failure Rate Distribution</em>' attribute.
   * @see #isSetAllocatedFailureRateDistribution()
   * @see #AllocatedFailureRateDistribution()
   * @see #getAllocatedFailureRateDistribution()
   * @generated
   */
  void setAllocatedFailureRateDistribution(Double value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWFailureMode#getAllocatedFailureRateDistribution <em>Allocated Failure Rate Distribution</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetAllocatedFailureRateDistribution()
   * @see #getAllocatedFailureRateDistribution()
   * @see #setAllocatedFailureRateDistribution(Double)
   * @generated
   */
  void unsetAllocatedFailureRateDistribution();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWFailureMode#getAllocatedFailureRateDistribution <em>Allocated Failure Rate Distribution</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Allocated Failure Rate Distribution</em>' attribute is set.
   * @see #AllocatedFailureRateDistribution()
   * @see #getAllocatedFailureRateDistribution()
   * @see #setAllocatedFailureRateDistribution(Double)
   * @generated
   */
  boolean isSetAllocatedFailureRateDistribution();

  /**
   * Returns the value of the '<em><b>Failure Mode Type</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * This attribute textually describes the type of a failure mode of a HWComponent (e.g. "No value" for a sensor).
   * <!-- end-model-doc -->
   * @return the value of the '<em>Failure Mode Type</em>' attribute.
   * @see #isSetFailureModeType()
   * @see #unsetFailureModeType()
   * @see #setFailureModeType(String)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWFailureMode_FailureModeType()
   * @model default="" unsettable="true" dataType="org.safe.metamodel.safe10.String" required="true"
   *        annotation="MetaData guid='{0DA419D7-ADDF-41c3-9900-162D8F88F00F}' id='948547807' EA\040name='failureModeType'"
   *        extendedMetaData="name='FAILURE-MODE-TYPE' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='FAILURE-MODE-TYPES' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  String getFailureModeType();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWFailureMode#getFailureModeType <em>Failure Mode Type</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Failure Mode Type</em>' attribute.
   * @see #isSetFailureModeType()
   * @see #FailureModeType()
   * @see #getFailureModeType()
   * @generated
   */
  void setFailureModeType(String value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWFailureMode#getFailureModeType <em>Failure Mode Type</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetFailureModeType()
   * @see #getFailureModeType()
   * @see #setFailureModeType(String)
   * @generated
   */
  void unsetFailureModeType();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWFailureMode#getFailureModeType <em>Failure Mode Type</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Failure Mode Type</em>' attribute is set.
   * @see #FailureModeType()
   * @see #getFailureModeType()
   * @see #setFailureModeType(String)
   * @generated
   */
  boolean isSetFailureModeType();

  /**
   * Returns the value of the '<em><b>Potential Cause</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * This attribute allows the documentation of the potential cause of the HWComponent failure mode (e.g. high temperature).
   * <!-- end-model-doc -->
   * @return the value of the '<em>Potential Cause</em>' attribute.
   * @see #isSetPotentialCause()
   * @see #unsetPotentialCause()
   * @see #setPotentialCause(String)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWFailureMode_PotentialCause()
   * @model default="" unsettable="true" dataType="org.safe.metamodel.safe10.String" required="true"
   *        annotation="MetaData guid='{21663CD2-41C9-41b0-8AF3-5A6E7020E913}' id='-1042517708' EA\040name='potentialCause'"
   *        extendedMetaData="name='POTENTIAL-CAUSE' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='POTENTIAL-CAUSES' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  String getPotentialCause();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWFailureMode#getPotentialCause <em>Potential Cause</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Potential Cause</em>' attribute.
   * @see #isSetPotentialCause()
   * @see #PotentialCause()
   * @see #getPotentialCause()
   * @generated
   */
  void setPotentialCause(String value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWFailureMode#getPotentialCause <em>Potential Cause</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetPotentialCause()
   * @see #getPotentialCause()
   * @see #setPotentialCause(String)
   * @generated
   */
  void unsetPotentialCause();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWFailureMode#getPotentialCause <em>Potential Cause</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Potential Cause</em>' attribute is set.
   * @see #PotentialCause()
   * @see #getPotentialCause()
   * @see #setPotentialCause(String)
   * @generated
   */
  boolean isSetPotentialCause();

} // HWFailureMode
