/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;

import org.eclipse.emf.ecore.EObject;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>HW Latent Fault Metric</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class is the representation of the latent fault metric, demanded by ISO Part 5 Clause 8. The latent fault metric describes the robustness of the hardware architecture to cope with multiple-point latent faults (also see ISO Part 5 Annex C).
 * 
 * The calculation is included in the class HWLatentFaultMetricFormula.
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.Hardware.HWArchitecturalMetrics.HWLatentFaultMetric</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.HWLatentFaultMetric#getCalculatedValue <em>Calculated Value</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWLatentFaultMetric#getLfmCalculatedValue <em>Lfm Calculated Value</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getHWLatentFaultMetric()
 * @model annotation="MetaData guid='{15FF9875-93B0-47c7-91BF-59D1536C161C}' id='798161483' EA\040name='HWLatentFaultMetric'"
 *        extendedMetaData="name='HW-LATENT-FAULT-METRIC' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-LATENT-FAULT-METRICS'"
 * @generated
 */
public interface HWLatentFaultMetric extends EObject
{
  /**
   * Returns the value of the '<em><b>Calculated Value</b></em>' attribute.
   * The default value is <code>"0.0"</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The calculatedValue is the result of the calculation of the latent fault metric (in %).
   * <!-- end-model-doc -->
   * @return the value of the '<em>Calculated Value</em>' attribute.
   * @see #isSetCalculatedValue()
   * @see #unsetCalculatedValue()
   * @see #setCalculatedValue(Double)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWLatentFaultMetric_CalculatedValue()
   * @model default="0.0" unsettable="true" dataType="org.safe.metamodel.safe10.Float" required="true"
   *        annotation="MetaData guid='{B7548432-8C62-4fab-87B8-12909CF97214}' id='-982163152' EA\040name='calculatedValue'"
   *        extendedMetaData="name='CALCULATED-VALUE' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='CALCULATED-VALUES' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  Double getCalculatedValue();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWLatentFaultMetric#getCalculatedValue <em>Calculated Value</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Calculated Value</em>' attribute.
   * @see #isSetCalculatedValue()
   * @see #CalculatedValue()
   * @see #getCalculatedValue()
   * @generated
   */
  void setCalculatedValue(Double value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWLatentFaultMetric#getCalculatedValue <em>Calculated Value</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetCalculatedValue()
   * @see #getCalculatedValue()
   * @see #setCalculatedValue(Double)
   * @generated
   */
  void unsetCalculatedValue();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWLatentFaultMetric#getCalculatedValue <em>Calculated Value</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Calculated Value</em>' attribute is set.
   * @see #CalculatedValue()
   * @see #getCalculatedValue()
   * @see #setCalculatedValue(Double)
   * @generated
   */
  boolean isSetCalculatedValue();

  /**
   * Returns the value of the '<em><b>Lfm Calculated Value</b></em>' containment reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Lfm Calculated Value</em>' containment reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Lfm Calculated Value</em>' containment reference.
   * @see #setLfmCalculatedValue(HWLatentFaultMetricFormula)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWLatentFaultMetric_LfmCalculatedValue()
   * @model containment="true" required="true"
   *        annotation="MetaData guid='{93DD0114-27C2-4b23-ADE3-C0EFFD275B69}' id='1760907148' EA\040name=''"
   *        extendedMetaData="name='LFM-CALCULATED-VALUE' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='LFM-CALCULATED-VALUES' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  HWLatentFaultMetricFormula getLfmCalculatedValue();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWLatentFaultMetric#getLfmCalculatedValue <em>Lfm Calculated Value</em>}' containment reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Lfm Calculated Value</em>' containment reference.
   * @see #getLfmCalculatedValue()
   * @generated
   */
  void setLfmCalculatedValue(HWLatentFaultMetricFormula value);

} // HWLatentFaultMetric
