/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;

import org.eclipse.emf.ecore.EObject;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>HW Part Failure Mode</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class describes HWPartFailureModes of a HWPart as AUTOSAR HWElement. It aso captures the potential cause for a HWFailureMode as String (for documentation).
 * 
 * Each HWPartFailureMode of the Autosar HardwareElement must define a relation and contribution to a HWFailureMode of HardwareComponent (from hardware design level).
 * 
 * The HWFailureMode and HWFailureRateDistribution can be derived from e.g. Industry Source.
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.Hardware.FailurePart.HWPartFailureMode</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.HWPartFailureMode#getPartFailureModeType <em>Part Failure Mode Type</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWPartFailureMode#getFailureRateDistribution <em>Failure Rate Distribution</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWPartFailureMode#getPartPotentialCause <em>Part Potential Cause</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getHWPartFailureMode()
 * @model annotation="MetaData guid='{0A9E2147-2B2C-4c8c-9CB7-D6C6023CEA0B}' id='1226885119' EA\040name='HWPartFailureMode'"
 *        extendedMetaData="name='HW-PART-FAILURE-MODE' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-PART-FAILURE-MODES'"
 * @generated
 */
public interface HWPartFailureMode extends EObject
{
  /**
   * Returns the value of the '<em><b>Part Failure Mode Type</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * This attribute textually describes the type of a failure mode of a HWPart element (e.g. "ShortCircuit" for a resistor).
   * <!-- end-model-doc -->
   * @return the value of the '<em>Part Failure Mode Type</em>' attribute.
   * @see #isSetPartFailureModeType()
   * @see #unsetPartFailureModeType()
   * @see #setPartFailureModeType(String)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWPartFailureMode_PartFailureModeType()
   * @model default="" unsettable="true" dataType="org.safe.metamodel.safe10.String" required="true"
   *        annotation="MetaData guid='{0893FFFD-1237-4590-9760-C4F558DA2E9B}' id='1476004421' EA\040name='partFailureModeType'"
   *        extendedMetaData="name='PART-FAILURE-MODE-TYPE' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='PART-FAILURE-MODE-TYPES' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  String getPartFailureModeType();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWPartFailureMode#getPartFailureModeType <em>Part Failure Mode Type</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Part Failure Mode Type</em>' attribute.
   * @see #isSetPartFailureModeType()
   * @see #PartFailureModeType()
   * @see #getPartFailureModeType()
   * @generated
   */
  void setPartFailureModeType(String value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWPartFailureMode#getPartFailureModeType <em>Part Failure Mode Type</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetPartFailureModeType()
   * @see #getPartFailureModeType()
   * @see #setPartFailureModeType(String)
   * @generated
   */
  void unsetPartFailureModeType();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWPartFailureMode#getPartFailureModeType <em>Part Failure Mode Type</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Part Failure Mode Type</em>' attribute is set.
   * @see #PartFailureModeType()
   * @see #getPartFailureModeType()
   * @see #setPartFailureModeType(String)
   * @generated
   */
  boolean isSetPartFailureModeType();

  /**
   * Returns the value of the '<em><b>Failure Rate Distribution</b></em>' attribute.
   * The default value is <code>"0"</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * This attribute describes the distribution of the failure rate of the HWPart element for the specific hardware part failure mode in percentage.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Failure Rate Distribution</em>' attribute.
   * @see #isSetFailureRateDistribution()
   * @see #unsetFailureRateDistribution()
   * @see #setFailureRateDistribution(Integer)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWPartFailureMode_FailureRateDistribution()
   * @model default="0" unsettable="true" dataType="org.safe.metamodel.safe10.Integer" required="true"
   *        annotation="MetaData guid='{8783BE94-14A7-4304-8386-2C7E2AB653AE}' id='-1825422892' EA\040name='FailureRateDistribution'"
   *        extendedMetaData="name='FAILURE-RATE-DISTRIBUTION' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='FAILURE-RATE-DISTRIBUTIONS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  Integer getFailureRateDistribution();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWPartFailureMode#getFailureRateDistribution <em>Failure Rate Distribution</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Failure Rate Distribution</em>' attribute.
   * @see #isSetFailureRateDistribution()
   * @see #FailureRateDistribution()
   * @see #getFailureRateDistribution()
   * @generated
   */
  void setFailureRateDistribution(Integer value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWPartFailureMode#getFailureRateDistribution <em>Failure Rate Distribution</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetFailureRateDistribution()
   * @see #getFailureRateDistribution()
   * @see #setFailureRateDistribution(Integer)
   * @generated
   */
  void unsetFailureRateDistribution();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWPartFailureMode#getFailureRateDistribution <em>Failure Rate Distribution</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Failure Rate Distribution</em>' attribute is set.
   * @see #FailureRateDistribution()
   * @see #getFailureRateDistribution()
   * @see #setFailureRateDistribution(Integer)
   * @generated
   */
  boolean isSetFailureRateDistribution();

  /**
   * Returns the value of the '<em><b>Part Potential Cause</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * This attribute allows the documentation of the potential cause of the HWPart failure mode (e.g. high temperature).
   * <!-- end-model-doc -->
   * @return the value of the '<em>Part Potential Cause</em>' attribute.
   * @see #isSetPartPotentialCause()
   * @see #unsetPartPotentialCause()
   * @see #setPartPotentialCause(String)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWPartFailureMode_PartPotentialCause()
   * @model default="" unsettable="true" dataType="org.safe.metamodel.safe10.String" required="true"
   *        annotation="MetaData guid='{39B5E2BC-D226-46f6-BE22-D93B0495283D}' id='342740002' EA\040name='partPotentialCause'"
   *        extendedMetaData="name='PART-POTENTIAL-CAUSE' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='PART-POTENTIAL-CAUSES' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  String getPartPotentialCause();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWPartFailureMode#getPartPotentialCause <em>Part Potential Cause</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Part Potential Cause</em>' attribute.
   * @see #isSetPartPotentialCause()
   * @see #PartPotentialCause()
   * @see #getPartPotentialCause()
   * @generated
   */
  void setPartPotentialCause(String value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWPartFailureMode#getPartPotentialCause <em>Part Potential Cause</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetPartPotentialCause()
   * @see #getPartPotentialCause()
   * @see #setPartPotentialCause(String)
   * @generated
   */
  void unsetPartPotentialCause();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWPartFailureMode#getPartPotentialCause <em>Part Potential Cause</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Part Potential Cause</em>' attribute is set.
   * @see #PartPotentialCause()
   * @see #getPartPotentialCause()
   * @see #setPartPotentialCause(String)
   * @generated
   */
  boolean isSetPartPotentialCause();

} // HWPartFailureMode
