/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;

import org.eclipse.emf.ecore.EObject;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>HW Single Point Fault Metric</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class is the representation of the single-point fault metric, demanded by ISO Part 5 Clause 8. The single-point fault metric describes the robustness of the hardware architecture to cope with single-point and residual faults (also see ISO Part 5 Annex C).
 * 
 * The calculation is included in the class HWSinglePointFaultMetricFormula.
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.Hardware.HWArchitecturalMetrics.HWSinglePointFaultMetric</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.HWSinglePointFaultMetric#getCalculatedValue <em>Calculated Value</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.HWSinglePointFaultMetric#getSpfmCalculatedValue <em>Spfm Calculated Value</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getHWSinglePointFaultMetric()
 * @model annotation="MetaData guid='{0A8A8236-5EE9-4c44-B763-4DD9F3B34FFD}' id='-1061699761' EA\040name='HWSinglePointFaultMetric'"
 *        extendedMetaData="name='HW-SINGLE-POINT-FAULT-METRIC' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='HW-SINGLE-POINT-FAULT-METRICS'"
 * @generated
 */
public interface HWSinglePointFaultMetric extends EObject
{
  /**
   * Returns the value of the '<em><b>Calculated Value</b></em>' attribute.
   * The default value is <code>"0.0"</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The calculatedValue is the result of the calculation of the single-point fault metric (in %).
   * <!-- end-model-doc -->
   * @return the value of the '<em>Calculated Value</em>' attribute.
   * @see #isSetCalculatedValue()
   * @see #unsetCalculatedValue()
   * @see #setCalculatedValue(Double)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWSinglePointFaultMetric_CalculatedValue()
   * @model default="0.0" unsettable="true" dataType="org.safe.metamodel.safe10.Float" required="true"
   *        annotation="MetaData guid='{5EC000DD-8EC9-4043-B040-40280E79625F}' id='2129500900' EA\040name='calculatedValue'"
   *        extendedMetaData="name='CALCULATED-VALUE' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='CALCULATED-VALUES' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  Double getCalculatedValue();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWSinglePointFaultMetric#getCalculatedValue <em>Calculated Value</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Calculated Value</em>' attribute.
   * @see #isSetCalculatedValue()
   * @see #CalculatedValue()
   * @see #getCalculatedValue()
   * @generated
   */
  void setCalculatedValue(Double value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.HWSinglePointFaultMetric#getCalculatedValue <em>Calculated Value</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetCalculatedValue()
   * @see #getCalculatedValue()
   * @see #setCalculatedValue(Double)
   * @generated
   */
  void unsetCalculatedValue();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.HWSinglePointFaultMetric#getCalculatedValue <em>Calculated Value</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Calculated Value</em>' attribute is set.
   * @see #CalculatedValue()
   * @see #getCalculatedValue()
   * @see #setCalculatedValue(Double)
   * @generated
   */
  boolean isSetCalculatedValue();

  /**
   * Returns the value of the '<em><b>Spfm Calculated Value</b></em>' containment reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Spfm Calculated Value</em>' containment reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Spfm Calculated Value</em>' containment reference.
   * @see #setSpfmCalculatedValue(HWSinglePointFaultMetricFormula)
   * @see org.safe.metamodel.safe10.Safe10Package#getHWSinglePointFaultMetric_SpfmCalculatedValue()
   * @model containment="true" required="true"
   *        annotation="MetaData guid='{76596F3D-1199-4863-9963-813B359DF3F2}' id='-2027442618' EA\040name=''"
   *        extendedMetaData="name='SPFM-CALCULATED-VALUE' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='SPFM-CALCULATED-VALUES' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  HWSinglePointFaultMetricFormula getSpfmCalculatedValue();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.HWSinglePointFaultMetric#getSpfmCalculatedValue <em>Spfm Calculated Value</em>}' containment reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Spfm Calculated Value</em>' containment reference.
   * @see #getSpfmCalculatedValue()
   * @generated
   */
  void setSpfmCalculatedValue(HWSinglePointFaultMetricFormula value);

} // HWSinglePointFaultMetric
