/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;


/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Malfunction Mapping</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * Via the class MalfunctionMapping it is possible to map malfunctions of one abstraction level (e.g. EAST ADL implementation level) to another level of abstraction (e.g. EAST ADL analysis level). This way the correlation between different levels of abstraction can be made explicit.
 * 
 * The MalfunctionMapping shall be attached to the "lower" level of abstraction. Example:
 * <ul>
 * 	<li>a malfunction defined for a software component (implementation level) shall be related with a malfunction defined on design level</li>
 * </ul>
 * <ul>
 * 	<li>in this case, (at least) two instances of SafetyExtensions (TechnicalSafetyExtension, AutosarSystemSafetyExtension) exist. In each of them an ErrorModelType is defined containing the before mentioned malfunctions</li>
 * </ul>
 * <ul>
 * 	<li>in the AutosarSystemSafetyExtension, we define an MalfunctionMapping and relate the software malfunction (in the role of "origin") to the malfunction defined within the TechnicalSafetyExtension (in the role "target")</li>
 * </ul>
 * 
 * Thus, the following rules shall be applied:
 * <ul>
 * 	<li>the MalfunctionPrototype referenced via the "origin" relationship shall be defined within the same SafetyExtension as an instance of this class</li>
 * 	<li>the MalfunctionPrototype references via the "target" relationship shall be defined within a SafetyExtension which corresponds to a higher level of abstraction</li>
 * </ul>
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.ErrorModel.Mapping.MalfunctionMapping</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.MalfunctionMapping#getOrigin <em>Origin</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.MalfunctionMapping#getTarget <em>Target</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getMalfunctionMapping()
 * @model annotation="MetaData guid='{1E5BA56F-DE0C-436a-8E4D-D469454544C5}' id='1363688014' EA\040name='MalfunctionMapping'"
 *        extendedMetaData="name='MALFUNCTION-MAPPING' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='MALFUNCTION-MAPPINGS'"
 * @generated
 */
public interface MalfunctionMapping extends Identifiable
{
  /**
   * Returns the value of the '<em><b>Origin</b></em>' containment reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Origin</em>' containment reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Origin</em>' containment reference.
   * @see #setOrigin(MalfunctionInstanceRef)
   * @see org.safe.metamodel.safe10.Safe10Package#getMalfunctionMapping_Origin()
   * @model containment="true" required="true"
   *        annotation="MetaData guid='{4028C1DF-34B0-4055-A9C3-27A300D6D151}' id='594040086' EA\040name=''"
   *        annotation="TaggedValues xml.name='ORIGIN-IREF' xml.namePlural='ORIGIN-IREFS' xml.roleElement='true' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        extendedMetaData="name='ORIGIN-IREF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='ORIGIN-IREFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  MalfunctionInstanceRef getOrigin();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.MalfunctionMapping#getOrigin <em>Origin</em>}' containment reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Origin</em>' containment reference.
   * @see #getOrigin()
   * @generated
   */
  void setOrigin(MalfunctionInstanceRef value);

  /**
   * Returns the value of the '<em><b>Target</b></em>' containment reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Target</em>' containment reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Target</em>' containment reference.
   * @see #setTarget(MalfunctionInstanceRef)
   * @see org.safe.metamodel.safe10.Safe10Package#getMalfunctionMapping_Target()
   * @model containment="true" required="true"
   *        annotation="MetaData guid='{FB75537C-5F4C-487b-B5B5-5259ECF38490}' id='1296611551' EA\040name=''"
   *        annotation="TaggedValues xml.name='TARGET-IREF' xml.namePlural='TARGET-IREFS' xml.roleElement='true' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        extendedMetaData="name='TARGET-IREF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='TARGET-IREFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  MalfunctionInstanceRef getTarget();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.MalfunctionMapping#getTarget <em>Target</em>}' containment reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Target</em>' containment reference.
   * @see #getTarget()
   * @generated
   */
  void setTarget(MalfunctionInstanceRef value);

} // MalfunctionMapping
