/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;

import org.eclipse.emf.common.util.EList;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Native Error Behavior</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * NativeErrorBehavior represents the descriptions of failure logics or semantics that the architectural element associated by the ErrorModelType exhibits. 
 * 
 * Semantics: 
 * The NativeErrorBehavior is defined in the failureLogic string, either directly or as a url referencing an external specification. 
 * The failureLogic can be based on different formalisms, depending on the analysis techniques and tools available. This is indicated by its type:ErrorBehaviorKind attribute. The failureLogic attribute contains the actual failure propagation logic. 
 * 
 * Extension:
 * UML:Behavior
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.ErrorModel.ErrorBehavior.NativeErrorBehavior</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.NativeErrorBehavior#getFailureLogic <em>Failure Logic</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.NativeErrorBehavior#getType <em>Type</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.NativeErrorBehavior#getExternalFailure <em>External Failure</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.NativeErrorBehavior#getExternalFault <em>External Fault</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getNativeErrorBehavior()
 * @model annotation="MetaData guid='{39B32206-50E2-4341-AB6F-EE435A39A44F}' id='1021324283' EA\040name='NativeErrorBehavior'"
 *        extendedMetaData="name='NATIVE-ERROR-BEHAVIOR' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='NATIVE-ERROR-BEHAVIORS'"
 * @generated
 */
public interface NativeErrorBehavior extends AbstractErrorBehavior
{
  /**
   * Returns the value of the '<em><b>Failure Logic</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The specification of error behavior based on an external formalism or the path to the file containing the external specification.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Failure Logic</em>' attribute.
   * @see #isSetFailureLogic()
   * @see #unsetFailureLogic()
   * @see #setFailureLogic(String)
   * @see org.safe.metamodel.safe10.Safe10Package#getNativeErrorBehavior_FailureLogic()
   * @model default="" unsettable="true" dataType="org.safe.metamodel.safe10.String"
   *        annotation="MetaData guid='{98A5FBBE-6B68-474e-8BCD-3220EF2EAC68}' id='1923824928' EA\040name='failureLogic'"
   *        extendedMetaData="name='FAILURE-LOGIC' kind='attribute'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='FAILURE-LOGICS' xmlAttribute='true' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  String getFailureLogic();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.NativeErrorBehavior#getFailureLogic <em>Failure Logic</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Failure Logic</em>' attribute.
   * @see #isSetFailureLogic()
   * @see #FailureLogic()
   * @see #getFailureLogic()
   * @generated
   */
  void setFailureLogic(String value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.NativeErrorBehavior#getFailureLogic <em>Failure Logic</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetFailureLogic()
   * @see #getFailureLogic()
   * @see #setFailureLogic(String)
   * @generated
   */
  void unsetFailureLogic();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.NativeErrorBehavior#getFailureLogic <em>Failure Logic</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Failure Logic</em>' attribute is set.
   * @see #FailureLogic()
   * @see #getFailureLogic()
   * @see #setFailureLogic(String)
   * @generated
   */
  boolean isSetFailureLogic();

  /**
   * Returns the value of the '<em><b>Type</b></em>' attribute.
   * The default value is <code>"HIP_HOPS"</code>.
   * The literals are from the enumeration {@link org.safe.metamodel.safe10.ErrorBehaviorKind}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The type of formalism applied for the error behavior description.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Type</em>' attribute.
   * @see org.safe.metamodel.safe10.ErrorBehaviorKind
   * @see #isSetType()
   * @see #unsetType()
   * @see #setType(ErrorBehaviorKind)
   * @see org.safe.metamodel.safe10.Safe10Package#getNativeErrorBehavior_Type()
   * @model default="HIP_HOPS" unsettable="true" required="true"
   *        annotation="MetaData guid='{8616762C-C8C7-477a-B763-B54F302A54A9}' id='-1459323231' EA\040name='type'"
   *        extendedMetaData="name='TYPE' kind='element'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='TYPES' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  ErrorBehaviorKind getType();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.NativeErrorBehavior#getType <em>Type</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Type</em>' attribute.
   * @see org.safe.metamodel.safe10.ErrorBehaviorKind
   * @see #isSetType()
   * @see #Type()
   * @see #getType()
   * @generated
   */
  void setType(ErrorBehaviorKind value);

  /**
   * Unsets the value of the '{@link org.safe.metamodel.safe10.NativeErrorBehavior#getType <em>Type</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetType()
   * @see #getType()
   * @see #setType(ErrorBehaviorKind)
   * @generated
   */
  void unsetType();

  /**
   * Returns whether the value of the '{@link org.safe.metamodel.safe10.NativeErrorBehavior#getType <em>Type</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Type</em>' attribute is set.
   * @see #Type()
   * @see #getType()
   * @see #setType(ErrorBehaviorKind)
   * @generated
   */
  boolean isSetType();

  /**
   * Returns the value of the '<em><b>External Failure</b></em>' reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.MalfunctionPrototype}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * external failures that may result from the ErrorBehavior
   * <!-- end-model-doc -->
   * @return the value of the '<em>External Failure</em>' reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getNativeErrorBehavior_ExternalFailure()
   * @model required="true"
   *        annotation="MetaData guid='{CAD71ABB-8B0E-44e2-9842-EAB6ADB20B9E}' id='1217134799' EA\040name=''"
   *        extendedMetaData="name='EXTERNAL-FAILURE-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='EXTERNAL-FAILURE-REFS' xmlAttribute='false' featureWrapperElement='true' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  EList<MalfunctionPrototype> getExternalFailure();

  /**
   * Returns the value of the '<em><b>External Fault</b></em>' reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.MalfunctionPrototype}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * external(incoming) faults that influence the errorBehavior.
   * <!-- end-model-doc -->
   * @return the value of the '<em>External Fault</em>' reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getNativeErrorBehavior_ExternalFault()
   * @model annotation="MetaData guid='{4B90385F-EDC1-4205-8FE7-867780A9709D}' id='1374167750' EA\040name=''"
   *        extendedMetaData="name='EXTERNAL-FAULT-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='EXTERNAL-FAULT-REFS' xmlAttribute='false' featureWrapperElement='true' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  EList<MalfunctionPrototype> getExternalFault();

} // NativeErrorBehavior
