/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis France and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis France - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel.safe10;

import org.eatop.eel.eastadl21.Environment;

import org.eclipse.emf.common.util.EList;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Operational Situation</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * An operational situation is a scenario that may occur during a vehicles lifetime. Operational situations are formed by contributions of different actors, namely the driver (input of the driver via steering wheel, gas pedal, etc), the environment (e.g. road and lighting conditions), and other participants (pedestrians, other vehicles, etc).
 * 
 * The operational situations and operating modes in which an item's malfunctioning behavior will result in a hazardous event shall be described, both for cases when the vehicle is correctly used and when it is incorrectly used in a foreseeable way 
 * <i><u>
 * </u></i><i><u>Reference: </u></i>
 * ISO 26262-3-7.4.2.1.1
 * ISO 26262-3-Annex.B-TableB.3.
 * 
 * Original fully qualified name: 
 * <em><b>safe10.ClassModel.Hazards.OperationalSituation</b></em> 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link org.safe.metamodel.safe10.OperationalSituation#getOtherSubjects <em>Other Subjects</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.OperationalSituation#getEnvironment <em>Environment</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.OperationalSituation#getDriver <em>Driver</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.OperationalSituation#getExternalHardware <em>External Hardware</em>}</li>
 *   <li>{@link org.safe.metamodel.safe10.OperationalSituation#getOtherParticipants <em>Other Participants</em>}</li>
 * </ul>
 * </p>
 *
 * @see org.safe.metamodel.safe10.Safe10Package#getOperationalSituation()
 * @model annotation="MetaData guid='{FF0A044E-CF76-46f6-8E90-A8791083C522}' id='-1141085200' EA\040name='OperationalSituation'"
 *        extendedMetaData="name='OPERATIONAL-SITUATION' kind='elementOnly'"
 *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='OPERATIONAL-SITUATIONS'"
 * @generated
 */
public interface OperationalSituation extends TraceableSpecification
{
  /**
   * Returns the value of the '<em><b>Other Subjects</b></em>' reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.Actor}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Other Subjects</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Other Subjects</em>' reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getOperationalSituation_OtherSubjects()
   * @model annotation="MetaData guid='{2D262B62-EA66-487c-8A97-9A04FC01805A}' id='-1938993912' EA\040name=''"
   *        extendedMetaData="name='OTHER-SUBJECTS-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='OTHER-SUBJECTS-REFS' xmlAttribute='false' featureWrapperElement='true' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  EList<Actor> getOtherSubjects();

  /**
   * Returns the value of the '<em><b>Environment</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Environment</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Environment</em>' reference.
   * @see #setEnvironment(Environment)
   * @see org.safe.metamodel.safe10.Safe10Package#getOperationalSituation_Environment()
   * @model annotation="MetaData guid='{DB923406-010C-4551-8C30-BD7A51B02CAA}' id='-1124400094' EA\040name=''"
   *        extendedMetaData="name='ENVIRONMENT-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='ENVIRONMENT-REFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  Environment getEnvironment();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.OperationalSituation#getEnvironment <em>Environment</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Environment</em>' reference.
   * @see #getEnvironment()
   * @generated
   */
  void setEnvironment(Environment value);

  /**
   * Returns the value of the '<em><b>Driver</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Driver</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Driver</em>' reference.
   * @see #setDriver(Actor)
   * @see org.safe.metamodel.safe10.Safe10Package#getOperationalSituation_Driver()
   * @model annotation="MetaData guid='{64B412BC-A1D4-4742-AEFF-10B66BCA6497}' id='845963527' EA\040name=''"
   *        extendedMetaData="name='DRIVER-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='DRIVER-REFS' xmlAttribute='false' featureWrapperElement='false' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  Actor getDriver();

  /**
   * Sets the value of the '{@link org.safe.metamodel.safe10.OperationalSituation#getDriver <em>Driver</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Driver</em>' reference.
   * @see #getDriver()
   * @generated
   */
  void setDriver(Actor value);

  /**
   * Returns the value of the '<em><b>External Hardware</b></em>' reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.Actor}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>External Hardware</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>External Hardware</em>' reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getOperationalSituation_ExternalHardware()
   * @model annotation="MetaData guid='{05885B18-6E67-46e1-860E-EB0161202715}' id='1252791427' EA\040name=''"
   *        extendedMetaData="name='EXTERNAL-HARDWARE-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='EXTERNAL-HARDWARE-REFS' xmlAttribute='false' featureWrapperElement='true' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  EList<Actor> getExternalHardware();

  /**
   * Returns the value of the '<em><b>Other Participants</b></em>' reference list.
   * The list contents are of type {@link org.safe.metamodel.safe10.Actor}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Other Participants</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Other Participants</em>' reference list.
   * @see org.safe.metamodel.safe10.Safe10Package#getOperationalSituation_OtherParticipants()
   * @model annotation="MetaData guid='{FE5BE433-EC89-488f-9704-5F2F267A2028}' id='1686740702' EA\040name=''"
   *        extendedMetaData="name='OTHER-PARTICIPANTS-REF' kind='element' namespace='http://safe-project.eu/1.0.1'"
   *        annotation="http:///org/eclipse/sphinx/emf/serialization/XMLPersistenceMappingExtendedMetaData wrapperName='OTHER-PARTICIPANTS-REFS' xmlAttribute='false' featureWrapperElement='true' featureElement='true' classifierWrapperElement='false' classifierElement='false'"
   * @generated
   */
  EList<Actor> getOtherParticipants();

} // OperationalSituation
