/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodel10.util;

import org.artop.aal.common.metamodel.AutosarReleaseDescriptor;
import org.eatop.eel.common.metamodel.EastADLReleaseDescriptor;
import org.eatop.eel.eastadl21.util.Eastadl21ReleaseDescriptor;
import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.impl.EPackageRegistryImpl;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.util.ExtendedMetaData;
import org.eclipse.emf.ecore.xmi.XMLResource;
import org.eclipse.sphinx.emf.resource.BasicMigrationExtendedMetaData;
import org.safe.common.resource.impl.SafeResourceFactoryImpl;
import org.safe.metamodel.safe10.Activator;
import org.safe.metamodel10.SAFE10ReleaseDescriptor;

import autosar40.util.Autosar40ReleaseDescriptor;

public class Safe10ResourceFactoryImpl extends SafeResourceFactoryImpl {

	/**
	 * Creates an instance of the resource factory. <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	public Safe10ResourceFactoryImpl() {
		super(SAFE10ReleaseDescriptor.INSTANCE);
	}

	/**
	 * Creates and initializes an {@link ExtendedMetaData} instance to be used on {@link XMLResource resources} created
	 * with this {@link Resource.Factory resource factory}.
	 * 
	 * @return The newly created and initialized {@link ExtendedMetaData} instance.
	 */
	@Override
	protected ExtendedMetaData createExtendedMetaData() {
		// Create and initialize migration-enabled extended meta data enabling SAFE resources whose version is not
		// the same but compatible with that of current SAFE metamodel implementation to be loaded
		BasicMigrationExtendedMetaData extendedMetaData = new BasicMigrationExtendedMetaData(new EPackageRegistryImpl(EPackage.Registry.INSTANCE)) {
			@Override
			public String getNamespace(EPackage ePackage) {
				// Is given EPackage an EPackage of an EAST-ADL metamodel?
				String uri = ePackage.getNsURI();
				if (uri != null && uri.startsWith(EastADLReleaseDescriptor.BASE_NAMESPACE)) {
					// Suppress individual sub EPackage namespaces; always use namespace of current EAST-ADL release
					return Eastadl21ReleaseDescriptor.INSTANCE.getNamespace();
				} else if (uri != null && uri.startsWith(AutosarReleaseDescriptor.BASE_NAMESPACE)) {
					// Suppress individual sub EPackage namespaces; always use namespace of current EAST-ADL release
					return Autosar40ReleaseDescriptor.INSTANCE.getNamespace();
				} else {
					return super.getNamespace(ePackage);
				}
			}

		};

		// extendedMetaData.putPackage(safeRelease.getNamespace(), safeRelease.getRootEPackage());
		for (java.net.URI compatibleNamespaceURI : safeRelease.getCompatibleNamespaceURIs()) {
			extendedMetaData.putPackage(compatibleNamespaceURI.toString(), safeRelease.getRootEPackage());
		}
		return extendedMetaData;
	}

	/**
	 * Creates an instance of the resource. <!-- begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @generated
	 */
	@Override
	public Resource createResource(URI uri) {
		XMLResource result = new Safe10ResourceImpl(uri);
		initResource(result);

		return result;

	}

	@Override
	protected void initSchemaLocationBaseURIs() {
		schemaLocationURIHandler.addSchemaLocationBaseURI(Activator.getPlugin(), "model"); //$NON-NLS-1$
	}

} // SAFE10ResourceFactoryImpl
