/**
 * <copyright>
 * 
 * Copyright (c) Continental AG and others.
 * All rights reserved. This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 
 * which accompanies this distribution, and is
 * available at http://www.eclipse.org/org/documents/epl-v10.php
 * 
 * Contributors: 
 *     Continental AG - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.serialization.internal;

import java.util.List;

import org.eatop.eel.serialization.internal.util.IEastADLSerializationConstants;
import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.InternalEObject;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.xmi.XMLHelper;
import org.eclipse.emf.ecore.xmi.XMLResource;
import org.eclipse.sphinx.emf.metamodel.IMetaModelDescriptor;
import org.eclipse.sphinx.emf.metamodel.MetaModelDescriptorRegistry;
import org.eclipse.sphinx.emf.serialization.internal.XMLPersistenceMappingHelperImpl;
import org.safe.common.metamodel.SAFEReleaseDescriptor;
import org.safe.common.util.ISAFEConstants;

public class SafeXMLPersistenceMappingHelperImpl extends XMLPersistenceMappingHelperImpl implements XMLHelper {
	/**
	 * Instantiates a new XMLHelper and sets its resource to given parameter value.
	 * 
	 * @param resource
	 *            The resource about which this helper will provide info.
	 */
	public SafeXMLPersistenceMappingHelperImpl(XMLResource resource) {
		super(resource);
		setResource(resource);
	}

	@Override
	public String getHREF(EObject obj) {
		InternalEObject o = (InternalEObject) obj;

		URI objectURI = o.eProxyURI();
		if (objectURI == null) {
			Resource otherResource = obj.eResource();
			if (otherResource == null) {
				if (resource != null && resource.getID(obj) != null) {
					objectURI = getHREF(resource, obj);
				} else {
					objectURI = handleDanglingHREF(obj);
					if (objectURI == null) {
						return null;
					}
				}
			} else {
				// FIXME
				IMetaModelDescriptor targetMMDescriptor = MetaModelDescriptorRegistry.INSTANCE.getDescriptor(obj.eClass());
				if (!targetMMDescriptor.getIdentifier().startsWith(SAFEReleaseDescriptor.ID)) {
					return getURIFragment(otherResource, obj);
				}
				objectURI = getHREF(otherResource, obj);
			}
		}

		objectURI = deresolve(objectURI);
		String result = objectURI.toString();

		// FIXME
		int index = result.lastIndexOf(IEastADLSerializationConstants.FRAGMENT_SEPARATOR); // "#"
		if (index != -1) {
			result = result.substring(index + 1);
		}
		index = result.lastIndexOf(IEastADLSerializationConstants.QUERY_SEPARATOR + IEastADLSerializationConstants.DESTINATION_TYPE_KEY
				+ IEastADLSerializationConstants.KEY_VALUE_SEPARATOR); // "?type="
		if (index != -1) {
			result = result.substring(0, index);
		}

		return result;
	}

	@Override
	protected String getPrefix(EPackage ePackage, boolean mustHavePrefix) {
		String nsPrefix = packages.get(ePackage);
		if (nsPrefix == null || mustHavePrefix && nsPrefix.length() == 0) {
			// FIXME
			String nsURI = null;
			if (xmlSchemaTypePackage == ePackage) {
				nsURI = XMLResource.XML_SCHEMA_URI;
			} else {
				nsURI = ePackage.getNsURI();
				if (extendedMetaData != null) {
					if (nsURI.contains(ISAFEConstants.AUTOSAR_ROOT_PACKAGE_NSURI)) {
						nsURI = ISAFEConstants.AUTOSAR_NSURI;
					} else {
						nsURI = extendedMetaData.getNamespace(ePackage);
					}
				}
			}

			boolean found = false;
			List<String> prefixes = urisToPrefixes.get(nsURI);
			if (prefixes != null) {
				for (String prefix : prefixes) {
					nsPrefix = prefix;
					if (!mustHavePrefix || nsPrefix.length() > 0) {
						found = true;
						break;
					}
				}
			}

			if (!found) {
				// for any content prefix to URI mapping could be in namespace context
				nsPrefix = namespaceSupport.getPrefix(nsURI);
				if (nsPrefix != null) {
					return nsPrefix;
				}

				if (nsURI != null) {
					nsPrefix = xmlSchemaTypePackage == ePackage ? ISAFEConstants.PACKAGE_PREFIX_XSD : ePackage.getNsPrefix();
				}
				if (nsPrefix == null) {
					nsPrefix = mustHavePrefix ? "_" : ""; //$NON-NLS-1$ //$NON-NLS-2$
				}

				if (prefixesToURIs.containsKey(nsPrefix)) {
					String currentValue = prefixesToURIs.get(nsPrefix);
					if (currentValue == null ? nsURI != null : !currentValue.equals(nsURI)) {
						int index = 1;
						while (prefixesToURIs.containsKey(nsPrefix + "_" + index)) { //$NON-NLS-1$
							++index;
						}
						nsPrefix += "_" + index; //$NON-NLS-1$
					}
				}

				prefixesToURIs.put(nsPrefix, nsURI);
			}

			if (!packages.containsKey(ePackage)) {
				packages.put(ePackage, nsPrefix);
			}
		}

		return nsPrefix;
	}

	// FIXME: to check 2013-01-09
	/**
	 * Update the mapping of prefixToURI. This method is used when saving the type attribute: if the package of eClass
	 * is other than the package of the feature's containing class, then the name of the eClass is added to be saved. To
	 * avoid the validation problem, the prefix is not saved directly in the type attribute, otherwise the
	 * "prefix:name", e.g., "_1:HW_ELEMENT" could not be validated by the parser. Meanwhile, this method is invoked to
	 * update the mapping of prefixToURI internally.
	 */
	public void updatePrefixToURI(EPackage ePackage, boolean mustHavePrefix) {
		getPrefix(ePackage, mustHavePrefix);
	}

}
