/**
 * <copyright>
 * 
 * Copyright (c) Continental AG and others.
 * All rights reserved. This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 
 * which accompanies this distribution, and is
 * available at http://www.eclipse.org/org/documents/epl-v10.php
 * 
 * Contributors: 
 *     Continental AG - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.serialization.internal;

import org.eatop.eel.serialization.internal.ExtendedXMLPersistenceMappingLoadImpl;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.xmi.XMLHelper;
import org.xml.sax.helpers.DefaultHandler;

/**
 * An XMLLoadImpl that is specially designed to load SAFE resources.
 */
public class SafeXMLPersistenceMappingLoadImpl extends ExtendedXMLPersistenceMappingLoadImpl {

	/**
	 * The package that will be associated with the target namespace.
	 */
	protected EPackage basePackage = null;

	/**
	 * Instantiates this class as an XMLLoadImpl with given helper and keeps track of the base package on which the
	 * XMLLoad will act.
	 * 
	 * @param helper
	 *            The helper that provides info during the deserialization process, typically annotations.
	 * @param ePackage
	 *            The basePackage to use.
	 */
	public SafeXMLPersistenceMappingLoadImpl(XMLHelper helper, EPackage ePackage) {
		super(helper);
		basePackage = ePackage;
	}

	/**
	 * Instantiates this class as an XMLLoadImpl with given helper and keeps track of the base package on which the
	 * XMLLoad will act.
	 * 
	 * @param helper
	 *            The helper that provides info during the deserialization process, typically annotations.
	 * @param ePackage
	 *            The basePackage to use.
	 */
	public SafeXMLPersistenceMappingLoadImpl(XMLHelper helper) {
		super(helper);
	}

	/*
	 * @see org.eclipse.sphinx.emf.resource.ExtendedXMLLoadImpl#makeDefaultHandler()
	 */
	@Override
	protected DefaultHandler makeDefaultHandler() {
		SafeXMLPersistenceMappingHandler handler = new SafeXMLPersistenceMappingHandler(resource, helper, options);
		return handler;
	}
}
