/**
 * <copyright>
 * 
 * Copyright (c) itemis and others.
 * All rights reserved. This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 
 * which accompanies this distribution, and is
 * available at http://www.eclipse.org/org/documents/epl-v10.php
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
 package org.safe.metamodelgen.serialization.generators.xsd

import autosar40.util.Autosar40ResourceFactoryImpl
import org.eatop.eel.eastadl21.util.Eastadl21ResourceFactoryImpl
import java.util.List
import org.artop.aal.common.metamodel.AutosarReleaseDescriptor
import org.artop.aal.common.resource.impl.AutosarResourceFactoryImpl
import org.eatop.eel.common.metamodel.EastADLReleaseDescriptor
import org.eclipse.eatop.metamodelgen.serialization.generators.util.Eastadl2XSDUtil
import org.eclipse.eatop.metamodelgen.serialization.generators.util.ITaggedValueConstants
import org.eclipse.emf.common.util.URI
import org.eclipse.emf.ecore.EClass
import org.eclipse.emf.ecore.EDataType
import org.eclipse.emf.ecore.ENamedElement
import org.eclipse.emf.ecore.EPackage
import org.eclipse.emf.ecore.EReference
import org.eclipse.emf.ecore.util.EcoreUtil
import org.eclipse.emf.ecore.util.ExtendedMetaData
import org.eclipse.emf.ecore.xmi.XMLResource
import org.eclipse.sphinx.emf.metamodel.IMetaModelDescriptor
import org.eclipse.sphinx.emf.metamodel.MetaModelDescriptorRegistry
import org.eclipse.sphinx.emf.resource.SchemaLocationURIHandler
import org.eclipse.sphinx.emf.serialization.generators.util.Ecore2XSDUtil
import org.eclipse.sphinx.emf.serialization.generators.util.IGeneratorConstants
import org.eclipse.sphinx.emf.serialization.generators.xsd.Ecore2XSDFactory

class SAFEEcore2XSDFactory extends Ecore2XSDFactory {
	
	//String EA_SCHEMA_PATH = "C:/Work/Workspace/runtime-EclipseApplication/safe.test/model/referenced/eastadl2111.xsd";
	
	new(EPackage ecoreModel) {
		super(ecoreModel);
	}
	
    	/**
	 * provide the actual referenced type xml name
	 * in general case, it is the upper case of the fetched xml name
	 * in SAFE, it may also be +"-IREF" or +"-TREF"
	 * */
	override protected String getTypeXMLName(String xmlName, ENamedElement eElement){
		val EPackage rootPackage = EcoreUtil.getRootContainer(eElement) as EPackage;
		val String nsURI = rootPackage.getNsURI();
		
		// if the type is created in the same xsd, return the fetched xmlName
		if(nsURI.equals(xsdExtendedMetaData.getNamespace(ecoreModel))){
			return xmlName;
		}
		// if it is Ecore element
		else if(nsURI.equals(IGeneratorConstants.DEFAULT_ECORE_NAMESPACE)){
			return xmlName;
		} 
		// if it is in referenced ecores
		else if(referencedEcores.contains(rootPackage)){
			//return XSDExtendedMetaDataUtil::buildXmlName(xmlName);
			// singular name by default
			var String result = Eastadl2XSDUtil::getSingularName(eElement);
			if(eElement instanceof EClass){
				
				val String stereotype = EcoreUtil.getAnnotation(eElement, ITaggedValueConstants.ANNOTATION_STEREOTYPE, ITaggedValueConstants.ANNOTATION_STEREOTYPE);
				if(ITaggedValueConstants.STEREOTYPE_INSTANCE_REF.equals(stereotype)){
					result = Eastadl2XSDUtil::getInstanceRefClassNameSingle(eElement as EClass);
				}
			}
			else if(eElement instanceof EReference){
				val String stereotype = EcoreUtil.getAnnotation(eElement, ITaggedValueConstants.ANNOTATION_STEREOTYPE, ITaggedValueConstants.ANNOTATION_STEREOTYPE);
				
				if (eElement != null && (eElement as EReference).getEType() != null)  {
					// has stereotype instance reference?
					val String stereotype2 = EcoreUtil.getAnnotation((eElement as EReference).getEType(), ITaggedValueConstants.ANNOTATION_STEREOTYPE, ITaggedValueConstants.ANNOTATION_STEREOTYPE);
					if (ITaggedValueConstants.STEREOTYPE_INSTANCE_REF.equals(stereotype2)) {
				      // the aggregation from source to instanceRef class is found	            
	           			result = Ecore2XSDUtil::buildXmlName(eElement.getName()) + IGeneratorConstants.SUFFIX_NAME;
					}
				}
				else if(ITaggedValueConstants.STEREOTYPE_INSTANCE_REF.equals(stereotype)){
					result = Ecore2XSDUtil::buildXmlName(eElement.getName())+ IGeneratorConstants.SUFFIX_NAME;
				}
			}
			return result;
		}
		
		//return XSDExtendedMetaDataUtil::buildXmlName(xmlName);
		return Eastadl2XSDUtil::getSingularName(eElement);
	}	
	
	override protected String getRootNsPrefix(EPackage ePackage){
		var String nsPrefix = ePackage.getNsPrefix();
		if(nsPrefix == ""){
			nsPrefix = "SAFE";
		}
		return nsPrefix;
	}
	
  override protected URI getXSDSchemaFileURIFromNsURI(String nsURI){
  	
	val IMetaModelDescriptor mmDescriptor = MetaModelDescriptorRegistry.INSTANCE.getDescriptor(new java.net.URI(nsURI));
	if(mmDescriptor!=null){
		if (mmDescriptor instanceof AutosarReleaseDescriptor){
  			// create a AUTOSAR resource
  			val AutosarResourceFactoryImpl resourceFactory = new Autosar40ResourceFactoryImpl();
  			val XMLResource resource = resourceFactory.createResource(URI.createURI("")) as XMLResource;
  			val SchemaLocationURIHandler uriHandler = (resource.getDefaultLoadOptions().get(XMLResource.OPTION_URI_HANDLER)) as SchemaLocationURIHandler;
  		    val URI resolvedUri = uriHandler.resolve(URI.createURI(nsURI));
  			if(resolvedUri != null){
  				return resolvedUri;
  			} 			
  		}
  		else if (mmDescriptor instanceof EastADLReleaseDescriptor){
  			// create a EASTADL resource
  			val Eastadl21ResourceFactoryImpl resourceFactory = new Eastadl21ResourceFactoryImpl();
  			val XMLResource resource = resourceFactory.createResource(URI.createURI("")) as XMLResource;
  			val SchemaLocationURIHandler uriHandler = (resource.getDefaultLoadOptions().get(XMLResource.OPTION_URI_HANDLER)) as SchemaLocationURIHandler;
  		    val URI resolvedUri = uriHandler.resolve(URI.createURI(nsURI));
  			if(resolvedUri != null){
  					return resolvedUri;
  			} 			
	
			//return EcorePlatformUtil.createURI(new Path(EA_SCHEMA_PATH));	
  		}
	}	
  	 
  	// by default return null
  	return null;
  }
  
    //===================================
  override Boolean isXMLPrimitiveXsdType(EDataType dataType) {

		val String stereotype = EcoreUtil.getAnnotation(dataType, ITaggedValueConstants.ANNOTATION_STEREOTYPE, ITaggedValueConstants.ANNOTATION_STEREOTYPE);
		val Boolean isPrimitive = ITaggedValueConstants.STEREOTYPE_PRIMITIVE.equals(stereotype);
		val Boolean isXsdTypeDefined = xsdExtendedMetaData.getXMLXsdSimpleType(dataType) != IGeneratorConstants.UNINITIALIZED_STRING;
		val Boolean isCustomSimpleTypeDefined = IGeneratorConstants.BOOLEAN_TRUE.equals(xsdExtendedMetaData.getXMLCustomSimpleType(dataType));
		var Boolean isPatternDefined = false;
		val List<String> patterns = ExtendedMetaData.INSTANCE.getPatternFacet(dataType);
		if (!patterns.isEmpty()) {
			isPatternDefined = patterns.get(0) != null;
		}

		// if is primitive, xsdType is defined, customType (custom simple type) is not defined, and pattern is not
		// defined
		if (isPrimitive && isXsdTypeDefined && !isCustomSimpleTypeDefined && !isPatternDefined) {
			return true;
		}

		return false;
	}
  
}