/**
 * <copyright>
 * 
 * Copyright (c) itemis and others.
 * All rights reserved. This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 
 * which accompanies this distribution, and is
 * available at http://www.eclipse.org/org/documents/epl-v10.php
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodelgen.ui;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.resources.IFile;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.eatop.metamodelgen.Activator;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.dialogs.ProgressMonitorDialog;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.sphinx.platform.util.PlatformLogUtil;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.handlers.HandlerUtil;
import org.safe.metamodelgen.SAFEEcoreMMGen;

public class SAFEMMGenUIHandler extends AbstractHandler {
	
	protected String EAP_FILE_EXTENSION = "eap";
	protected String ECORE_FILE_EXTENSION = "ecore";	

	protected static String GENERATE_ECORE_ONLY_PARAMETER = "org.safe.metamodelgen.commandParameters.ecoreGenOnly";
	protected static String GENERATE_MM_EMF_CODE_PARAMETER = "org.safe.metamodelgen.commandParameters.mmImplGen"; //$NON-NLS-1$
	protected static String GENERATE_ALL_PARAMETER = "org.safe.metamodelgen.commandParameters.allGen";
	
	public Object execute(ExecutionEvent event) throws ExecutionException {		
		// Gets the selected file from explorer
		IFile selectedEapFile = unwrap(event, IFile.class);
		Shell shell = HandlerUtil.getActiveShell(event);
		
		if (selectedEapFile != null) {
			String fileExtension = selectedEapFile.getFileExtension();
			if (fileExtension != null && fileExtension.equals(EAP_FILE_EXTENSION)) { //$NON-NLS-1$
				
				String generateEcoreOnly = event.getParameter(GENERATE_ECORE_ONLY_PARAMETER);
				String generateMMCode = event.getParameter(GENERATE_MM_EMF_CODE_PARAMETER);	
				String generateAll = event.getParameter(GENERATE_ALL_PARAMETER);
				generateEcoreMM(selectedEapFile, new Boolean(generateEcoreOnly).booleanValue(), new Boolean(generateMMCode).booleanValue(), new Boolean(generateAll).booleanValue(), shell);
			}
		} else {
			MessageDialog.openInformation(shell, "Info", "Please select a EAP source file");
		}
		return null;
	}
	
	protected void generateEcoreMM(IFile selectedEapFile, boolean generateEcoreOnly, boolean generateMMCode, boolean generateAll, Shell shell){
		// create EASTADLEcoreMMGen	
		final SAFEEcoreMMGen ecoreMMgen = new SAFEEcoreMMGen(selectedEapFile, generateEcoreOnly, generateMMCode, generateAll);
		
		// progress monitor dialog
		ProgressMonitorDialog dialog = new ProgressMonitorDialog(shell);    
		try {
			dialog.run(true, true, new IRunnableWithProgress(){
			     public void run(IProgressMonitor monitor) {
			         monitor.beginTask("Generating Ecore file ...", 100);
			         monitor.subTask("Generating Ecore file ...");
			         
			         // execute the task ...
			        	 try {
							ecoreMMgen.generate(monitor);
						} catch (Exception e) {
							PlatformLogUtil.logAsError(Activator.getDefault(), e);
						}
			     }
			 });
		} catch (InvocationTargetException e) {
			PlatformLogUtil.logAsError(Activator.getDefault(), e.getMessage());
		} catch (InterruptedException e) {
			PlatformLogUtil.logAsError(Activator.getDefault(), e.getMessage());
		} 
		
	}
	
	private <T> T unwrap(Object o, Class<T> clazz) {
		if (o instanceof ExecutionEvent) {
			o = HandlerUtil.getCurrentSelection((ExecutionEvent) o);
		}

		if (o instanceof IStructuredSelection) {
			o = ((IStructuredSelection) o).getFirstElement();
		}

		if (o instanceof IAdaptable) {
			o = ((IAdaptable) o).getAdapter(clazz);
		}

		if (clazz.isInstance(o)) {
			return clazz.cast(o);
		}

		return null;
	}
	
	
}
