/**
 * <copyright>
 * 
 * Copyright (c) itemis and others.
 * All rights reserved. This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 
 * which accompanies this distribution, and is
 * available at http://www.eclipse.org/org/documents/epl-v10.php
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.metamodelgen;

import java.io.IOException;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.SubProgressMonitor;
import org.eclipse.eatop.eaadapter.ea2ecore.postprocessings.AddOriginalQualifiedNameAnnotation;
import org.eclipse.eatop.eaadapter.ea2ecore.postprocessings.CreateGenModel;
import org.eclipse.eatop.eaadapter.ea2ecore.postprocessings.DeleteEmptyIdentifiablePackage;
import org.eclipse.eatop.eaadapter.ea2ecore.postprocessings.DeleteExampleModelPackage;
import org.eclipse.eatop.eaadapter.ea2ecore.postprocessings.DeletePackageGeneratedEcore;
import org.eclipse.eatop.eaadapter.ea2ecore.postprocessings.FlattenPackages;
import org.eclipse.eatop.eaadapter.ea2ecore.postprocessings.MakeAllFeaturesOrdered;
import org.eclipse.eatop.eaadapter.ea2ecore.postprocessings.MakeEEnumEDataTypeUnsettable;
import org.eclipse.eatop.eaadapter.ea2ecore.postprocessings.NameChanger;
import org.eclipse.eatop.eaadapter.ea2ecore.postprocessings.PackageNamesToLowercase;
import org.eclipse.eatop.eaadapter.ea2ecore.postprocessings.SetAttributesDefaultValue;
import org.eclipse.eatop.eaadapter.ea2ecore.postprocessings.SetInstanceClassNameForDataTypes;
import org.eclipse.eatop.metamodelgen.EcoreMMGen;
import org.eclipse.eatop.metamodelgen.postprocessings.AnalysisPersistencePattern;
import org.eclipse.eatop.metamodelgen.postprocessings.ConfigureInstanceRefAssociation;
import org.eclipse.eatop.metamodelgen.postprocessings.ConfigureInstanceRefClass;
import org.safe.metamodelgen.postprocessings.CopyAutosarFiles;
import org.safe.metamodelgen.postprocessings.CopyEastadlFiles;
import org.safe.metamodelgen.postprocessings.DeleteReferencesPackage;
import org.safe.metamodelgen.postprocessings.DetectUnusedReference;
import org.safe.metamodelgen.postprocessings.ReplaceReferences;
import org.safe.metamodelgen.postprocessings.SAFEAddPersistenceMapping;
import org.safe.metamodelgen.postprocessings.SAFEAdjustGenModel;
import org.safe.metamodelgen.postprocessings.SAFEAdjustRootEPackageNsURI;
import org.safe.metamodelgen.postprocessings.SAFEConvertEClassPrimitivesToEDataTypes;
import org.safe.metamodelgen.postprocessings.SAFECreateExtendedMetaData;
import org.safe.metamodelgen.postprocessings.SAFECreateXSDSchema;
import org.safe.metamodelgen.postprocessings.SAFEGenerateEMFProjects;
import org.safe.metamodelgen.postprocessings.SAFENormalizePackageNsURI;
import org.safe.metamodelgen.util.SAFEConstants;

public class SAFEEcoreMMGen extends EcoreMMGen{

	static private String SAFE_metaModelType = SAFEConstants.METAMODEL_TYPE_SAFE;
	private String eastadlStubPluginId = "org.eatop.stub";
	private String autosarStubPluginId = "org.artop.stub";
	
	public SAFEEcoreMMGen(IFile eapFile, boolean generateEcoreOnly, boolean generateMMCode, boolean generateAll){
		super(eapFile, SAFE_metaModelType, generateEcoreOnly, generateMMCode, generateAll);
	}
	
	@Override
	protected void addInitialEcorePostProcessings(String version){
		adapter.addPostProcessing(new DeletePackageGeneratedEcore());      
		adapter.addPostProcessing(new AddOriginalQualifiedNameAnnotation());
		adapter.addPostProcessing(new NameChanger());
                              
		adapter.addPostProcessing(new SAFEConvertEClassPrimitivesToEDataTypes());
		adapter.addPostProcessing(new SetInstanceClassNameForDataTypes());       
		adapter.addPostProcessing(new SAFENormalizePackageNsURI(version));
		adapter.addPostProcessing(new MakeAllFeaturesOrdered());
		adapter.addPostProcessing(new MakeEEnumEDataTypeUnsettable());
		adapter.addPostProcessing(new SetAttributesDefaultValue());
		adapter.addPostProcessing(new ConfigureInstanceRefAssociation());
		adapter.addPostProcessing(new ConfigureInstanceRefClass());
		adapter.addPostProcessing(new DeleteEmptyIdentifiablePackage());
		adapter.addPostProcessing(new PackageNamesToLowercase());
	}
	
	@Override
	protected void addAdjustEcorePostProcessings(String version, String geastadlRootDir, String eastadlRootDir, String autosarRootDir){	

		// SAFE specific
		adapter.addPostProcessing(new DeleteExampleModelPackage());       	
		adapter.addPostProcessing(new DetectUnusedReference());       	
		adapter.addPostProcessing(new CopyEastadlFiles(ecoreFile, eastadlRootDir));
		adapter.addPostProcessing(new CopyAutosarFiles(ecoreFile, autosarRootDir));
		adapter.addPostProcessing(new ReplaceReferences(ecoreFile));  
		adapter.addPostProcessing(new DeleteReferencesPackage());
    	
		//adapter.addPostProcessing(new SAFESetMetamodelTypeAnnotation(version));
		adapter.addPostProcessing(new FlattenPackages());
		adapter.addPostProcessing(new SAFECreateExtendedMetaData(version));
		adapter.addPostProcessing(new SAFEAdjustRootEPackageNsURI(version));
	}
	 
	@Override
	protected void addPersistenceMappingPostProcessings(IProgressMonitor monitor){
		adapter.addPostProcessing(new SAFEAddPersistenceMapping (ecoreFile, new SubProgressMonitor(monitor, 1)));
		// analysis and calculate patterns
		adapter.addPostProcessing(new AnalysisPersistencePattern());
	}
	
	@Override
	protected void addMMCodePostProcessings(String version, IProgressMonitor monitor) throws IOException{
		adapter.addPostProcessing(new CreateGenModel(ecoreFile, getProjectName()));
		adapter.addPostProcessing(new SAFEAdjustGenModel(ecoreFile, getProjectName(), version));
		adapter.addPostProcessing(new SAFEGenerateEMFProjects(new SubProgressMonitor(monitor, 1), ecoreFile, true, true, 
     			version));
	}
	
	@Override
	protected void addXSDSchemaPostProcessings(IProgressMonitor monitor){
		adapter.addPostProcessing(new SAFECreateXSDSchema(new SubProgressMonitor(monitor, 1), ecoreFile, eapFile));
	}
	
	@Override
	 protected String getRootPackageName(){
		 return "safe10";	
	 }
	 
	@Override
	 protected String getVersion(){
			 return "1.0.1";
	 }
	 
	@Override
	 protected String getEastadlRootDir(){
		 //URI stubUri = URI.createPlatformResourceURI(eastadlStubPluginId, true);
		 //IPath stubPath = EcorePlatformUtil.createAbsoluteFileLocation(stubUri);
		 //return stubPath.toFile().getAbsolutePath();		 	 
		 //return "C:\\Work\\Workspace\\runtime-EclipseApplication\\org.eatop.stub";
		 return eastadlStubPluginId + modelDir;	
	 }
	 
	@Override
	 protected String getAutosarRootDir(){
//		 URI stubUri = URI.createPlatformResourceURI(autosarStubPluginId, true);
//		 IPath stubPath = EcorePlatformUtil.createAbsoluteFileLocation(stubUri);
//		 return stubPath.toFile().getAbsolutePath();	 
		 //return "C:\\Work\\Workspace\\runtime-EclipseApplication\\org.artop.stub";
		return autosarStubPluginId + modelDir;	
	 }
}

